(window.webpackJsonp=window.webpackJsonp||[]).push([[91],{216:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"km",fields:{year:{displayName:"ឆ្នាំ",relative:{0:"ឆ្នាំ​នេះ",1:"ឆ្នាំ​ក្រោយ","-1":"ឆ្នាំ​មុន"},relativeTime:{future:{other:"{0} ឆ្នាំទៀត"},past:{other:"{0} ឆ្នាំ​មុន"}}},"year-short":{displayName:"ឆ្នាំ",relative:{0:"ឆ្នាំ​នេះ",1:"ឆ្នាំ​ក្រោយ","-1":"ឆ្នាំ​មុន"},relativeTime:{future:{other:"{0} ឆ្នាំទៀត"},past:{other:"{0} ឆ្នាំ​មុន"}}},"year-narrow":{displayName:"ឆ្នាំ",relative:{0:"ឆ្នាំ​នេះ",1:"ឆ្នាំ​ក្រោយ","-1":"ឆ្នាំ​មុន"},relativeTime:{future:{other:"{0} ឆ្នាំទៀត"},past:{other:"{0} ឆ្នាំ​មុន"}}},quarter:{displayName:"ត្រីមាស",relative:{0:"ត្រីមាស​នេះ",1:"ត្រីមាស​ក្រោយ","-1":"ត្រីមាស​មុន"},relativeTime:{future:{other:"{0} ត្រីមាសទៀត"},past:{other:"{0} ត្រីមាស​មុន"}}},"quarter-short":{displayName:"ត្រីមាស",relative:{0:"ត្រីមាស​នេះ",1:"ត្រីមាស​ក្រោយ","-1":"ត្រីមាស​មុន"},relativeTime:{future:{other:"{0} ត្រីមាសទៀត"},past:{other:"{0} ត្រីមាស​មុន"}}},"quarter-narrow":{displayName:"ត្រីមាស",relative:{0:"ត្រីមាស​នេះ",1:"ត្រីមាស​ក្រោយ","-1":"ត្រីមាស​មុន"},relativeTime:{future:{other:"{0} ត្រីមាសទៀត"},past:{other:"{0} ត្រីមាស​មុន"}}},month:{displayName:"ខែ",relative:{0:"ខែ​នេះ",1:"ខែ​ក្រោយ","-1":"ខែ​មុន"},relativeTime:{future:{other:"{0} ខែទៀត"},past:{other:"{0} ខែមុន"}}},"month-short":{displayName:"ខែ",relative:{0:"ខែ​នេះ",1:"ខែ​ក្រោយ","-1":"ខែ​មុន"},relativeTime:{future:{other:"{0} ខែទៀត"},past:{other:"{0} ខែមុន"}}},"month-narrow":{displayName:"ខែ",relative:{0:"ខែ​នេះ",1:"ខែ​ក្រោយ","-1":"ខែ​មុន"},relativeTime:{future:{other:"{0} ខែទៀត"},past:{other:"{0} ខែមុន"}}},week:{displayName:"សប្ដាហ៍",relative:{0:"សប្ដាហ៍​នេះ",1:"សប្ដាហ៍​ក្រោយ","-1":"សប្ដាហ៍​មុន"},relativeTime:{future:{other:"{0} សប្ដាហ៍ទៀត"},past:{other:"{0} សប្ដាហ៍​មុន"}},relativePeriod:"សប្តាហ៍នៃ {0}"},"week-short":{displayName:"សប្ដាហ៍",relative:{0:"សប្ដាហ៍​នេះ",1:"សប្ដាហ៍​ក្រោយ","-1":"សប្ដាហ៍​មុន"},relativeTime:{future:{other:"{0} សប្ដាហ៍ទៀត"},past:{other:"{0} សប្ដាហ៍​មុន"}},relativePeriod:"សប្តាហ៍នៃ {0}"},"week-narrow":{displayName:"សប្ដាហ៍",relative:{0:"សប្ដាហ៍​នេះ",1:"សប្ដាហ៍​ក្រោយ","-1":"សប្ដាហ៍​មុន"},relativeTime:{future:{other:"{0} សប្ដាហ៍ទៀត"},past:{other:"{0} សប្ដាហ៍​មុន"}},relativePeriod:"សប្តាហ៍នៃ {0}"},day:{displayName:"ថ្ងៃ",relative:{0:"ថ្ងៃ​នេះ",1:"ថ្ងៃ​ស្អែក",2:"​ខាន​ស្អែក","-2":"ម្សិល​ម៉្ងៃ","-1":"ម្សិលមិញ"},relativeTime:{future:{other:"{0} ថ្ងៃទៀត"},past:{other:"{0} ថ្ងៃ​មុន"}}},"day-short":{displayName:"ថ្ងៃ",relative:{0:"ថ្ងៃ​នេះ",1:"ថ្ងៃស្អែក",2:"​ខាន​ស្អែក","-2":"ម្សិល​ម៉្ងៃ","-1":"ម្សិលមិញ"},relativeTime:{future:{other:"{0} ថ្ងៃទៀត"},past:{other:"{0} ថ្ងៃ​​មុន"}}},"day-narrow":{displayName:"ថ្ងៃ",relative:{0:"ថ្ងៃ​នេះ",1:"ថ្ងៃស្អែក",2:"​ខាន​ស្អែក","-2":"ម្សិល​ម៉្ងៃ","-1":"ម្សិលមិញ"},relativeTime:{future:{other:"{0} ថ្ងៃទៀត"},past:{other:"{0} ថ្ងៃ​​មុន"}}},hour:{displayName:"ម៉ោង",relative:{0:"ម៉ោងនេះ"},relativeTime:{future:{other:"ក្នុង​រយៈ​ពេល {0} ម៉ោង"},past:{other:"{0} ម៉ោង​មុន"}}},"hour-short":{displayName:"ម៉ោង",relative:{0:"ម៉ោងនេះ"},relativeTime:{future:{other:"{0} ម៉ោងទៀត"},past:{other:"{0} ម៉ោង​មុន"}}},"hour-narrow":{displayName:"ម៉ោង",relative:{0:"ម៉ោងនេះ"},relativeTime:{future:{other:"{0} ម៉ោងទៀត"},past:{other:"{0} ម៉ោង​មុន"}}},minute:{displayName:"នាទី",relative:{0:"នាទីនេះ"},relativeTime:{future:{other:"{0} នាទីទៀត"},past:{other:"{0} នាទី​មុន"}}},"minute-short":{displayName:"នាទី",relative:{0:"នាទីនេះ"},relativeTime:{future:{other:"{0} នាទីទៀត"},past:{other:"{0} នាទី​​មុន"}}},"minute-narrow":{displayName:"នាទី",relative:{0:"នាទីនេះ"},relativeTime:{future:{other:"{0} នាទីទៀត"},past:{other:"{0} នាទី​​មុន"}}},second:{displayName:"វិនាទី",relative:{0:"ឥឡូវ"},relativeTime:{future:{other:"{0} វិនាទីទៀត"},past:{other:"{0} វិនាទី​មុន"}}},"second-short":{displayName:"វិនាទី",relative:{0:"ឥឡូវ"},relativeTime:{future:{other:"{0} វិនាទីទៀត"},past:{other:"{0} វិនាទី​មុន"}}},"second-narrow":{displayName:"វិនាទី",relative:{0:"ឥឡូវ"},relativeTime:{future:{other:"{0} វិនាទីទៀត"},past:{other:"{0} វិនាទី​មុន"}}}}})}}]);
//# sourceMappingURL=91.aaedf07e1a1c0392f425.index.js.map