(window.webpackJsonp=window.webpackJsonp||[]).push([[93],{218:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"ko",fields:{year:{displayName:"년",relative:{0:"올해",1:"내년","-1":"작년"},relativeTime:{future:{other:"{0}년 후"},past:{other:"{0}년 전"}}},"year-short":{displayName:"년",relative:{0:"올해",1:"내년","-1":"작년"},relativeTime:{future:{other:"{0}년 후"},past:{other:"{0}년 전"}}},"year-narrow":{displayName:"년",relative:{0:"올해",1:"내년","-1":"작년"},relativeTime:{future:{other:"{0}년 후"},past:{other:"{0}년 전"}}},quarter:{displayName:"분기",relative:{0:"이번 분기",1:"다음 분기","-1":"지난 분기"},relativeTime:{future:{other:"{0}분기 후"},past:{other:"{0}분기 전"}}},"quarter-short":{displayName:"분기",relative:{0:"이번 분기",1:"다음 분기","-1":"지난 분기"},relativeTime:{future:{other:"{0}분기 후"},past:{other:"{0}분기 전"}}},"quarter-narrow":{displayName:"분기",relative:{0:"이번 분기",1:"다음 분기","-1":"지난 분기"},relativeTime:{future:{other:"{0}분기 후"},past:{other:"{0}분기 전"}}},month:{displayName:"월",relative:{0:"이번 달",1:"다음 달","-1":"지난달"},relativeTime:{future:{other:"{0}개월 후"},past:{other:"{0}개월 전"}}},"month-short":{displayName:"월",relative:{0:"이번 달",1:"다음 달","-1":"지난달"},relativeTime:{future:{other:"{0}개월 후"},past:{other:"{0}개월 전"}}},"month-narrow":{displayName:"월",relative:{0:"이번 달",1:"다음 달","-1":"지난달"},relativeTime:{future:{other:"{0}개월 후"},past:{other:"{0}개월 전"}}},week:{displayName:"주",relative:{0:"이번 주",1:"다음 주","-1":"지난주"},relativeTime:{future:{other:"{0}주 후"},past:{other:"{0}주 전"}},relativePeriod:"{0}번째 주"},"week-short":{displayName:"주",relative:{0:"이번 주",1:"다음 주","-1":"지난주"},relativeTime:{future:{other:"{0}주 후"},past:{other:"{0}주 전"}},relativePeriod:"{0}번째 주"},"week-narrow":{displayName:"주",relative:{0:"이번 주",1:"다음 주","-1":"지난주"},relativeTime:{future:{other:"{0}주 후"},past:{other:"{0}주 전"}},relativePeriod:"{0}번째 주"},day:{displayName:"일",relative:{0:"오늘",1:"내일",2:"모레","-2":"그저께","-1":"어제"},relativeTime:{future:{other:"{0}일 후"},past:{other:"{0}일 전"}}},"day-short":{displayName:"일",relative:{0:"오늘",1:"내일",2:"모레","-2":"그저께","-1":"어제"},relativeTime:{future:{other:"{0}일 후"},past:{other:"{0}일 전"}}},"day-narrow":{displayName:"일",relative:{0:"오늘",1:"내일",2:"모레","-2":"그저께","-1":"어제"},relativeTime:{future:{other:"{0}일 후"},past:{other:"{0}일 전"}}},hour:{displayName:"시",relative:{0:"현재 시간"},relativeTime:{future:{other:"{0}시간 후"},past:{other:"{0}시간 전"}}},"hour-short":{displayName:"시",relative:{0:"현재 시간"},relativeTime:{future:{other:"{0}시간 후"},past:{other:"{0}시간 전"}}},"hour-narrow":{displayName:"시",relative:{0:"현재 시간"},relativeTime:{future:{other:"{0}시간 후"},past:{other:"{0}시간 전"}}},minute:{displayName:"분",relative:{0:"현재 분"},relativeTime:{future:{other:"{0}분 후"},past:{other:"{0}분 전"}}},"minute-short":{displayName:"분",relative:{0:"현재 분"},relativeTime:{future:{other:"{0}분 후"},past:{other:"{0}분 전"}}},"minute-narrow":{displayName:"분",relative:{0:"현재 분"},relativeTime:{future:{other:"{0}분 후"},past:{other:"{0}분 전"}}},second:{displayName:"초",relative:{0:"지금"},relativeTime:{future:{other:"{0}초 후"},past:{other:"{0}초 전"}}},"second-short":{displayName:"초",relative:{0:"지금"},relativeTime:{future:{other:"{0}초 후"},past:{other:"{0}초 전"}}},"second-narrow":{displayName:"초",relative:{0:"지금"},relativeTime:{future:{other:"{0}초 후"},past:{other:"{0}초 전"}}}}},{locale:"ko-KP",parentLocale:"ko"})}}]);
//# sourceMappingURL=93.aaedf07e1a1c0392f425.index.js.map