{% extends "richie/fullwidth.html" %}
{% load cms_tags i18n %}

{% block content %}
<div class="organization-list">
  <h1 class="organization-list__title">{{ current_page.get_title }}</h1>

  <div class="organization-list__content">
  {% for page in current_page.get_child_pages %}
    {% if page.organization %}
      {% include "courses/cms/fragment_organization_glimpse.html" with organization=page.organization %}
    {% endif %}
  {% empty %}
    <p class="organization-list__content__item--empty">{% trans "No organization yet" %}</p>
  {% endfor %}
  </div>
</div>
{% endblock content %}
