(window.webpackJsonp=window.webpackJsonp||[]).push([[79],{204:function(e,a){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"jv",fields:{year:{displayName:"taun",relative:{0:"taun iki",1:"taun ngarep","-1":"taun wingi"},relativeTime:{future:{other:"ing {0} taun"},past:{other:"{0} taun kepungkur"}}},"year-short":{displayName:"taun",relative:{0:"taun iki",1:"taun ngarep","-1":"taun wingi"},relativeTime:{future:{other:"ing {0} tn"},past:{other:"{0} tn kepungkur"}}},"year-narrow":{displayName:"taun",relative:{0:"taun iki",1:"taun ngarep","-1":"taun wingi"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},quarter:{displayName:"triwulan",relative:{0:"kwartal iki",1:"kwartal ngarep","-1":"kwartal wingi"},relativeTime:{future:{other:"ing {0} kwartal"},past:{other:"{0} kwartal kepungkur"}}},"quarter-short":{displayName:"triwulan",relative:{0:"kwartal iki",1:"kwartal ngarep","-1":"kwartal wingi"},relativeTime:{future:{other:"ing {0} kwrt."},past:{other:"{0} kwrt. kepungkur"}}},"quarter-narrow":{displayName:"triwulan",relative:{0:"kwartal iki",1:"kwartal ngarep","-1":"kwartal wingi"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},month:{displayName:"sasi",relative:{0:"sasi iki",1:"sasi ngarep","-1":"sasi wingi"},relativeTime:{future:{other:"ing {0} sasi"},past:{other:"{0} sasi kepungkur"}}},"month-short":{displayName:"sasi",relative:{0:"sasi iki",1:"sasi ngarep","-1":"sasi wingi"},relativeTime:{future:{other:"ing {0} s."},past:{other:"{0} s. kepungkur"}}},"month-narrow":{displayName:"sasi",relative:{0:"sasi iki",1:"sasi ngarep","-1":"sasi wingi"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},week:{displayName:"pekan",relative:{0:"pekan iki",1:"pekan ngarep","-1":"pekan wingi"},relativeTime:{future:{other:"ing {0} minggu"},past:{other:"{0} minggu kepungkur"}},relativePeriod:"pekan kaping {0}"},"week-short":{displayName:"pekan",relative:{0:"pekan iki",1:"pekan ngarep","-1":"pekan wingi"},relativeTime:{future:{other:"ing {0} mgg."},past:{other:"{0} mgg. kepungkur"}},relativePeriod:"pekan kaping {0}"},"week-narrow":{displayName:"pekan",relative:{0:"pekan iki",1:"pekan ngarep","-1":"pekan wingi"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}},relativePeriod:"pekan kaping {0}"},day:{displayName:"dino",relative:{0:"saiki",1:"sesuk","-1":"wingi"},relativeTime:{future:{other:"ing {0} dina"},past:{other:"{0} dina kepungkur"}}},"day-short":{displayName:"dino",relative:{0:"saiki",1:"sesuk","-1":"wingi"},relativeTime:{future:{other:"ing {0} dina"},past:{other:"-{0} d"}}},"day-narrow":{displayName:"dino",relative:{0:"saiki",1:"sesuk","-1":"wingi"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},hour:{displayName:"jam",relative:{0:"jam iki"},relativeTime:{future:{other:"ing {0} jam"},past:{other:"{0} jam kepungkur"}}},"hour-short":{displayName:"jam",relative:{0:"jam iki"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-narrow":{displayName:"jam",relative:{0:"jam iki"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},minute:{displayName:"menit",relative:{0:"menit iki"},relativeTime:{future:{other:"ing {0} mnt"},past:{other:"{0} men. kepungkur"}}},"minute-short":{displayName:"menit",relative:{0:"menit iki"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-narrow":{displayName:"menit",relative:{0:"menit iki"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},second:{displayName:"detik",relative:{0:"now"},relativeTime:{future:{other:"ing {0} detik"},past:{other:"{0} detik kepungkur"}}},"second-short":{displayName:"detik",relative:{0:"now"},relativeTime:{future:{other:"ing {0} dtk"},past:{other:"{0} det. kepungkur"}}},"second-narrow":{displayName:"detik",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}}}})}}]);
//# sourceMappingURL=79.aaedf07e1a1c0392f425.index.js.map