(window.webpackJsonp=window.webpackJsonp||[]).push([[137],{262:function(e,r){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"nn",fields:{year:{displayName:"år",relative:{0:"i år",1:"neste år","-1":"i fjor"},relativeTime:{future:{one:"om {0} år",other:"om {0} år"},past:{one:"for {0} år sidan",other:"for {0} år sidan"}}},"year-short":{displayName:"år",relative:{0:"i år",1:"neste år","-1":"i fjor"},relativeTime:{future:{one:"om {0} år",other:"om {0} år"},past:{one:"for {0} år sidan",other:"for {0} år sidan"}}},"year-narrow":{displayName:"år",relative:{0:"i år",1:"neste år","-1":"i fjor"},relativeTime:{future:{one:"om {0} år",other:"om {0} år"},past:{one:"for {0} år sidan",other:"for {0} år sidan"}}},quarter:{displayName:"kvartal",relative:{0:"dette kvartalet",1:"neste kvartal","-1":"førre kvartal"},relativeTime:{future:{one:"om {0} kvartal",other:"om {0} kvartal"},past:{one:"for {0} kvartal sidan",other:"for {0} kvartal sidan"}}},"quarter-short":{displayName:"kv.",relative:{0:"dette kvartalet",1:"neste kvartal","-1":"førre kvartal"},relativeTime:{future:{one:"om {0} kv.",other:"om {0} kv."},past:{one:"for {0} kv. sidan",other:"for {0} kv. sidan"}}},"quarter-narrow":{displayName:"kv.",relative:{0:"dette kvartalet",1:"neste kvartal","-1":"førre kvartal"},relativeTime:{future:{one:"+{0} kv.",other:"+{0} kv."},past:{one:"–{0} kv.",other:"–{0} kv."}}},month:{displayName:"månad",relative:{0:"denne månaden",1:"neste månad","-1":"førre månad"},relativeTime:{future:{one:"om {0} månad",other:"om {0} månadar"},past:{one:"for {0} månad sidan",other:"for {0} månadar sidan"}}},"month-short":{displayName:"mnd.",relative:{0:"denne månaden",1:"neste månad","-1":"førre månad"},relativeTime:{future:{one:"om {0} md.",other:"om {0} md."},past:{one:"for {0} md. sidan",other:"for {0} md. sidan"}}},"month-narrow":{displayName:"md.",relative:{0:"denne månaden",1:"neste månad","-1":"førre månad"},relativeTime:{future:{one:"+{0} md.",other:"+{0} md."},past:{one:"–{0} md.",other:"–{0} md."}}},week:{displayName:"veke",relative:{0:"denne veka",1:"neste veke","-1":"førre veke"},relativeTime:{future:{one:"om {0} veke",other:"om {0} veker"},past:{one:"for {0} veke sidan",other:"for {0} veker sidan"}},relativePeriod:"veka som inneheld {0}"},"week-short":{displayName:"veke",relative:{0:"denne veka",1:"neste veke","-1":"førre veke"},relativeTime:{future:{one:"om {0} v.",other:"om {0} v."},past:{one:"for {0} v. sidan",other:"for {0} v. sidan"}},relativePeriod:"veka med {0}"},"week-narrow":{displayName:"v.",relative:{0:"denne veka",1:"neste veke","-1":"førre veke"},relativeTime:{future:{one:"+{0} v.",other:"+{0} v."},past:{one:"–{0} v.",other:"–{0} v."}},relativePeriod:"v. m. {0}"},day:{displayName:"dag",relative:{0:"i dag",1:"i morgon",2:"i overmorgon","-2":"i førgår","-1":"i går"},relativeTime:{future:{one:"om {0} døgn",other:"om {0} døgn"},past:{one:"for {0} døgn sidan",other:"for {0} døgn sidan"}}},"day-short":{displayName:"dag",relative:{0:"i dag",1:"i morgon",2:"i overmorgon","-2":"i førgår","-1":"i går"},relativeTime:{future:{one:"om {0} d.",other:"om {0} d."},past:{one:"for {0} d. sidan",other:"for {0} d. sidan"}}},"day-narrow":{displayName:"d.",relative:{0:"i dag",1:"i morgon",2:"i overmorgon","-2":"i førgår","-1":"i går"},relativeTime:{future:{one:"+{0} d.",other:"+{0} d."},past:{one:"–{0} d.",other:"–{0} d."}}},hour:{displayName:"time",relative:{0:"denne timen"},relativeTime:{future:{one:"om {0} time",other:"om {0} timar"},past:{one:"for {0} time sidan",other:"for {0} timar sidan"}}},"hour-short":{displayName:"t",relative:{0:"denne timen"},relativeTime:{future:{one:"om {0} t",other:"om {0} t"},past:{one:"for {0} t sidan",other:"for {0} t sidan"}}},"hour-narrow":{displayName:"t",relative:{0:"denne timen"},relativeTime:{future:{one:"+{0} t",other:"+{0} t"},past:{one:"–{0} t",other:"–{0} t"}}},minute:{displayName:"minutt",relative:{0:"dette minuttet"},relativeTime:{future:{one:"om {0} minutt",other:"om {0} minutt"},past:{one:"for {0} minutt sidan",other:"for {0} minutt sidan"}}},"minute-short":{displayName:"min",relative:{0:"dette minuttet"},relativeTime:{future:{one:"om {0} min",other:"om {0} min"},past:{one:"for {0} min sidan",other:"for {0} min sidan"}}},"minute-narrow":{displayName:"m",relative:{0:"dette minuttet"},relativeTime:{future:{one:"+{0} min",other:"+{0} min"},past:{one:"–{0} min",other:"–{0} min"}}},second:{displayName:"sekund",relative:{0:"no"},relativeTime:{future:{one:"om {0} sekund",other:"om {0} sekund"},past:{one:"for {0} sekund sidan",other:"for {0} sekund sidan"}}},"second-short":{displayName:"sek",relative:{0:"no"},relativeTime:{future:{one:"om {0} sek",other:"om {0} sek"},past:{one:"for {0} sek sidan",other:"for {0} sek sidan"}}},"second-narrow":{displayName:"s",relative:{0:"no"},relativeTime:{future:{one:"+{0} s",other:"+{0} s"},past:{one:"–{0} s",other:"–{0} s"}}}}})}}]);
//# sourceMappingURL=137.aaedf07e1a1c0392f425.index.js.map