(window.webpackJsonp=window.webpackJsonp||[]).push([[65],{190:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"hi",fields:{year:{displayName:"वर्ष",relative:{0:"इस वर्ष",1:"अगला वर्ष","-1":"पिछला वर्ष"},relativeTime:{future:{one:"{0} वर्ष में",other:"{0} वर्ष में"},past:{one:"{0} वर्ष पहले",other:"{0} वर्ष पहले"}}},"year-short":{displayName:"वर्ष",relative:{0:"इस वर्ष",1:"अगला वर्ष","-1":"पिछला वर्ष"},relativeTime:{future:{one:"{0} वर्ष में",other:"{0} वर्ष में"},past:{one:"{0} वर्ष पहले",other:"{0} वर्ष पहले"}}},"year-narrow":{displayName:"वर्ष",relative:{0:"इस वर्ष",1:"अगला वर्ष","-1":"पिछला वर्ष"},relativeTime:{future:{one:"{0} वर्ष में",other:"{0} वर्ष में"},past:{one:"{0} वर्ष पहले",other:"{0} वर्ष पहले"}}},quarter:{displayName:"तिमाही",relative:{0:"इस तिमाही",1:"अगली तिमाही","-1":"अंतिम तिमाही"},relativeTime:{future:{one:"{0} तिमाही में",other:"{0} तिमाहियों में"},past:{one:"{0} तिमाही पहले",other:"{0} तिमाही पहले"}}},"quarter-short":{displayName:"तिमाही",relative:{0:"इस तिमाही",1:"अगली तिमाही","-1":"अंतिम तिमाही"},relativeTime:{future:{one:"{0} तिमाही में",other:"{0} तिमाहियों में"},past:{one:"{0} तिमाही पहले",other:"{0} तिमाहियों पहले"}}},"quarter-narrow":{displayName:"तिमाही",relative:{0:"इस तिमाही",1:"अगली तिमाही","-1":"अंतिम तिमाही"},relativeTime:{future:{one:"{0} ति॰ में",other:"{0} ति॰ में"},past:{one:"{0} ति॰ पहले",other:"{0} ति॰ पहले"}}},month:{displayName:"माह",relative:{0:"इस माह",1:"अगला माह","-1":"पिछला माह"},relativeTime:{future:{one:"{0} माह में",other:"{0} माह में"},past:{one:"{0} माह पहले",other:"{0} माह पहले"}}},"month-short":{displayName:"माह",relative:{0:"इस माह",1:"अगला माह","-1":"पिछला माह"},relativeTime:{future:{one:"{0} माह में",other:"{0} माह में"},past:{one:"{0} माह पहले",other:"{0} माह पहले"}}},"month-narrow":{displayName:"माह",relative:{0:"इस माह",1:"अगला माह","-1":"पिछला माह"},relativeTime:{future:{one:"{0} माह में",other:"{0} माह में"},past:{one:"{0} माह पहले",other:"{0} माह पहले"}}},week:{displayName:"सप्ताह",relative:{0:"इस सप्ताह",1:"अगला सप्ताह","-1":"पिछला सप्ताह"},relativeTime:{future:{one:"{0} सप्ताह में",other:"{0} सप्ताह में"},past:{one:"{0} सप्ताह पहले",other:"{0} सप्ताह पहले"}},relativePeriod:"{0} के सप्ताह"},"week-short":{displayName:"सप्ताह",relative:{0:"इस सप्ताह",1:"अगला सप्ताह","-1":"पिछला सप्ताह"},relativeTime:{future:{one:"{0} सप्ताह में",other:"{0} सप्ताह में"},past:{one:"{0} सप्ताह पहले",other:"{0} सप्ताह पहले"}},relativePeriod:"{0} के सप्ताह"},"week-narrow":{displayName:"सप्ताह",relative:{0:"इस सप्ताह",1:"अगला सप्ताह","-1":"पिछला सप्ताह"},relativeTime:{future:{one:"{0} सप्ताह में",other:"{0} सप्ताह में"},past:{one:"{0} सप्ताह पहले",other:"{0} सप्ताह पहले"}},relativePeriod:"{0} के सप्ताह"},day:{displayName:"दिन",relative:{0:"आज",1:"कल",2:"परसों","-2":"परसों","-1":"कल"},relativeTime:{future:{one:"{0} दिन में",other:"{0} दिन में"},past:{one:"{0} दिन पहले",other:"{0} दिन पहले"}}},"day-short":{displayName:"दिन",relative:{0:"आज",1:"कल",2:"परसों","-2":"परसों","-1":"कल"},relativeTime:{future:{one:"{0} दिन में",other:"{0} दिन में"},past:{one:"{0} दिन पहले",other:"{0} दिन पहले"}}},"day-narrow":{displayName:"दिन",relative:{0:"आज",1:"कल",2:"परसों","-2":"परसों","-1":"कल"},relativeTime:{future:{one:"{0} दिन में",other:"{0} दिन में"},past:{one:"{0} दिन पहले",other:"{0} दिन पहले"}}},hour:{displayName:"घंटा",relative:{0:"यह घंटा"},relativeTime:{future:{one:"{0} घंटे में",other:"{0} घंटे में"},past:{one:"{0} घंटे पहले",other:"{0} घंटे पहले"}}},"hour-short":{displayName:"घं॰",relative:{0:"यह घंटा"},relativeTime:{future:{one:"{0} घं॰ में",other:"{0} घं॰ में"},past:{one:"{0} घं॰ पहले",other:"{0} घं॰ पहले"}}},"hour-narrow":{displayName:"घं॰",relative:{0:"यह घंटा"},relativeTime:{future:{one:"{0} घं॰ में",other:"{0} घं॰ में"},past:{one:"{0} घं॰ पहले",other:"{0} घं॰ पहले"}}},minute:{displayName:"मिनट",relative:{0:"यह मिनट"},relativeTime:{future:{one:"{0} मिनट में",other:"{0} मिनट में"},past:{one:"{0} मिनट पहले",other:"{0} मिनट पहले"}}},"minute-short":{displayName:"मि॰",relative:{0:"यह मिनट"},relativeTime:{future:{one:"{0} मि॰ में",other:"{0} मि॰ में"},past:{one:"{0} मि॰ पहले",other:"{0} मि॰ पहले"}}},"minute-narrow":{displayName:"मि॰",relative:{0:"यह मिनट"},relativeTime:{future:{one:"{0} मि॰ में",other:"{0} मि॰ में"},past:{one:"{0} मि॰ पहले",other:"{0} मि॰ पहले"}}},second:{displayName:"सेकंड",relative:{0:"अब"},relativeTime:{future:{one:"{0} सेकंड में",other:"{0} सेकंड में"},past:{one:"{0} सेकंड पहले",other:"{0} सेकंड पहले"}}},"second-short":{displayName:"से॰",relative:{0:"अब"},relativeTime:{future:{one:"{0} से॰ में",other:"{0} से॰ में"},past:{one:"{0} से॰ पहले",other:"{0} से॰ पहले"}}},"second-narrow":{displayName:"से॰",relative:{0:"अब"},relativeTime:{future:{one:"{0} से॰ में",other:"{0} से॰ में"},past:{one:"{0} से॰ पहले",other:"{0} से॰ पहले"}}}}})}}]);
//# sourceMappingURL=65.aaedf07e1a1c0392f425.index.js.map