(window.webpackJsonp=window.webpackJsonp||[]).push([[76],{201:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"ja",fields:{year:{displayName:"年",relative:{0:"今年",1:"翌年","-1":"昨年"},relativeTime:{future:{other:"{0} 年後"},past:{other:"{0} 年前"}}},"year-short":{displayName:"年",relative:{0:"今年",1:"翌年","-1":"昨年"},relativeTime:{future:{other:"{0} 年後"},past:{other:"{0} 年前"}}},"year-narrow":{displayName:"年",relative:{0:"今年",1:"翌年","-1":"昨年"},relativeTime:{future:{other:"{0}年後"},past:{other:"{0}年前"}}},quarter:{displayName:"四半期",relative:{0:"今四半期",1:"翌四半期","-1":"前四半期"},relativeTime:{future:{other:"{0} 四半期後"},past:{other:"{0} 四半期前"}}},"quarter-short":{displayName:"四半期",relative:{0:"今四半期",1:"翌四半期","-1":"前四半期"},relativeTime:{future:{other:"{0} 四半期後"},past:{other:"{0} 四半期前"}}},"quarter-narrow":{displayName:"四半期",relative:{0:"今四半期",1:"翌四半期","-1":"前四半期"},relativeTime:{future:{other:"{0}四半期後"},past:{other:"{0}四半期前"}}},month:{displayName:"月",relative:{0:"今月",1:"翌月","-1":"先月"},relativeTime:{future:{other:"{0} か月後"},past:{other:"{0} か月前"}}},"month-short":{displayName:"月",relative:{0:"今月",1:"翌月","-1":"先月"},relativeTime:{future:{other:"{0} か月後"},past:{other:"{0} か月前"}}},"month-narrow":{displayName:"月",relative:{0:"今月",1:"翌月","-1":"先月"},relativeTime:{future:{other:"{0}か月後"},past:{other:"{0}か月前"}}},week:{displayName:"週",relative:{0:"今週",1:"翌週","-1":"先週"},relativeTime:{future:{other:"{0} 週間後"},past:{other:"{0} 週間前"}},relativePeriod:"{0} 日の週"},"week-short":{displayName:"週",relative:{0:"今週",1:"翌週","-1":"先週"},relativeTime:{future:{other:"{0} 週間後"},past:{other:"{0} 週間前"}},relativePeriod:"{0} 日の週"},"week-narrow":{displayName:"週",relative:{0:"今週",1:"翌週","-1":"先週"},relativeTime:{future:{other:"{0}週間後"},past:{other:"{0}週間前"}},relativePeriod:"{0}日の週"},day:{displayName:"日",relative:{0:"今日",1:"明日",2:"明後日","-2":"一昨日","-1":"昨日"},relativeTime:{future:{other:"{0} 日後"},past:{other:"{0} 日前"}}},"day-short":{displayName:"日",relative:{0:"今日",1:"明日",2:"明後日","-2":"一昨日","-1":"昨日"},relativeTime:{future:{other:"{0} 日後"},past:{other:"{0} 日前"}}},"day-narrow":{displayName:"日",relative:{0:"今日",1:"明日",2:"明後日","-2":"一昨日","-1":"昨日"},relativeTime:{future:{other:"{0}日後"},past:{other:"{0}日前"}}},hour:{displayName:"時",relative:{0:"1 時間以内"},relativeTime:{future:{other:"{0} 時間後"},past:{other:"{0} 時間前"}}},"hour-short":{displayName:"時",relative:{0:"1 時間以内"},relativeTime:{future:{other:"{0} 時間後"},past:{other:"{0} 時間前"}}},"hour-narrow":{displayName:"時",relative:{0:"1 時間以内"},relativeTime:{future:{other:"{0}時間後"},past:{other:"{0}時間前"}}},minute:{displayName:"分",relative:{0:"1 分以内"},relativeTime:{future:{other:"{0} 分後"},past:{other:"{0} 分前"}}},"minute-short":{displayName:"分",relative:{0:"1 分以内"},relativeTime:{future:{other:"{0} 分後"},past:{other:"{0} 分前"}}},"minute-narrow":{displayName:"分",relative:{0:"1 分以内"},relativeTime:{future:{other:"{0}分後"},past:{other:"{0}分前"}}},second:{displayName:"秒",relative:{0:"今"},relativeTime:{future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}}},"second-short":{displayName:"秒",relative:{0:"今"},relativeTime:{future:{other:"{0} 秒後"},past:{other:"{0} 秒前"}}},"second-narrow":{displayName:"秒",relative:{0:"今"},relativeTime:{future:{other:"{0}秒後"},past:{other:"{0}秒前"}}}}})}}]);
//# sourceMappingURL=76.aaedf07e1a1c0392f425.index.js.map