(window.webpackJsonp=window.webpackJsonp||[]).push([[142],{267:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"or",fields:{year:{displayName:"ବର୍ଷ",relative:{0:"ଏହି ବର୍ଷ",1:"ଆଗାମୀ ବର୍ଷ","-1":"ଗତ ବର୍ଷ"},relativeTime:{future:{one:"{0} ବର୍ଷରେ",other:"{0} ବର୍ଷରେ"},past:{one:"{0} ବର୍ଷ ପୂର୍ବେ",other:"{0} ବର୍ଷ ପୂର୍ବେ"}}},"year-short":{displayName:"ବ.",relative:{0:"ଏହି ବର୍ଷ",1:"ଆଗାମୀ ବର୍ଷ","-1":"ଗତ ବର୍ଷ"},relativeTime:{future:{one:"{0} ବ. ରେ",other:"{0} ବ. ରେ"},past:{one:"{0} ବ. ପୂର୍ବେ",other:"{0} ବ. ପୂର୍ବେ"}}},"year-narrow":{displayName:"ବ.",relative:{0:"ଏହି ବର୍ଷ",1:"ଆଗାମୀ ବର୍ଷ","-1":"ଗତ ବର୍ଷ"},relativeTime:{future:{one:"{0} ବ. ରେ",other:"{0} ବ. ରେ"},past:{one:"{0} ବ. ପୂର୍ବେ",other:"{0} ବ. ପୂର୍ବେ"}}},quarter:{displayName:"ତ୍ରୟମାସ",relative:{0:"ଗତ ତ୍ରୟମାସ",1:"ଆଗାମୀ ତ୍ରୟମାସ","-1":"ଗତ ତ୍ରୟମାସ"},relativeTime:{future:{one:"{0} ତ୍ରୟମାସରେ",other:"{0} ତ୍ରୟମାସରେ"},past:{one:"{0} ତ୍ରୟମାସ ପୂର୍ବେ",other:"{0} ତ୍ରୟମାସ ପୂର୍ବେ"}}},"quarter-short":{displayName:"ତ୍ରୟ.",relative:{0:"ଗତ ତ୍ରୟମାସ",1:"ଆଗାମୀ ତ୍ରୟମାସ","-1":"ଗତ ତ୍ରୟମାସ"},relativeTime:{future:{one:"{0} ତ୍ରୟ. ରେ",other:"{0} ତ୍ରୟ. ରେ"},past:{one:"{0} ତ୍ରୟ. ପୂର୍ବେ",other:"{0} ତ୍ରୟ. ପୂର୍ବେ"}}},"quarter-narrow":{displayName:"ତ୍ରୟ.",relative:{0:"ଗତ ତ୍ରୟମାସ",1:"ଆଗାମୀ ତ୍ରୟମାସ","-1":"ଗତ ତ୍ରୟମାସ"},relativeTime:{future:{one:"{0} ତ୍ରୟ. ରେ",other:"{0} ତ୍ରୟ. ରେ"},past:{one:"{0} ତ୍ରୟ. ପୂର୍ବେ",other:"{0} ତ୍ରୟ. ପୂର୍ବେ"}}},month:{displayName:"ମାସ",relative:{0:"ଏହି ମାସ",1:"ଆଗାମୀ ମାସ","-1":"ଗତ ମାସ"},relativeTime:{future:{one:"{0} ମାସରେ",other:"{0} ମାସରେ"},past:{one:"{0} ମାସ ପୂର୍ବେ",other:"{0} ମାସ ପୂର୍ବେ"}}},"month-short":{displayName:"ମା.",relative:{0:"ଏହି ମାସ",1:"ଆଗାମୀ ମାସ","-1":"ଗତ ମାସ"},relativeTime:{future:{one:"{0} ମା. ରେ",other:"{0} ମା. ରେ"},past:{one:"{0} ମା. ପୂର୍ବେ",other:"{0} ମା. ପୂର୍ବେ"}}},"month-narrow":{displayName:"ମା.",relative:{0:"ଏହି ମାସ",1:"ଆଗାମୀ ମାସ","-1":"ଗତ ମାସ"},relativeTime:{future:{one:"{0} ମା. ରେ",other:"{0} ମା. ରେ"},past:{one:"{0} ମା. ପୂର୍ବେ",other:"{0} ମା. ପୂର୍ବେ"}}},week:{displayName:"ସପ୍ତାହ",relative:{0:"ଏହି ସପ୍ତାହ",1:"ଆଗାମୀ ସପ୍ତାହ","-1":"ଗତ ସପ୍ତାହ"},relativeTime:{future:{one:"{0} ସପ୍ତାହରେ",other:"{0} ସପ୍ତାହରେ"},past:{one:"{0} ସପ୍ତାହରେ",other:"{0} ସପ୍ତାହ ପୂର୍ବେ"}},relativePeriod:"{0} ର ସପ୍ତାହ"},"week-short":{displayName:"ସ.",relative:{0:"ଏହି ସପ୍ତାହ",1:"ଆଗାମୀ ସପ୍ତାହ","-1":"ଗତ ସପ୍ତାହ"},relativeTime:{future:{one:"{0} ସପ୍ତା. ରେ",other:"{0} ସପ୍ତା. ରେ"},past:{one:"{0} ସପ୍ତା. ପୂର୍ବେ",other:"{0} ସପ୍ତା. ପୂର୍ବେ"}},relativePeriod:"{0} ର ସପ୍ତାହ"},"week-narrow":{displayName:"ସ.",relative:{0:"ଏହି ସପ୍ତାହ",1:"ଆଗାମୀ ସପ୍ତାହ","-1":"ଗତ ସପ୍ତାହ"},relativeTime:{future:{one:"{0} ସପ୍ତା. ରେ",other:"{0} ସପ୍ତା. ରେ"},past:{one:"{0} ସପ୍ତା. ପୂର୍ବେ",other:"{0} ସପ୍ତା. ପୂର୍ବେ"}},relativePeriod:"{0} ର ସପ୍ତାହ"},day:{displayName:"ଦିନ",relative:{0:"ଆଜି",1:"ଆସନ୍ତାକାଲି","-1":"ଗତକାଲି"},relativeTime:{future:{one:"{0} ଦିନରେ",other:"{0} ଦିନରେ"},past:{one:"{0} ଦିନ ପୂର୍ବେ",other:"{0} ଦିନ ପୂର୍ବେ"}}},"day-short":{displayName:"ଦିନ",relative:{0:"ଆଜି",1:"ଆସନ୍ତାକାଲି","-1":"ଗତକାଲି"},relativeTime:{future:{one:"{0} ଦିନରେ",other:"{0} ଦିନରେ"},past:{one:"{0} ଦିନ ପୂର୍ବେ",other:"{0} ଦିନ ପୂର୍ବେ"}}},"day-narrow":{displayName:"ଦିନ",relative:{0:"ଆଜି",1:"ଆସନ୍ତାକାଲି","-1":"ଗତକାଲି"},relativeTime:{future:{one:"{0} ଦିନରେ",other:"{0} ଦିନରେ"},past:{one:"{0} ଦିନ ପୂର୍ବେ",other:"{0} ଦିନ ପୂର୍ବେ"}}},hour:{displayName:"ଘଣ୍ଟା",relative:{0:"ଏହି ଘଣ୍ଟା"},relativeTime:{future:{one:"{0} ଘଣ୍ଟାରେ",other:"{0} ଘଣ୍ଟାରେ"},past:{one:"{0} ଘଣ୍ଟା ପୂର୍ବେ",other:"{0} ଘଣ୍ଟା ପୂର୍ବେ"}}},"hour-short":{displayName:"ଘ.",relative:{0:"ଏହି ଘଣ୍ଟା"},relativeTime:{future:{one:"{0} ଘ. ରେ",other:"{0} ଘ. ରେ"},past:{one:"{0} ଘ. ପୂର୍ବେ",other:"{0} ଘ. ପୂର୍ବେ"}}},"hour-narrow":{displayName:"ଘ.",relative:{0:"ଏହି ଘଣ୍ଟା"},relativeTime:{future:{one:"{0} ଘ. ରେ",other:"{0} ଘ. ରେ"},past:{one:"{0} ଘ. ପୂର୍ବେ",other:"{0} ଘ. ପୂର୍ବେ"}}},minute:{displayName:"ମିନିଟ୍",relative:{0:"ଏହି ମିନିଟ୍"},relativeTime:{future:{one:"{0} ମିନିଟ୍‌‌ରେ",other:"{0} ମିନିଟ୍‌‌ରେ"},past:{one:"{0} ମିନିଟ୍ ପୂର୍ବେ",other:"{0} ମିନିଟ୍ ପୂର୍ବେ"}}},"minute-short":{displayName:"ମି.",relative:{0:"ଏହି ମିନିଟ୍"},relativeTime:{future:{one:"{0} ମି. ରେ",other:"{0} ମି. ରେ"},past:{one:"{0} ମି. ପୂର୍ବେ",other:"{0} ମି. ପୂର୍ବେ"}}},"minute-narrow":{displayName:"ମି.",relative:{0:"ଏହି ମିନିଟ୍"},relativeTime:{future:{one:"{0} ମି. ରେ",other:"{0} ମି. ରେ"},past:{one:"{0} ମି. ପୂର୍ବେ",other:"{0} ମି. ପୂର୍ବେ"}}},second:{displayName:"ସେକେଣ୍ଡ୍",relative:{0:"ବର୍ତ୍ତମାନ"},relativeTime:{future:{one:"{0} ସେକେଣ୍ଡରେ",other:"{0} ସେକେଣ୍ଡରେ"},past:{one:"{0} ସେକେଣ୍ଡ ପୂର୍ବେ",other:"{0} ସେକେଣ୍ଡ ପୂର୍ବେ"}}},"second-short":{displayName:"ସେକେଣ୍ଡ୍",relative:{0:"ବର୍ତ୍ତମାନ"},relativeTime:{future:{one:"{0} ସେ. ରେ",other:"{0} ସେ. ରେ"},past:{one:"{0} ସେ. ପୂର୍ବେ",other:"{0} ସେ. ପୂର୍ବେ"}}},"second-narrow":{displayName:"ସେ.",relative:{0:"ବର୍ତ୍ତମାନ"},relativeTime:{future:{one:"{0} ସେ. ରେ",other:"{0} ସେ. ରେ"},past:{one:"{0} ସେ. ପୂର୍ବେ",other:"{0} ସେ. ପୂର୍ବେ"}}}}})}}]);
//# sourceMappingURL=142.aaedf07e1a1c0392f425.index.js.map