(window.webpackJsonp=window.webpackJsonp||[]).push([[7],{132:function(e,a){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"ast",fields:{year:{displayName:"añu",relative:{0:"esti añu",1:"l’añu viniente","-1":"l’añu pasáu"},relativeTime:{future:{one:"en {0} añu",other:"en {0} años"},past:{one:"hai {0} añu",other:"hai {0} años"}}},"year-short":{displayName:"añu",relative:{0:"esti añu",1:"l’añu vin.","-1":"l’añu pas."},relativeTime:{future:{one:"en {0} añu",other:"en {0} años"},past:{one:"hai {0} añu",other:"hai {0} años"}}},"year-narrow":{displayName:"añu",relative:{0:"esti añu",1:"añu vin.","-1":"añu pas."},relativeTime:{future:{one:"en {0} a.",other:"en {0} a."},past:{one:"hai {0} a.",other:"hai {0} a."}}},quarter:{displayName:"trimestre",relative:{0:"esti trimestre",1:"trimestre viniente","-1":"trimestre anterior"},relativeTime:{future:{one:"en {0} trimestre",other:"en {0} trimestres"},past:{one:"hai {0} trimestre",other:"hai {0} trimestres"}}},"quarter-short":{displayName:"tri.",relative:{0:"esti trim.",1:"trim. vin.","-1":"trim. ant."},relativeTime:{future:{one:"en {0} trim.",other:"en {0} trim."},past:{one:"hai {0} trim.",other:"hai {0} trim."}}},"quarter-narrow":{displayName:"tri.",relative:{0:"esti trim.",1:"trim. vin.","-1":"trim. ant."},relativeTime:{future:{one:"en {0} tr.",other:"en {0} tr."},past:{one:"hai {0} tr.",other:"hai {0} tr."}}},month:{displayName:"mes",relative:{0:"esti mes",1:"el mes viniente","-1":"el mes pasáu"},relativeTime:{future:{one:"en {0} mes",other:"en {0} meses"},past:{one:"hai {0} mes",other:"hai {0} meses"}}},"month-short":{displayName:"mes",relative:{0:"esti mes",1:"mes vin.","-1":"mes pas."},relativeTime:{future:{one:"en {0} mes",other:"en {0} meses"},past:{one:"hai {0} mes",other:"hai {0} meses"}}},"month-narrow":{displayName:"mes",relative:{0:"esti mes",1:"mes vin.","-1":"mes pas."},relativeTime:{future:{one:"en {0} m.",other:"en {0} m."},past:{one:"hai {0} m.",other:"hai {0} m."}}},week:{displayName:"selmana",relative:{0:"esta selmana",1:"la selmana viniente","-1":"la selmana pasada"},relativeTime:{future:{one:"en {0} selmana",other:"en {0} selmanes"},past:{one:"hai {0} selmana",other:"hai {0} selmanes"}},relativePeriod:"la selmana del {0}"},"week-short":{displayName:"sel.",relative:{0:"esta selm.",1:"selm. viniente","-1":"selm. pasada"},relativeTime:{future:{one:"en {0} selm.",other:"en {0} selm."},past:{one:"hai {0} selm.",other:"hai {0} selm."}},relativePeriod:"la selmana del {0}"},"week-narrow":{displayName:"sel.",relative:{0:"esta selm.",1:"selm. vin.","-1":"selm. pas."},relativeTime:{future:{one:"en {0} se.",other:"en {0} se."},past:{one:"hai {0} se.",other:"hai {0} se."}},relativePeriod:"la selmana del {0}"},day:{displayName:"día",relative:{0:"güei",1:"mañana",2:"pasao mañana","-2":"antayeri","-1":"ayeri"},relativeTime:{future:{one:"en {0} día",other:"en {0} díes"},past:{one:"hai {0} día",other:"hai {0} díes"}}},"day-short":{displayName:"día",relative:{0:"güei",1:"mañana",2:"pasao mañana","-2":"antayeri","-1":"ayeri"},relativeTime:{future:{one:"en {0} día",other:"en {0} díes"},past:{one:"hai {0} día",other:"hai {0} díes"}}},"day-narrow":{displayName:"día",relative:{0:"güei",1:"mañ.",2:"p. mañ.","-2":"antay.","-1":"ayeri"},relativeTime:{future:{one:"en {0} d.",other:"en {0} d."},past:{one:"hai {0} d.",other:"hai {0} d."}}},hour:{displayName:"hora",relative:{0:"esta hora"},relativeTime:{future:{one:"en {0} hora",other:"en {0} hores"},past:{one:"hai {0} hora",other:"hai {0} hores"}}},"hour-short":{displayName:"h.",relative:{0:"esta hora"},relativeTime:{future:{one:"en {0} h.",other:"en {0} h."},past:{one:"hai {0} h.",other:"hai {0} h."}}},"hour-narrow":{displayName:"h.",relative:{0:"esta h."},relativeTime:{future:{one:"en {0} h.",other:"en {0} h."},past:{one:"hai {0} h.",other:"hai {0} h."}}},minute:{displayName:"minutu",relative:{0:"esti minutu"},relativeTime:{future:{one:"en {0} minutu",other:"en {0} minutos"},past:{one:"hai {0} minutu",other:"hai {0} minutos"}}},"minute-short":{displayName:"min.",relative:{0:"esti min."},relativeTime:{future:{one:"en {0} min.",other:"en {0} min."},past:{one:"hai {0} min.",other:"hai {0} min."}}},"minute-narrow":{displayName:"m.",relative:{0:"esti min."},relativeTime:{future:{one:"en {0} min.",other:"en {0} min."},past:{one:"hai {0} min.",other:"hai {0} min."}}},second:{displayName:"segundu",relative:{0:"agora"},relativeTime:{future:{one:"en {0} segundu",other:"en {0} segundos"},past:{one:"hai {0} segundu",other:"hai {0} segundos"}}},"second-short":{displayName:"s.",relative:{0:"agora"},relativeTime:{future:{one:"en {0} seg.",other:"en {0} seg."},past:{one:"hai {0} seg.",other:"hai {0} seg."}}},"second-narrow":{displayName:"s.",relative:{0:"agora"},relativeTime:{future:{one:"en {0} s.",other:"en {0} s."},past:{one:"hai {0} s.",other:"hai {0} s."}}}}})}}]);
//# sourceMappingURL=7.aaedf07e1a1c0392f425.index.js.map