# Generated by Django 2.1.10 on 2019-07-17 06:27

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [("courses", "0004_auto_20190619_1630")]

    operations = [
        migrations.AddField(
            model_name="category",
            name="color",
            field=models.CharField(blank=True, max_length=10, null=True),
        )
    ]
