(window.webpackJsonp=window.webpackJsonp||[]).push([[129],{254:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"mzn",fields:{year:{displayName:"سال",relative:{0:"امسال",1:"سال دیگه","-1":"پارسال"},relativeTime:{future:{other:"{0} سال دله"},past:{other:"{0} سال پیش"}}},"year-short":{displayName:"سال",relative:{0:"امسال",1:"سال دیگه","-1":"پارسال"},relativeTime:{future:{other:"{0} سال دله"},past:{other:"{0} سال پیش"}}},"year-narrow":{displayName:"سال",relative:{0:"امسال",1:"سال دیگه","-1":"پارسال"},relativeTime:{future:{other:"{0} سال دله"},past:{other:"{0} سال پیش"}}},quarter:{displayName:"ربع",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"{0} ربع دله"},past:{other:"{0} ربع پیش"}}},"quarter-short":{displayName:"ربع",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"{0} ربع دله"},past:{other:"{0} ربع پیش"}}},"quarter-narrow":{displayName:"ربع",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"{0} ربع دله"},past:{other:"{0} ربع پیش"}}},month:{displayName:"ماه",relative:{0:"این ماه",1:"ماه ِبعد","-1":"ماه قبل"},relativeTime:{future:{other:"{0} ماه دله"},past:{other:"{0} ماه پیش"}}},"month-short":{displayName:"ماه",relative:{0:"این ماه",1:"ماه ِبعد","-1":"ماه قبل"},relativeTime:{future:{other:"{0} ماه دله"},past:{other:"{0} ماه پیش"}}},"month-narrow":{displayName:"ماه",relative:{0:"این ماه",1:"ماه ِبعد","-1":"ماه قبل"},relativeTime:{future:{other:"{0} ماه دله"},past:{other:"{0} ماه پیش"}}},week:{displayName:"هفته",relative:{0:"این هفته",1:"بعدی هفته","-1":"قبلی هفته"},relativeTime:{future:{other:"{0} هفته دله"},past:{other:"{0} هفته پیش"}},relativePeriod:"the week of {0}"},"week-short":{displayName:"هفته",relative:{0:"این هفته",1:"بعدی هفته","-1":"قبلی هفته"},relativeTime:{future:{other:"{0} هفته دله"},past:{other:"{0} هفته پیش"}},relativePeriod:"the week of {0}"},"week-narrow":{displayName:"هفته",relative:{0:"این هفته",1:"بعدی هفته","-1":"قبلی هفته"},relativeTime:{future:{other:"{0} هفته دله"},past:{other:"{0} هفته پیش"}},relativePeriod:"the week of {0}"},day:{displayName:"روز",relative:{0:"اَمروز",1:"فِردا","-1":"دیروز"},relativeTime:{future:{other:"{0} روز دله"},past:{other:"{0} روز پیش"}}},"day-short":{displayName:"روز",relative:{0:"اَمروز",1:"فِردا","-1":"دیروز"},relativeTime:{future:{other:"{0} روز دله"},past:{other:"{0} روز پیش"}}},"day-narrow":{displayName:"روز",relative:{0:"اَمروز",1:"فِردا","-1":"دیروز"},relativeTime:{future:{other:"{0} روز دله"},past:{other:"{0} روز پیش"}}},hour:{displayName:"ساعِت",relative:{0:"this hour"},relativeTime:{future:{other:"{0} ساعِت دله"},past:{other:"{0} ساعِت پیش"}}},"hour-short":{displayName:"ساعت",relative:{0:"this hour"},relativeTime:{future:{other:"{0} ساعت دله"},past:{other:"{0} ساعت پیش"}}},"hour-narrow":{displayName:"ساعت",relative:{0:"this hour"},relativeTime:{future:{other:"{0} ساعت دله"},past:{other:"{0} ساعت پیش"}}},minute:{displayName:"دقیقه",relative:{0:"this minute"},relativeTime:{future:{other:"{0} دقیقه دله"},past:{other:"{0} دَقه پیش"}}},"minute-short":{displayName:"دَقه",relative:{0:"this minute"},relativeTime:{future:{other:"{0} دَقه دله"},past:{other:"{0} دَقه پیش"}}},"minute-narrow":{displayName:"دَقه",relative:{0:"this minute"},relativeTime:{future:{other:"{0} دَقه دله"},past:{other:"{0} دَقه پیش"}}},second:{displayName:"ثانیه",relative:{0:"now"},relativeTime:{future:{other:"{0} ثانیه دله"},past:{other:"{0} ثانیه پیش"}}},"second-short":{displayName:"ثانیه",relative:{0:"now"},relativeTime:{future:{other:"{0} ثانیه دله"},past:{other:"{0} ثانیه پیش"}}},"second-narrow":{displayName:"ثانیه",relative:{0:"now"},relativeTime:{future:{other:"{0} ثانیه دله"},past:{other:"{0} ثانیه پیش"}}}}})}}]);
//# sourceMappingURL=129.aaedf07e1a1c0392f425.index.js.map