(window.webpackJsonp=window.webpackJsonp||[]).push([[71],{196:function(a,e){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"id",fields:{year:{displayName:"tahun",relative:{0:"tahun ini",1:"tahun depan","-1":"tahun lalu"},relativeTime:{future:{other:"dalam {0} tahun"},past:{other:"{0} tahun yang lalu"}}},"year-short":{displayName:"thn.",relative:{0:"tahun ini",1:"tahun depan","-1":"tahun lalu"},relativeTime:{future:{other:"dlm {0} thn"},past:{other:"{0} thn lalu"}}},"year-narrow":{displayName:"thn.",relative:{0:"tahun ini",1:"tahun depan","-1":"tahun lalu"},relativeTime:{future:{other:"dlm {0} thn"},past:{other:"{0} thn lalu"}}},quarter:{displayName:"kuartal",relative:{0:"kuartal ini",1:"kuartal berikutnya","-1":"Kuartal lalu"},relativeTime:{future:{other:"dalam {0} kuartal"},past:{other:"{0} kuartal yang lalu"}}},"quarter-short":{displayName:"krtl.",relative:{0:"kuartal ini",1:"kuartal berikutnya","-1":"Kuartal lalu"},relativeTime:{future:{other:"dlm {0} krtl."},past:{other:"{0} krtl. lalu"}}},"quarter-narrow":{displayName:"krtl.",relative:{0:"kuartal ini",1:"kuartal berikutnya","-1":"Kuartal lalu"},relativeTime:{future:{other:"dlm {0} krtl."},past:{other:"{0} krtl. lalu"}}},month:{displayName:"bulan",relative:{0:"bulan ini",1:"bulan berikutnya","-1":"bulan lalu"},relativeTime:{future:{other:"dalam {0} bulan"},past:{other:"{0} bulan yang lalu"}}},"month-short":{displayName:"bln.",relative:{0:"bulan ini",1:"bulan berikutnya","-1":"bulan lalu"},relativeTime:{future:{other:"dlm {0} bln"},past:{other:"{0} bln lalu"}}},"month-narrow":{displayName:"bln.",relative:{0:"bulan ini",1:"bulan berikutnya","-1":"bulan lalu"},relativeTime:{future:{other:"dlm {0} bln"},past:{other:"{0} bln lalu"}}},week:{displayName:"minggu",relative:{0:"minggu ini",1:"minggu depan","-1":"minggu lalu"},relativeTime:{future:{other:"dalam {0} minggu"},past:{other:"{0} minggu yang lalu"}},relativePeriod:"minggu ke-{0}"},"week-short":{displayName:"mgg.",relative:{0:"minggu ini",1:"minggu depan","-1":"minggu lalu"},relativeTime:{future:{other:"dlm {0} mgg"},past:{other:"{0} mgg lalu"}},relativePeriod:"mgg ke-{0}"},"week-narrow":{displayName:"mgg.",relative:{0:"minggu ini",1:"minggu depan","-1":"minggu lalu"},relativeTime:{future:{other:"dlm {0} mgg"},past:{other:"{0} mgg lalu"}},relativePeriod:"mgg ke-{0}"},day:{displayName:"hari",relative:{0:"hari ini",1:"besok",2:"lusa","-2":"kemarin dulu","-1":"kemarin"},relativeTime:{future:{other:"dalam {0} hari"},past:{other:"{0} hari yang lalu"}}},"day-short":{displayName:"h",relative:{0:"hari ini",1:"besok",2:"lusa","-2":"kemarin dulu","-1":"kemarin"},relativeTime:{future:{other:"dalam {0} h"},past:{other:"{0} h lalu"}}},"day-narrow":{displayName:"h",relative:{0:"hari ini",1:"besok",2:"lusa","-2":"kemarin dulu","-1":"kemarin"},relativeTime:{future:{other:"dalam {0} h"},past:{other:"{0} h lalu"}}},hour:{displayName:"Jam",relative:{0:"jam ini"},relativeTime:{future:{other:"dalam {0} jam"},past:{other:"{0} jam yang lalu"}}},"hour-short":{displayName:"jam",relative:{0:"jam ini"},relativeTime:{future:{other:"dalam {0} jam"},past:{other:"{0} jam lalu"}}},"hour-narrow":{displayName:"j",relative:{0:"jam ini"},relativeTime:{future:{other:"dalam {0} jam"},past:{other:"{0} jam lalu"}}},minute:{displayName:"menit",relative:{0:"menit ini"},relativeTime:{future:{other:"dalam {0} menit"},past:{other:"{0} menit yang lalu"}}},"minute-short":{displayName:"mnt.",relative:{0:"menit ini"},relativeTime:{future:{other:"dlm {0} mnt"},past:{other:"{0} mnt lalu"}}},"minute-narrow":{displayName:"m",relative:{0:"menit ini"},relativeTime:{future:{other:"dlm {0} mnt"},past:{other:"{0} mnt lalu"}}},second:{displayName:"detik",relative:{0:"sekarang"},relativeTime:{future:{other:"dalam {0} detik"},past:{other:"{0} detik yang lalu"}}},"second-short":{displayName:"dtk.",relative:{0:"sekarang"},relativeTime:{future:{other:"dlm {0} dtk"},past:{other:"{0} dtk lalu"}}},"second-narrow":{displayName:"d",relative:{0:"sekarang"},relativeTime:{future:{other:"dlm {0} dtk"},past:{other:"{0} dtk lalu"}}}}})}}]);
//# sourceMappingURL=71.aaedf07e1a1c0392f425.index.js.map