(window.webpackJsonp=window.webpackJsonp||[]).push([[160],{285:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"sd",fields:{year:{displayName:"سال",relative:{0:"پويون سال",1:"پويون سال","-1":"پويون سال"},relativeTime:{future:{one:"{0} سالن ۾",other:"{0} سالن ۾"},past:{one:"{0} سال پهرين",other:"{0} سال پهرين"}}},"year-short":{displayName:"سال",relative:{0:"پويون سال",1:"پويون سال","-1":"پويون سال"},relativeTime:{future:{one:"{0} سالن ۾",other:"{0} سالن ۾"},past:{one:"{0} سال پهرين",other:"{0} سال پهرين"}}},"year-narrow":{displayName:"سال",relative:{0:"پويون سال",1:"پويون سال","-1":"پويون سال"},relativeTime:{future:{one:"{0} سالن ۾",other:"{0} سالن ۾"},past:{one:"{0} سال پهرين",other:"{0} سال پهرين"}}},quarter:{displayName:"ٽي ماهي",relative:{0:"هن ٽي ماهي",1:"اڳين ٽي ماهي","-1":"پوئين ٽي ماهي"},relativeTime:{future:{one:"{0} ٽي ماهي ۾",other:"{0} ٽي ماهي ۾"},past:{one:"{0} ٽي ماهي پهرين",other:"{0} ٽي ماهي پهرين"}}},"quarter-short":{displayName:"ٽي ماهي",relative:{0:"هن ٽي ماهي",1:"اڳين ٽي ماهي","-1":"پوئين ٽي ماهي"},relativeTime:{future:{one:"{0} ٽي ماهي ۾",other:"{0} ٽي ماهي ۾"},past:{one:"{0} ٽي ماهي پهرين",other:"{0} ٽي ماهي پهرين"}}},"quarter-narrow":{displayName:"ٽي ماهي",relative:{0:"هن ٽي ماهي",1:"اڳين ٽي ماهي","-1":"پوئين ٽي ماهي"},relativeTime:{future:{one:"{0} ٽي ماهي ۾",other:"{0} ٽي ماهي ۾"},past:{one:"{0} ٽي ماهي پهرين",other:"{0} ٽي ماهي پهرين"}}},month:{displayName:"مهينو",relative:{0:"هن مهيني",1:"اڳين مهيني","-1":"پوئين مهيني"},relativeTime:{future:{one:"{0} مهينن ۾",other:"{0} مهينن ۾"},past:{one:"{0} مهينا پهرين",other:"{0} مهينا پهرين"}}},"month-short":{displayName:"مهينو",relative:{0:"هن مهيني",1:"اڳين مهيني","-1":"پوئين مهيني"},relativeTime:{future:{one:"{0} مهينن ۾",other:"{0} مهينن ۾"},past:{one:"{0} مهينا پهرين",other:"{0} مهينا پهرين"}}},"month-narrow":{displayName:"مهينو",relative:{0:"هن مهيني",1:"اڳين مهيني","-1":"پوئين مهيني"},relativeTime:{future:{one:"{0} مهينن ۾",other:"{0} مهينن ۾"},past:{one:"{0} مهينا پهرين",other:"{0} مهينا پهرين"}}},week:{displayName:"هفتو",relative:{0:"هن هفتي",1:"اڳين هفتي","-1":"پوئين هفتي"},relativeTime:{future:{one:"{0} هفتن ۾",other:"{0} هفتن ۾"},past:{one:"{0} هفتا پهرين",other:"{0} هفتا پهرين"}},relativePeriod:"{0} جي هفتي"},"week-short":{displayName:"هفتو",relative:{0:"هن هفتي",1:"اڳين هفتي","-1":"پوئين هفتي"},relativeTime:{future:{one:"{0} هفتن ۾",other:"{0} هفتن ۾"},past:{one:"{0} هفتا پهرين",other:"{0} هفتا پهرين"}},relativePeriod:"{0} جي هفتي"},"week-narrow":{displayName:"هفتو",relative:{0:"هن هفتي",1:"اڳين هفتي","-1":"پوئين هفتي"},relativeTime:{future:{one:"{0} هفتن ۾",other:"{0} هفتن ۾"},past:{one:"{0} هفتا پهرين",other:"{0} هفتا پهرين"}},relativePeriod:"{0} جي هفتي"},day:{displayName:"ڏينهن",relative:{0:"اڄ",1:"سڀاڻي","-1":"ڪل"},relativeTime:{future:{one:"{0} ڏينهن ۾",other:"{0} ڏينهن ۾"},past:{one:"{0} ڏينهن پهرين",other:"{0} ڏينهن پهرين"}}},"day-short":{displayName:"ڏينهن",relative:{0:"اڄ",1:"سڀاڻي","-1":"ڪل"},relativeTime:{future:{one:"{0} ڏينهن ۾",other:"{0} ڏينهن ۾"},past:{one:"{0} ڏينهن پهرين",other:"{0} ڏينهن پهرين"}}},"day-narrow":{displayName:"ڏينهن",relative:{0:"اڄ",1:"سڀاڻي","-1":"ڪل"},relativeTime:{future:{one:"{0} ڏينهن ۾",other:"{0} ڏينهن ۾"},past:{one:"{0} ڏينهن پهرين",other:"{0} ڏينهن پهرين"}}},hour:{displayName:"ڪلاڪ",relative:{0:"هن ڪلڪ"},relativeTime:{future:{one:"{0} ڪلاڪ ۾",other:"{0} ڪلاڪ ۾"},past:{one:"{0} ڪلاڪ پهرين",other:"{0} ڪلاڪ پهرين"}}},"hour-short":{displayName:"ڪلاڪ",relative:{0:"هن ڪلڪ"},relativeTime:{future:{one:"{0} ڪلاڪ ۾",other:"{0} ڪلاڪ ۾"},past:{one:"{0} ڪلاڪ پهرين",other:"{0} ڪلاڪ پهرين"}}},"hour-narrow":{displayName:"ڪلاڪ",relative:{0:"هن ڪلڪ"},relativeTime:{future:{one:"{0} ڪلاڪ ۾",other:"{0} ڪلاڪ ۾"},past:{one:"{0} ڪلاڪ پهرين",other:"{0} ڪلاڪ پهرين"}}},minute:{displayName:"منٽ",relative:{0:"هن منٽ"},relativeTime:{future:{one:"{0} منٽن ۾",other:"+{0} min"},past:{one:"{0} منٽ پهرين",other:"{0} منٽ پهرين"}}},"minute-short":{displayName:"منٽ",relative:{0:"هن منٽ"},relativeTime:{future:{one:"{0} منٽن ۾",other:"{0} منٽن ۾"},past:{one:"{0} منٽ پهرين",other:"{0} منٽ پهرين"}}},"minute-narrow":{displayName:"منٽ",relative:{0:"هن منٽ"},relativeTime:{future:{one:"{0} منٽن ۾",other:"{0} منٽن ۾"},past:{one:"{0} منٽ پهرين",other:"{0} منٽ پهرين"}}},second:{displayName:"سيڪنڊ",relative:{0:"هاڻي"},relativeTime:{future:{one:"{0} سيڪنڊن ۾",other:"{0} سيڪنڊن ۾"},past:{one:"{0} سيڪنڊ پهرين",other:"{0} سيڪنڊ پهرين"}}},"second-short":{displayName:"سيڪنڊ",relative:{0:"هاڻي"},relativeTime:{future:{one:"{0} سيڪنڊن ۾",other:"{0} سيڪنڊن ۾"},past:{one:"{0} سيڪنڊ پهرين",other:"{0} سيڪنڊ پهرين"}}},"second-narrow":{displayName:"سيڪنڊ",relative:{0:"هاڻي"},relativeTime:{future:{one:"{0} سيڪنڊن ۾",other:"{0} سيڪنڊن ۾"},past:{one:"{0} سيڪنڊ پهرين",other:"{0} سيڪنڊ پهرين"}}}}})}}]);
//# sourceMappingURL=160.aaedf07e1a1c0392f425.index.js.map