{% extends "richie/fullwidth.html" %}
{% load cms_tags i18n %}

{% block content %}
<div class="blogpost-glimpse-list">
  <h1 class="blogpost-glimpse-list__title">{{ current_page.get_title }}</h1>

  {% for page in current_page.get_child_pages %}
    {% if page.blogpost %}
      {% include "courses/cms/fragment_blogpost_glimpse.html" with blogpost=page.blogpost %}
    {% endif %}
  {% empty %}
    <p class="blogpost-glimpse blogpost-glimpse--empty">
    {% trans "No associated blogposts" %}
    </p>
  {% endfor %}
</div>
{% endblock content %}
