(window.webpackJsonp=window.webpackJsonp||[]).push([[5],{130:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"as",fields:{year:{displayName:"বছৰ",relative:{0:"এই বছৰ",1:"অহা বছৰ","-1":"যোৱা বছৰ"},relativeTime:{future:{one:"{0} বছৰত",other:"{0} বছৰত"},past:{one:"{0} বছৰৰ পূৰ্বে",other:"{0} বছৰৰ পূৰ্বে"}}},"year-short":{displayName:"বছৰ",relative:{0:"এই বছৰ",1:"অহা বছৰ","-1":"যোৱা বছৰ"},relativeTime:{future:{one:"{0} বছৰত",other:"{0} বছৰত"},past:{one:"{0} বছৰৰ পূৰ্বে",other:"{0} বছৰৰ পূৰ্বে"}}},"year-narrow":{displayName:"বছৰ",relative:{0:"এই বছৰ",1:"অহা বছৰ","-1":"যোৱা বছৰ"},relativeTime:{future:{one:"{0} বছৰত",other:"{0} বছৰত"},past:{one:"{0} বছৰৰ পূৰ্বে",other:"{0} বছৰৰ পূৰ্বে"}}},quarter:{displayName:"তিনি মাহ",relative:{0:"এই তিনি মাহ",1:"অহা তিনি মাহ","-1":"যোৱা তিনি মাহ"},relativeTime:{future:{one:"{0} তিনি মাহত",other:"{0} তিনি মাহত"},past:{one:"{0} তিনি মাহ পূৰ্বে",other:"{0} তিনি মাহ পূৰ্বে"}}},"quarter-short":{displayName:"তিনি মাহ",relative:{0:"এই তিনি মাহ",1:"অহা তিনি মাহ","-1":"যোৱা তিনি মাহ"},relativeTime:{future:{one:"{0} তিনি মাহত",other:"{0} তিনি মাহত"},past:{one:"{0} তিনি মাহ পূৰ্বে",other:"{0} তিনি মাহ পূৰ্বে"}}},"quarter-narrow":{displayName:"তিনি মাহ",relative:{0:"এই তিনি মাহ",1:"অহা তিনি মাহ","-1":"যোৱা তিনি মাহ"},relativeTime:{future:{one:"{0} তিনি মাহত",other:"{0} তিনি মাহত"},past:{one:"{0} তিনি মাহ পূৰ্বে",other:"{0} তিনি মাহ পূৰ্বে"}}},month:{displayName:"মাহ",relative:{0:"এই মাহ",1:"অহা মাহ","-1":"যোৱা মাহ"},relativeTime:{future:{one:"{0} মাহত",other:"{0} মাহত"},past:{one:"{0} মাহ পূৰ্বে",other:"{0} মাহ পূৰ্বে"}}},"month-short":{displayName:"মাহ",relative:{0:"এই মাহ",1:"অহা মাহ","-1":"যোৱা মাহ"},relativeTime:{future:{one:"{0} মাহত",other:"{0} মাহত"},past:{one:"{0} মাহ পূৰ্বে",other:"{0} মাহ পূৰ্বে"}}},"month-narrow":{displayName:"মাহ",relative:{0:"এই মাহ",1:"অহা মাহ","-1":"যোৱা মাহ"},relativeTime:{future:{one:"{0} মাহত",other:"{0} মাহত"},past:{one:"{0} মাহ পূৰ্বে",other:"{0} মাহ পূৰ্বে"}}},week:{displayName:"সপ্তাহ",relative:{0:"এই সপ্তাহ",1:"অহা সপ্তাহ","-1":"যোৱা সপ্তাহ"},relativeTime:{future:{one:"{0} সপ্তাহত",other:"{0} সপ্তাহত"},past:{one:"{0} সপ্তাহ পূৰ্বে",other:"{0} সপ্তাহ পূৰ্বে"}},relativePeriod:"{0}ৰ সপ্তাহ"},"week-short":{displayName:"সপ্তাহ",relative:{0:"এই সপ্তাহ",1:"অহা সপ্তাহ","-1":"যোৱা সপ্তাহ"},relativeTime:{future:{one:"{0} সপ্তাহত",other:"{0} সপ্তাহত"},past:{one:"{0} সপ্তাহ পূৰ্বে",other:"{0} সপ্তাহ পূৰ্বে"}},relativePeriod:"{0}ৰ সপ্তাহ"},"week-narrow":{displayName:"সপ্তাহ",relative:{0:"এই সপ্তাহ",1:"অহা সপ্তাহ","-1":"যোৱা সপ্তাহ"},relativeTime:{future:{one:"{0} সপ্তাহত",other:"{0} সপ্তাহত"},past:{one:"{0} সপ্তাহ পূৰ্বে",other:"{0} সপ্তাহ পূৰ্বে"}},relativePeriod:"{0}ৰ সপ্তাহ"},day:{displayName:"দিন",relative:{0:"আজি",1:"কাইলৈ",2:"পৰহিলৈ","-2":"পৰহি","-1":"কালি"},relativeTime:{future:{one:"{0} দিনত",other:"{0} দিনত"},past:{one:"{0} দিন পূৰ্বে",other:"{0} দিন পূৰ্বে"}}},"day-short":{displayName:"দিন",relative:{0:"আজি",1:"কাইলৈ",2:"পৰহিলৈ","-2":"পৰহি","-1":"কালি"},relativeTime:{future:{one:"{0} দিনত",other:"{0} দিনত"},past:{one:"{0} দিন পূৰ্বে",other:"{0} দিন পূৰ্বে"}}},"day-narrow":{displayName:"দিন",relative:{0:"আজি",1:"কাইলৈ",2:"পৰহিলৈ","-2":"পৰহি","-1":"কালি"},relativeTime:{future:{one:"{0} দিনত",other:"{0} দিনত"},past:{one:"{0} দিন পূৰ্বে",other:"{0} দিন পূৰ্বে"}}},hour:{displayName:"ঘণ্টা",relative:{0:"এইটো ঘণ্টাত"},relativeTime:{future:{one:"{0} ঘণ্টাত",other:"{0} ঘণ্টাত"},past:{one:"{0} ঘণ্টা পূৰ্বে",other:"{0} ঘণ্টা পূৰ্বে"}}},"hour-short":{displayName:"ঘণ্টা",relative:{0:"এইটো ঘণ্টাত"},relativeTime:{future:{one:"{0} ঘণ্টাত",other:"{0} ঘণ্টাত"},past:{one:"{0} ঘণ্টা পূৰ্বে",other:"{0} ঘণ্টা পূৰ্বে"}}},"hour-narrow":{displayName:"ঘণ্টা",relative:{0:"এইটো ঘণ্টাত"},relativeTime:{future:{one:"{0} ঘণ্টাত",other:"{0} ঘণ্টাত"},past:{one:"{0} ঘণ্টা পূৰ্বে",other:"{0} ঘণ্টা পূৰ্বে"}}},minute:{displayName:"মিনিট",relative:{0:"এইটো মিনিটত"},relativeTime:{future:{one:"{0} মিনিটত",other:"{0} মিনিটত"},past:{one:"{0} মিনিট পূৰ্বে",other:"{0} মিনিট পূৰ্বে"}}},"minute-short":{displayName:"মিনিট",relative:{0:"এইটো মিনিটত"},relativeTime:{future:{one:"{0} মিনিটত",other:"{0} মিনিটত"},past:{one:"{0} মিনিট পূৰ্বে",other:"{0} মিনিট পূৰ্বে"}}},"minute-narrow":{displayName:"মিনিট",relative:{0:"এইটো মিনিটত"},relativeTime:{future:{one:"{0} মিনিটত",other:"{0} মিনিটত"},past:{one:"{0} মিনিট পূৰ্বে",other:"{0} মিনিট পূৰ্বে"}}},second:{displayName:"ছেকেণ্ড",relative:{0:"এতিয়া"},relativeTime:{future:{one:"{0} ছেকেণ্ডত",other:"{0} ছেকেণ্ডত"},past:{one:"{0} ছেকেণ্ড পূৰ্বে",other:"{0} ছেকেণ্ড পূৰ্বে"}}},"second-short":{displayName:"ছেকেণ্ড",relative:{0:"এতিয়া"},relativeTime:{future:{one:"{0} ছেকেণ্ডত",other:"{0} ছেকেণ্ডত"},past:{one:"{0} ছেকেণ্ড পূৰ্বে",other:"{0} ছেকেণ্ড পূৰ্বে"}}},"second-narrow":{displayName:"ছেকেণ্ড",relative:{0:"এতিয়া"},relativeTime:{future:{one:"{0} ছেকেণ্ডত",other:"{0} ছেকেণ্ডত"},past:{one:"{0} ছেকেণ্ড পূৰ্বে",other:"{0} ছেকেণ্ড পূৰ্বে"}}}}})}}]);
//# sourceMappingURL=5.aaedf07e1a1c0392f425.index.js.map