(window.webpackJsonp=window.webpackJsonp||[]).push([[128],{253:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"my",fields:{year:{displayName:"နှစ်",relative:{0:"ယခုနှစ်",1:"လာမည့်နှစ်","-1":"ယမန်နှစ်"},relativeTime:{future:{other:"{0} နှစ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} နှစ်"}}},"year-short":{displayName:"နှစ်",relative:{0:"ယခုနှစ်",1:"လာမည့်နှစ်","-1":"ယမန်နှစ်"},relativeTime:{future:{other:"{0} နှစ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} နှစ်"}}},"year-narrow":{displayName:"နှစ်",relative:{0:"ယခုနှစ်",1:"လာမည့်နှစ်","-1":"ယမန်နှစ်"},relativeTime:{future:{other:"{0} နှစ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} နှစ်"}}},quarter:{displayName:"သုံးလပတ်",relative:{0:"ယခု သုံးလပတ်",1:"လာမည့် သုံးလပတ်","-1":"ပြီးခဲ့သည့် သုံးလပတ်"},relativeTime:{future:{other:"သုံးလပတ်ကာလ {0} အတွင်း"},past:{other:"ပြီးခဲ့သည့် သုံးလပတ်ကာလ {0} ခုအတွင်း"}}},"quarter-short":{displayName:"သုံးလပတ်",relative:{0:"ယခုသုံးလပတ်",1:"နောက်လာမည့်သုံးလပတ်","-1":"ပြီးခဲ့သောသုံးလပတ်"},relativeTime:{future:{other:"သုံးလပတ်ကာလ {0} ခုအတွင်း"},past:{other:"ပြီးခဲ့သည့် သုံးလပတ်ကာလ {0} ခုအတွင်း"}}},"quarter-narrow":{displayName:"သုံးလပတ်",relative:{0:"ယခုသုံးလပတ်",1:"နောက်လာမည့်သုံးလပတ်","-1":"ပြီးခဲ့သောသုံးလပတ်"},relativeTime:{future:{other:"သုံးလပတ်ကာလ {0} ခုအတွင်း"},past:{other:"ပြီးခဲ့သည့် သုံးလပတ်ကာလ {0} ခုအတွင်း"}}},month:{displayName:"လ",relative:{0:"ယခုလ",1:"လာမည့်လ","-1":"ပြီးခဲ့သည့်လ"},relativeTime:{future:{other:"{0} လအတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} လ"}}},"month-short":{displayName:"လ",relative:{0:"ယခုလ",1:"လာမည့်လ","-1":"ပြီးခဲ့သည့်လ"},relativeTime:{future:{other:"{0} လအတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} လ"}}},"month-narrow":{displayName:"လ",relative:{0:"ယခုလ",1:"လာမည့်လ","-1":"ပြီးခဲ့သည့်လ"},relativeTime:{future:{other:"{0} လအတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} လ"}}},week:{displayName:"ပတ်",relative:{0:"ယခု သီတင်းပတ်",1:"လာမည့် သီတင်းပတ်","-1":"ပြီးခဲ့သည့် သီတင်းပတ်"},relativeTime:{future:{other:"{0} ပတ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} ပတ်"}},relativePeriod:"{0} ပတ်မြောက် သီတင်းပတ်"},"week-short":{displayName:"ပတ်",relative:{0:"ယခု သီတင်းပတ်",1:"လာမည့် သီတင်းပတ်","-1":"ပြီးခဲ့သည့် သီတင်းပတ်"},relativeTime:{future:{other:"{0} ပတ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} ပတ်"}},relativePeriod:"{0} ပတ်မြောက် သီတင်းပတ်"},"week-narrow":{displayName:"ပတ်",relative:{0:"ယခု သီတင်းပတ်",1:"လာမည့် သီတင်းပတ်","-1":"ပြီးခဲ့သည့် သီတင်းပတ်"},relativeTime:{future:{other:"{0} ပတ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} ပတ်"}},relativePeriod:"{0} ပတ်မြောက် သီတင်းပတ်"},day:{displayName:"ရက်",relative:{0:"ယနေ့",1:"မနက်ဖြန်",2:"သန်ဘက်ခါ","-2":"တစ်နေ့က","-1":"မနေ့က"},relativeTime:{future:{other:"{0} ရက်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} ရက်"}}},"day-short":{displayName:"ရက်",relative:{0:"ယနေ့",1:"မနက်ဖြန်",2:"သန်ဘက်ခါ","-2":"တစ်နေ့က","-1":"မနေ့က"},relativeTime:{future:{other:"{0} ရက်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} ရက်"}}},"day-narrow":{displayName:"ရက်",relative:{0:"ယနေ့",1:"မနက်ဖြန်",2:"သန်ဘက်ခါ","-2":"တစ်နေ့က","-1":"မနေ့က"},relativeTime:{future:{other:"{0} ရက်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} ရက်"}}},hour:{displayName:"နာရီ",relative:{0:"ဤအချိန်"},relativeTime:{future:{other:"{0} နာရီအတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} နာရီ"}}},"hour-short":{displayName:"နာရီ",relative:{0:"ဤအချိန်"},relativeTime:{future:{other:"{0} နာရီအတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} နာရီ"}}},"hour-narrow":{displayName:"နာရီ",relative:{0:"ဤအချိန်"},relativeTime:{future:{other:"{0} နာရီအတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} နာရီ"}}},minute:{displayName:"မိနစ်",relative:{0:"ဤမိနစ်"},relativeTime:{future:{other:"{0} မိနစ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} မိနစ်"}}},"minute-short":{displayName:"မိနစ်",relative:{0:"ဤမိနစ်"},relativeTime:{future:{other:"{0} မိနစ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} မိနစ်"}}},"minute-narrow":{displayName:"မိနစ်",relative:{0:"ဤမိနစ်"},relativeTime:{future:{other:"{0} မိနစ်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} မိနစ်"}}},second:{displayName:"စက္ကန့်",relative:{0:"ယခု"},relativeTime:{future:{other:"{0} စက္ကန့်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} စက္ကန့်"}}},"second-short":{displayName:"စက္ကန့်",relative:{0:"ယခု"},relativeTime:{future:{other:"{0} စက္ကန့်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} စက္ကန့်"}}},"second-narrow":{displayName:"စက္ကန့်",relative:{0:"ယခု"},relativeTime:{future:{other:"{0} စက္ကန့်အတွင်း"},past:{other:"ပြီးခဲ့သည့် {0} စက္ကန့်"}}}}})}}]);
//# sourceMappingURL=128.aaedf07e1a1c0392f425.index.js.map