(window.webpackJsonp=window.webpackJsonp||[]).push([[182],{307:function(e,a){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"tk",fields:{year:{displayName:"ýyl",relative:{0:"şu ýyl",1:"indiki ýyl","-1":"geçen ýyl"},relativeTime:{future:{one:"{0} ýyldan",other:"{0} ýyldan"},past:{one:"{0} ýyl öň",other:"{0} ýyl öň"}}},"year-short":{displayName:"ý.",relative:{0:"şu ýyl",1:"indiki ýyl","-1":"geçen ýyl"},relativeTime:{future:{one:"{0} ý-dan",other:"{0} ý-dan"},past:{one:"{0} ý. öň",other:"{0} ý. öň"}}},"year-narrow":{displayName:"ý.",relative:{0:"şu ýyl",1:"indiki ýyl","-1":"geçen ýyl"},relativeTime:{future:{one:"{0} ý-dan",other:"{0} ý-dan"},past:{one:"{0} ý. öň",other:"{0} ý. öň"}}},quarter:{displayName:"çärýek",relative:{0:"şu çärýek",1:"indiki çärýek","-1":"geçen çärýek"},relativeTime:{future:{one:"{0} çärýekden",other:"{0} çärýekden"},past:{one:"{0} çärýek öň",other:"{0} çärýek öň"}}},"quarter-short":{displayName:"çär.",relative:{0:"şu çärýek",1:"indiki çärýek","-1":"geçen çärýek"},relativeTime:{future:{one:"{0} çär-den",other:"{0} çär-den"},past:{one:"{0} çär. öň",other:"{0} çär. öň"}}},"quarter-narrow":{displayName:"çär.",relative:{0:"şu çärýek",1:"indiki çärýek","-1":"geçen çärýek"},relativeTime:{future:{one:"{0} ç-den",other:"{0} ç-den"},past:{one:"{0} ç. öň",other:"{0} ç. öň"}}},month:{displayName:"aý",relative:{0:"şu aý",1:"indiki aý","-1":"geçen aý"},relativeTime:{future:{one:"{0} aýdan",other:"{0} aýdan"},past:{one:"{0} aý öň",other:"{0} aý öň"}}},"month-short":{displayName:"aý",relative:{0:"şu aý",1:"indiki aý","-1":"geçen aý"},relativeTime:{future:{one:"{0} aýdan",other:"{0} aýdan"},past:{one:"{0} aý öň",other:"{0} aý öň"}}},"month-narrow":{displayName:"aý",relative:{0:"şu aý",1:"indiki aý","-1":"geçen aý"},relativeTime:{future:{one:"{0} aýdan",other:"{0} aýdan"},past:{one:"{0} aý öň",other:"{0} aý öň"}}},week:{displayName:"hepde",relative:{0:"şu hepde",1:"indiki hepde","-1":"geçen hepde"},relativeTime:{future:{one:"{0} hepdeden",other:"{0} hepdeden"},past:{one:"{0} hepde öň",other:"{0} hepde öň"}},relativePeriod:"{0} hepdesi"},"week-short":{displayName:"hep.",relative:{0:"şu hepde",1:"indiki hepde","-1":"geçen hepde"},relativeTime:{future:{one:"{0} hep-den",other:"{0} hep-den"},past:{one:"{0} hep. öň",other:"{0} hep. öň"}},relativePeriod:"{0} hepdesi"},"week-narrow":{displayName:"hep.",relative:{0:"şu hepde",1:"indiki hepde","-1":"geçen hepde"},relativeTime:{future:{one:"{0} h-den",other:"{0} h-den"},past:{one:"{0} h. öň",other:"{0} h. öň"}},relativePeriod:"{0} hepdesi"},day:{displayName:"gün",relative:{0:"şu gün",1:"ertir","-1":"düýn"},relativeTime:{future:{one:"{0} günden",other:"{0} günden"},past:{one:"{0} gün öň",other:"{0} gün öň"}}},"day-short":{displayName:"gün",relative:{0:"şu gün",1:"ertir","-1":"düýn"},relativeTime:{future:{one:"{0} g-den",other:"{0} g-den"},past:{one:"{0} g. öň",other:"{0} g. öň"}}},"day-narrow":{displayName:"gün",relative:{0:"şu gün",1:"ertir","-1":"düýn"},relativeTime:{future:{one:"{0} g-den",other:"{0} g-den"},past:{one:"{0} g. öň",other:"{0} g. öň"}}},hour:{displayName:"sagat",relative:{0:"şu sagat"},relativeTime:{future:{one:"{0} sagatdan",other:"{0} sagatdan"},past:{one:"{0} sagat öň",other:"{0} sagat öň"}}},"hour-short":{displayName:"sag.",relative:{0:"şu sagat"},relativeTime:{future:{one:"{0} sag-dan",other:"{0} sag-dan"},past:{one:"{0} sag. öň",other:"{0} sag. öň"}}},"hour-narrow":{displayName:"sag.",relative:{0:"şu sagat"},relativeTime:{future:{one:"{0} sag-dan",other:"{0} sag-dan"},past:{one:"{0} sag. öň",other:"{0} sag. öň"}}},minute:{displayName:"minut",relative:{0:"şu minut"},relativeTime:{future:{one:"{0} minutdan",other:"{0} minutdan"},past:{one:"{0} minut öň",other:"{0} minut öň"}}},"minute-short":{displayName:"min.",relative:{0:"şu minut"},relativeTime:{future:{one:"{0} min-dan",other:"{0} min-dan"},past:{one:"{0} min. öň",other:"{0} min. öň"}}},"minute-narrow":{displayName:"min.",relative:{0:"şu minut"},relativeTime:{future:{one:"{0} min-dan",other:"{0} min-dan"},past:{one:"{0} min. öň",other:"{0} min. öň"}}},second:{displayName:"sekunt",relative:{0:"häzir"},relativeTime:{future:{one:"{0} sekuntdan",other:"{0} sekuntdan"},past:{one:"{0} sekunt öň",other:"{0} sekunt öň"}}},"second-short":{displayName:"sek.",relative:{0:"häzir"},relativeTime:{future:{one:"{0} sek-dan",other:"{0} sek-dan"},past:{one:"{0} sek. öň",other:"{0} sek. öň"}}},"second-narrow":{displayName:"sek.",relative:{0:"häzir"},relativeTime:{future:{one:"{0} sek-dan",other:"{0} sek-dan"},past:{one:"{0} sek. öň",other:"{0} sek. öň"}}}}})}}]);
//# sourceMappingURL=182.aaedf07e1a1c0392f425.index.js.map