(window.webpackJsonp=window.webpackJsonp||[]).push([[107],{232:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"lo",fields:{year:{displayName:"ປີ",relative:{0:"ປີນີ້",1:"ປີໜ້າ","-1":"ປີກາຍ"},relativeTime:{future:{other:"ໃນອີກ {0} ປີ"},past:{other:"{0} ປີກ່ອນ"}}},"year-short":{displayName:"ປີ",relative:{0:"ປີນີ້",1:"ປີໜ້າ","-1":"ປີກາຍ"},relativeTime:{future:{other:"ໃນອີກ {0} ປີ"},past:{other:"{0} ປີກ່ອນ"}}},"year-narrow":{displayName:"ປີ",relative:{0:"ປີນີ້",1:"ປີໜ້າ","-1":"ປີກາຍ"},relativeTime:{future:{other:"ໃນອີກ {0} ປີ"},past:{other:"{0} ປີກ່ອນ"}}},quarter:{displayName:"ໄຕຣມາດ",relative:{0:"ໄຕຣມາດນີ້",1:"ໄຕຣມາດໜ້າ","-1":"ໄຕຣມາດກ່ອນໜ້າ"},relativeTime:{future:{other:"ໃນອີກ {0} ໄຕຣມາດ"},past:{other:"{0} ໄຕຣມາດກ່ອນ"}}},"quarter-short":{displayName:"ຕມ.",relative:{0:"ໄຕຣມາດນີ້",1:"ໄຕຣມາດໜ້າ","-1":"ໄຕຣມາດກ່ອນໜ້າ"},relativeTime:{future:{other:"ໃນ {0} ຕມ."},past:{other:"{0} ຕມ. ກ່ອນ"}}},"quarter-narrow":{displayName:"ຕມ.",relative:{0:"ໄຕຣມາດນີ້",1:"ໄຕຣມາດໜ້າ","-1":"ໄຕຣມາດກ່ອນໜ້າ"},relativeTime:{future:{other:"ໃນ {0} ຕມ."},past:{other:"{0} ຕມ. ກ່ອນ"}}},month:{displayName:"ເດືອນ",relative:{0:"ເດືອນນີ້",1:"ເດືອນໜ້າ","-1":"ເດືອນແລ້ວ"},relativeTime:{future:{other:"ໃນອີກ {0} ເດືອນ"},past:{other:"{0} ເດືອນກ່ອນ"}}},"month-short":{displayName:"ດ.",relative:{0:"ເດືອນນີ້",1:"ເດືອນໜ້າ","-1":"ເດືອນແລ້ວ"},relativeTime:{future:{other:"ໃນອີກ {0} ດ."},past:{other:"{0} ດ. ກ່ອນ"}}},"month-narrow":{displayName:"ດ.",relative:{0:"ເດືອນນີ້",1:"ເດືອນໜ້າ","-1":"ເດືອນແລ້ວ"},relativeTime:{future:{other:"ໃນອີກ {0} ດ."},past:{other:"{0} ດ. ກ່ອນ"}}},week:{displayName:"ອາທິດ",relative:{0:"ອາທິດນີ້",1:"ອາທິດໜ້າ","-1":"ອາທິດແລ້ວ"},relativeTime:{future:{other:"ໃນອີກ {0} ອາທິດ"},past:{other:"{0} ອາທິດກ່ອນ"}},relativePeriod:"ອາທິດທີ {0}"},"week-short":{displayName:"ອ.",relative:{0:"ອາທິດນີ້",1:"ອາທິດໜ້າ","-1":"ອາທິດແລ້ວ"},relativeTime:{future:{other:"ໃນອີກ {0} ອທ."},past:{other:"{0} ອທ. ກ່ອນ"}},relativePeriod:"ອາທິດທີ {0}"},"week-narrow":{displayName:"ອ.",relative:{0:"ອາທິດນີ້",1:"ອາທິດໜ້າ","-1":"ອາທິດແລ້ວ"},relativeTime:{future:{other:"ໃນອີກ {0} ອທ."},past:{other:"{0} ອທ. ກ່ອນ"}},relativePeriod:"ອາທິດທີ {0}"},day:{displayName:"ມື້",relative:{0:"ມື້ນີ້",1:"ມື້ອື່ນ",2:"ມື້ຮື","-2":"ມື້ກ່ອນ","-1":"ມື້ວານ"},relativeTime:{future:{other:"ໃນອີກ {0} ມື້"},past:{other:"{0} ມື້ກ່ອນ"}}},"day-short":{displayName:"ມື້",relative:{0:"ມື້ນີ້",1:"ມື້ອື່ນ",2:"ມື້ຮື","-2":"ມື້ກ່ອນ","-1":"ມື້ວານ"},relativeTime:{future:{other:"ໃນອີກ {0} ມື້"},past:{other:"{0} ມື້ກ່ອນ"}}},"day-narrow":{displayName:"ມື້",relative:{0:"ມື້ນີ້",1:"ມື້ອື່ນ",2:"ມື້ຮື","-2":"ມື້ກ່ອນ","-1":"ມື້ວານ"},relativeTime:{future:{other:"ໃນອີກ {0} ມື້"},past:{other:"{0} ມື້ກ່ອນ"}}},hour:{displayName:"ຊົ່ວໂມງ",relative:{0:"ຊົ່ວໂມງນີ້"},relativeTime:{future:{other:"ໃນອີກ {0} ຊົ່ວໂມງ"},past:{other:"{0} ຊົ່ວໂມງກ່ອນ"}}},"hour-short":{displayName:"ຊມ.",relative:{0:"ຊົ່ວໂມງນີ້"},relativeTime:{future:{other:"ໃນອີກ {0} ຊມ."},past:{other:"{0} ຊມ. ກ່ອນ"}}},"hour-narrow":{displayName:"ຊມ.",relative:{0:"ຊົ່ວໂມງນີ້"},relativeTime:{future:{other:"ໃນອີກ {0} ຊມ."},past:{other:"{0} ຊມ. ກ່ອນ"}}},minute:{displayName:"ນາທີ",relative:{0:"ນາທີນີ້"},relativeTime:{future:{other:"{0} ໃນອີກ 0 ນາທີ"},past:{other:"{0} ນາທີກ່ອນ"}}},"minute-short":{displayName:"ນທ.",relative:{0:"ນາທີນີ້"},relativeTime:{future:{other:"ໃນ {0} ນທ."},past:{other:"{0} ນທ. ກ່ອນ"}}},"minute-narrow":{displayName:"ນທ.",relative:{0:"ນາທີນີ້"},relativeTime:{future:{other:"ໃນ {0} ນທ."},past:{other:"{0} ນທ. ກ່ອນ"}}},second:{displayName:"ວິນາທີ",relative:{0:"ຕອນນີ້"},relativeTime:{future:{other:"ໃນອີກ {0} ວິນາທີ"},past:{other:"{0} ວິນາທີກ່ອນ"}}},"second-short":{displayName:"ວິ.",relative:{0:"ຕອນນີ້"},relativeTime:{future:{other:"ໃນ {0} ວິ."},past:{other:"{0} ວິ. ກ່ອນ"}}},"second-narrow":{displayName:"ວິ.",relative:{0:"ຕອນນີ້"},relativeTime:{future:{other:"ໃນ {0} ວິ."},past:{other:"{0} ວິ. ກ່ອນ"}}}}})}}]);
//# sourceMappingURL=107.aaedf07e1a1c0392f425.index.js.map