{% extends "richie/base.html" %}
{% load cms_tags %}

{% block title %}
    {% page_attribute "page_title" %}
{% endblock title %}

{% block content %}
    {% placeholder "maincontent" %}
{% endblock content %}
