{% extends "richie/base.html" %}
{% load cms_tags %}

{% block title %}
    {% page_attribute "page_title" %}
{% endblock title %}

{% block content %}
<div class="single-column">

    <h1 class="single-column__title">{{ current_page.get_title }}</h1>

    {% block column %}
        {% with header_level=2 %}
            {% placeholder "maincontent" %}
        {% endwith %}
    {% endblock column %}
</div>
{% endblock content %}
