{% extends "richie/base.html" %}
{% load cms_tags i18n search_tags %}
{% get_current_language as LANGUAGE_CODE %}

{% block meta %}
  {% if CDN_DOMAIN %}
  <meta name="public-path" value="{{ CDN_DOMAIN }}" />
  {% endif %}
{% endblock meta %}

{% block title %}{% page_attribute "page_title" %}{% endblock title %}

{# Enable flex on the `.body-content` so children can grow to occupy the available vertical space #}
{% block bodycontent_classes %}body-content--flex-mode{% endblock bodycontent_classes %}

{% block content %}
  <div class="search-template">
    <div class="search-template__content">
      {% with header_level=2 %}
        {% placeholder "content" %}
      {% endwith %}
      <div
        class="fun-react fun-react--search"
        data-locale="{{ LANGUAGE_CODE|react_locale }}"
        data-props='{"pageTitle": "{% page_attribute "page_title" %}"}'
      ></div>
    </div>
  </div>
{% endblock content %}
