(window.webpackJsonp=window.webpackJsonp||[]).push([[183],{308:function(e,i){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"to",fields:{year:{displayName:"taʻu",relative:{0:"taʻú ni",1:"taʻu kahaʻu","-1":"taʻu kuoʻosi"},relativeTime:{future:{other:"ʻi he taʻu ʻe {0}"},past:{other:"taʻu ʻe {0} kuoʻosi"}}},"year-short":{displayName:"taʻu",relative:{0:"taʻú ni",1:"taʻu kahaʻu","-1":"taʻu kuoʻosi"},relativeTime:{future:{other:"ʻi he taʻu ʻe {0}"},past:{other:"taʻu ʻe {0} kuoʻosi"}}},"year-narrow":{displayName:"taʻu",relative:{0:"taʻú ni",1:"taʻu kahaʻu","-1":"taʻu kuoʻosi"},relativeTime:{future:{other:"ʻi he taʻu ʻe {0}"},past:{other:"taʻu ʻe {0} kuoʻosi"}}},quarter:{displayName:"kuata",relative:{0:"kuata koʻeni",1:"kuata hoko","-1":"kuata kuoʻosi"},relativeTime:{future:{other:"ʻi he kuata ʻe {0}"},past:{other:"kuata ʻe {0} kuoʻosi"}}},"quarter-short":{displayName:"kuata",relative:{0:"kuata koʻeni",1:"kuata hoko","-1":"kuata kuoʻosi"},relativeTime:{future:{other:"ʻi he kuata ʻe {0}"},past:{other:"kuata ʻe {0} kuoʻosi"}}},"quarter-narrow":{displayName:"kuata",relative:{0:"kuata koʻeni",1:"kuata hoko","-1":"kuata kuoʻosi"},relativeTime:{future:{other:"ʻi he kuata ʻe {0}"},past:{other:"kuata ʻe {0} kuoʻosi"}}},month:{displayName:"māhina",relative:{0:"māhiná ni",1:"māhina kahaʻu","-1":"māhina kuoʻosi"},relativeTime:{future:{other:"ʻi he māhina ʻe {0}"},past:{other:"māhina ʻe {0} kuoʻosi"}}},"month-short":{displayName:"māhina",relative:{0:"māhiná ni",1:"māhina kahaʻu","-1":"māhina kuoʻosi"},relativeTime:{future:{other:"ʻi he māhina ʻe {0}"},past:{other:"māhina ʻe {0} kuoʻosi"}}},"month-narrow":{displayName:"māhina",relative:{0:"māhiná ni",1:"māhina kahaʻu","-1":"māhina kuoʻosi"},relativeTime:{future:{other:"ʻi he māhina ʻe {0}"},past:{other:"māhina ʻe {0} kuoʻosi"}}},week:{displayName:"uike",relative:{0:"uiké ni",1:"uike kahaʻu","-1":"uike kuoʻosi"},relativeTime:{future:{other:"ʻi he uike ʻe {0}"},past:{other:"uike ʻe {0} kuoʻosi"}},relativePeriod:"the week of {0}"},"week-short":{displayName:"uike",relative:{0:"uiké ni",1:"uike kahaʻu","-1":"uike kuoʻosi"},relativeTime:{future:{other:"ʻi he uike ʻe {0}"},past:{other:"uike ʻe {0} kuoʻosi"}},relativePeriod:"the week of {0}"},"week-narrow":{displayName:"uike",relative:{0:"uiké ni",1:"uike kahaʻu","-1":"uike kuoʻosi"},relativeTime:{future:{other:"ʻi he uike ʻe {0}"},past:{other:"uike ʻe {0} kuoʻosi"}},relativePeriod:"the week of {0}"},day:{displayName:"ʻaho",relative:{0:"ʻahó ni",1:"ʻapongipongi",2:"ʻahepongipongi","-2":"ʻaneheafi","-1":"ʻaneafi"},relativeTime:{future:{other:"ʻi he ʻaho ʻe {0}"},past:{other:"ʻaho ʻe {0} kuoʻosi"}}},"day-short":{displayName:"ʻaho",relative:{0:"ʻahó ni",1:"ʻapongipongi",2:"ʻahepongipongi","-2":"ʻaneheafi","-1":"ʻaneafi"},relativeTime:{future:{other:"ʻi he ʻaho ʻe {0}"},past:{other:"ʻaho ʻe {0} kuoʻosi"}}},"day-narrow":{displayName:"ʻaho",relative:{0:"ʻahó ni",1:"ʻapongipongi",2:"ʻahepongipongi","-2":"ʻaneheafi","-1":"ʻaneafi"},relativeTime:{future:{other:"ʻi he ʻaho ʻe {0}"},past:{other:"ʻaho ʻe {0} kuoʻosi"}}},hour:{displayName:"houa",relative:{0:"this hour"},relativeTime:{future:{other:"ʻi he houa ʻe {0}"},past:{other:"houa ʻe {0} kuoʻosi"}}},"hour-short":{displayName:"houa",relative:{0:"this hour"},relativeTime:{future:{other:"ʻi he houa ʻe {0}"},past:{other:"houa ʻe {0} kuoʻosi"}}},"hour-narrow":{displayName:"houa",relative:{0:"this hour"},relativeTime:{future:{other:"ʻi he houa ʻe {0}"},past:{other:"houa ʻe {0} kuoʻosi"}}},minute:{displayName:"miniti",relative:{0:"this minute"},relativeTime:{future:{other:"ʻi he miniti ʻe {0}"},past:{other:"miniti ʻe {0} kuoʻosi"}}},"minute-short":{displayName:"miniti",relative:{0:"this minute"},relativeTime:{future:{other:"ʻi he miniti ʻe {0}"},past:{other:"miniti ʻe {0} kuoʻosi"}}},"minute-narrow":{displayName:"miniti",relative:{0:"this minute"},relativeTime:{future:{other:"ʻi he miniti ʻe {0}"},past:{other:"miniti ʻe {0} kuoʻosi"}}},second:{displayName:"sekoni",relative:{0:"taimí ni"},relativeTime:{future:{other:"ʻi he sekoni ʻe {0}"},past:{other:"sekoni ʻe {0} kuoʻosi"}}},"second-short":{displayName:"sekoni",relative:{0:"taimí ni"},relativeTime:{future:{other:"ʻi he sekoni ʻe {0}"},past:{other:"sekoni ʻe {0} kuoʻosi"}}},"second-narrow":{displayName:"sekoni",relative:{0:"taimí ni"},relativeTime:{future:{other:"ʻi he sekoni ʻe {0}"},past:{other:"sekoni ʻe {0} kuoʻosi"}}}}})}}]);
//# sourceMappingURL=183.aaedf07e1a1c0392f425.index.js.map