{% load i18n menu_tags cms_tags%}{% spaceless %}
{% get_available_languages as languages %}
{% get_current_language as LANGUAGE_CODE %}
{% if languages|length > 1 %}
    {% for code, name in languages %}
    {% get_language_info for code as lang %}
    <li class="topbar__menu__list__item topbar__menu__list__item--language topbar__menu__list__item--{{ code }}{% if code == LANGUAGE_CODE %} topbar__menu__list__item--active{% endif %}">
        <a class="topbar__menu__list__item__link" href="{% page_language_url code %}"
        title="{% blocktrans %}Switch to {{ lang.name_translated }}{% endblocktrans %}">
            {{ lang.code|slice:":2" }}
        </a>
    </li>
    {% endfor %}
{% endif %}{% endspaceless %}
