(window.webpackJsonp=window.webpackJsonp||[]).push([[149],{274:function(a,e){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"qu",fields:{year:{displayName:"Year",relative:{0:"kunan wata",1:"hamuq wata","-1":"qayna wata"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},"year-short":{displayName:"Year",relative:{0:"kunan wata",1:"hamuq wata","-1":"qayna wata"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},"year-narrow":{displayName:"Year",relative:{0:"kunan wata",1:"hamuq wata","-1":"qayna wata"},relativeTime:{future:{other:"+{0} y"},past:{other:"-{0} y"}}},quarter:{displayName:"Quarter",relative:{0:"kunan kimsa killa",1:"hamuq kimsa killa","-1":"qayna kimsa killa"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},"quarter-short":{displayName:"Quarter",relative:{0:"kunan kimsa killa",1:"hamuq kimsa killa","-1":"qayna kimsa killa"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},"quarter-narrow":{displayName:"Quarter",relative:{0:"kunan kimsa killa",1:"hamuq kimsa killa","-1":"qayna kimsa killa"},relativeTime:{future:{other:"+{0} Q"},past:{other:"-{0} Q"}}},month:{displayName:"Month",relative:{0:"kunan killa",1:"hamuq killa","-1":"qayna killa"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-short":{displayName:"Month",relative:{0:"kunan killa",1:"hamuq killa","-1":"qayna killa"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},"month-narrow":{displayName:"Month",relative:{0:"kunan killa",1:"hamuq killa","-1":"qayna killa"},relativeTime:{future:{other:"+{0} m"},past:{other:"-{0} m"}}},week:{displayName:"Week",relative:{0:"kunan semana",1:"hamuq semana","-1":"qayna semana"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}},relativePeriod:"{0} semanapi"},"week-short":{displayName:"Week",relative:{0:"kunan semana",1:"hamuq semana","-1":"qayna semana"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}},relativePeriod:"{0} semanapi"},"week-narrow":{displayName:"Week",relative:{0:"kunan semana",1:"hamuq semana","-1":"qayna semana"},relativeTime:{future:{other:"+{0} w"},past:{other:"-{0} w"}},relativePeriod:"{0} semanapi"},day:{displayName:"Day",relative:{0:"kunan punchaw",1:"paqarin","-1":"qayna punchaw"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-short":{displayName:"Day",relative:{0:"kunan punchaw",1:"paqarin","-1":"qayna punchaw"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},"day-narrow":{displayName:"Day",relative:{0:"kunan punchaw",1:"paqarin","-1":"qayna punchaw"},relativeTime:{future:{other:"+{0} d"},past:{other:"-{0} d"}}},hour:{displayName:"Hour",relative:{0:"kay hora"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-short":{displayName:"Hour",relative:{0:"kay hora"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},"hour-narrow":{displayName:"Hour",relative:{0:"kay hora"},relativeTime:{future:{other:"+{0} h"},past:{other:"-{0} h"}}},minute:{displayName:"Minute",relative:{0:"kay minuto"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-short":{displayName:"Minute",relative:{0:"kay minuto"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},"minute-narrow":{displayName:"Minute",relative:{0:"kay minuto"},relativeTime:{future:{other:"+{0} min"},past:{other:"-{0} min"}}},second:{displayName:"Second",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-short":{displayName:"Second",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}},"second-narrow":{displayName:"Second",relative:{0:"now"},relativeTime:{future:{other:"+{0} s"},past:{other:"-{0} s"}}}}},{locale:"qu-BO",parentLocale:"qu"},{locale:"qu-EC",parentLocale:"qu"})}}]);
//# sourceMappingURL=149.aaedf07e1a1c0392f425.index.js.map