(window.webpackJsonp=window.webpackJsonp||[]).push([[57],{182:function(e,a){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"gl",fields:{year:{displayName:"ano",relative:{0:"este ano",1:"o próximo ano","-1":"o ano pasado"},relativeTime:{future:{one:"en {0} ano",other:"en {0} anos"},past:{one:"hai {0} ano",other:"hai {0} anos"}}},"year-short":{displayName:"ano",relative:{0:"este ano",1:"seguinte ano","-1":"ano pasado"},relativeTime:{future:{one:"en {0} ano",other:"en {0} anos"},past:{one:"hai {0} ano",other:"hai {0} anos"}}},"year-narrow":{displayName:"ano",relative:{0:"este ano",1:"seguinte ano","-1":"ano pasado"},relativeTime:{future:{one:"en {0} ano",other:"en {0} anos"},past:{one:"hai {0} ano",other:"hai {0} anos"}}},quarter:{displayName:"trimestre",relative:{0:"este trimestre",1:"o próximo trimestre","-1":"o trimestre pasado"},relativeTime:{future:{one:"en {0} trimestre",other:"en {0} trimestres"},past:{one:"hai {0} trimestre",other:"hai {0} trimestres"}}},"quarter-short":{displayName:"trim.",relative:{0:"este trim.",1:"trim. seguinte","-1":"trim. pasado"},relativeTime:{future:{one:"en {0} trim.",other:"en {0} trim."},past:{one:"hai {0} trim.",other:"hai {0} trim."}}},"quarter-narrow":{displayName:"trim.",relative:{0:"este trim.",1:"trim. seguinte","-1":"trim. pasado"},relativeTime:{future:{one:"en {0} trim.",other:"en {0} trim."},past:{one:"hai {0} trim.",other:"hai {0} trim."}}},month:{displayName:"mes",relative:{0:"este mes",1:"o próximo mes","-1":"o mes pasado"},relativeTime:{future:{one:"en {0} mes",other:"en {0} meses"},past:{one:"hai {0} mes",other:"hai {0} meses"}}},"month-short":{displayName:"mes",relative:{0:"este m.",1:"m. seguinte","-1":"m. pasado"},relativeTime:{future:{one:"en {0} mes",other:"en {0} meses"},past:{one:"hai {0} mes",other:"hai {0} meses"}}},"month-narrow":{displayName:"mes",relative:{0:"este m.",1:"m. seguinte","-1":"m. pasado"},relativeTime:{future:{one:"en {0} mes",other:"en {0} meses"},past:{one:"hai {0} mes",other:"hai {0} meses"}}},week:{displayName:"semana",relative:{0:"esta semana",1:"a próxima semana","-1":"a semana pasada"},relativeTime:{future:{one:"en {0} semana",other:"en {0} semanas"},past:{one:"hai {0} semana",other:"hai {0} semanas"}},relativePeriod:"a semana do {0}"},"week-short":{displayName:"sem.",relative:{0:"esta sem.",1:"sem. seguinte","-1":"sem. pasada"},relativeTime:{future:{one:"en {0} sem.",other:"en {0} sem."},past:{one:"hai {0} sem.",other:"hai {0} sem."}},relativePeriod:"a semana do {0}"},"week-narrow":{displayName:"sem.",relative:{0:"esta sem.",1:"sem. seguinte","-1":"sem. pasada"},relativeTime:{future:{one:"en {0} sem.",other:"en {0} sem."},past:{one:"hai {0} sem.",other:"hai {0} sem."}},relativePeriod:"a semana do {0}"},day:{displayName:"día",relative:{0:"hoxe",1:"mañá",2:"pasadomañá","-2":"antonte","-1":"onte"},relativeTime:{future:{one:"en {0} día",other:"en {0} días"},past:{one:"hai {0} día",other:"hai {0} días"}}},"day-short":{displayName:"día",relative:{0:"hoxe",1:"mañá",2:"pasadomañá","-2":"antonte","-1":"onte"},relativeTime:{future:{one:"en {0} día",other:"en {0} días"},past:{one:"hai {0} día",other:"hai {0} días"}}},"day-narrow":{displayName:"día",relative:{0:"hoxe",1:"mañá",2:"pasadomañá","-2":"antonte","-1":"onte"},relativeTime:{future:{one:"en {0} día",other:"en {0} días"},past:{one:"hai {0} día",other:"hai {0} días"}}},hour:{displayName:"hora",relative:{0:"esta hora"},relativeTime:{future:{one:"en {0} hora",other:"en {0} horas"},past:{one:"hai {0} hora",other:"hai {0} horas"}}},"hour-short":{displayName:"h",relative:{0:"esta hora"},relativeTime:{future:{one:"en {0} h",other:"en {0} h"},past:{one:"hai {0} h",other:"hai {0} h"}}},"hour-narrow":{displayName:"h",relative:{0:"esta hora"},relativeTime:{future:{one:"en {0} h",other:"en {0} h"},past:{one:"hai {0} h",other:"hai {0} h"}}},minute:{displayName:"minuto",relative:{0:"este minuto"},relativeTime:{future:{one:"en {0} minuto",other:"en {0} minutos"},past:{one:"hai {0} minuto",other:"hai {0} minutos"}}},"minute-short":{displayName:"min",relative:{0:"este minuto"},relativeTime:{future:{one:"en {0} min",other:"en {0} min"},past:{one:"hai {0} min",other:"hai {0} min"}}},"minute-narrow":{displayName:"min",relative:{0:"este minuto"},relativeTime:{future:{one:"en {0} min",other:"en {0} min"},past:{one:"hai {0} min",other:"hai {0} min"}}},second:{displayName:"segundo",relative:{0:"agora"},relativeTime:{future:{one:"en {0} segundo",other:"en {0} segundos"},past:{one:"hai {0} segundo",other:"hai {0} segundos"}}},"second-short":{displayName:"s",relative:{0:"agora"},relativeTime:{future:{one:"en {0} s",other:"en {0} s"},past:{one:"hai {0} s",other:"hai {0} s"}}},"second-narrow":{displayName:"s",relative:{0:"agora"},relativeTime:{future:{one:"en {0} s",other:"en {0} s"},past:{one:"hai {0} s",other:"hai {0} s"}}}}})}}]);
//# sourceMappingURL=57.aaedf07e1a1c0392f425.index.js.map