(window.webpackJsonp=window.webpackJsonp||[]).push([[134],{259:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"ne",fields:{year:{displayName:"वर्ष",relative:{0:"यो वर्ष",1:"आगामी वर्ष","-1":"गत वर्ष"},relativeTime:{future:{one:"{0} वर्षमा",other:"{0} वर्षमा"},past:{one:"{0} वर्ष अघि",other:"{0} वर्ष अघि"}}},"year-short":{displayName:"वर्ष",relative:{0:"यो वर्ष",1:"आगामी वर्ष","-1":"गत वर्ष"},relativeTime:{future:{one:"{0} वर्षमा",other:"{0} वर्षमा"},past:{one:"{0} वर्ष अघि",other:"{0} वर्ष अघि"}}},"year-narrow":{displayName:"वर्ष",relative:{0:"यो वर्ष",1:"आगामी वर्ष","-1":"गत वर्ष"},relativeTime:{future:{one:"{0} वर्षमा",other:"{0} वर्षमा"},past:{one:"{0} वर्ष अघि",other:"{0} वर्ष अघि"}}},quarter:{displayName:"सत्र",relative:{0:"यो सत्र",1:"अर्को सत्र","-1":"अघिल्लो सत्र"},relativeTime:{future:{one:"+{0} सत्रमा",other:"{0}सत्रमा"},past:{one:"{0}सत्र अघि",other:"{0}सत्र अघि"}}},"quarter-short":{displayName:"सत्र",relative:{0:"यो सत्र",1:"अर्को सत्र","-1":"अघिल्लो सत्र"},relativeTime:{future:{one:"{0}सत्रमा",other:"{0}सत्रमा"},past:{one:"{0}सत्र अघि",other:"{0}सत्र अघि"}}},"quarter-narrow":{displayName:"सत्र",relative:{0:"यो सत्र",1:"अर्को सत्र","-1":"अघिल्लो सत्र"},relativeTime:{future:{one:"{0}सत्रमा",other:"{0}सत्रमा"},past:{one:"{0}सत्र अघि",other:"{0}सत्र अघि"}}},month:{displayName:"महिना",relative:{0:"यो महिना",1:"अर्को महिना","-1":"गत महिना"},relativeTime:{future:{one:"{0} महिनामा",other:"{0} महिनामा"},past:{one:"{0} महिना पहिले",other:"{0} महिना पहिले"}}},"month-short":{displayName:"महिना",relative:{0:"यो महिना",1:"अर्को महिना","-1":"गत महिना"},relativeTime:{future:{one:"{0} महिनामा",other:"{0} महिनामा"},past:{one:"{0} महिना पहिले",other:"{0} महिना पहिले"}}},"month-narrow":{displayName:"महिना",relative:{0:"यो महिना",1:"अर्को महिना","-1":"गत महिना"},relativeTime:{future:{one:"{0} महिनामा",other:"{0} महिनामा"},past:{one:"{0} महिना पहिले",other:"{0} महिना पहिले"}}},week:{displayName:"हप्ता",relative:{0:"यो हप्ता",1:"आउने हप्ता","-1":"गत हप्ता"},relativeTime:{future:{one:"{0} हप्तामा",other:"{0} हप्तामा"},past:{one:"{0} हप्ता पहिले",other:"{0} हप्ता पहिले"}},relativePeriod:"{0}को हप्ता"},"week-short":{displayName:"हप्ता",relative:{0:"यो हप्ता",1:"आउने हप्ता","-1":"गत हप्ता"},relativeTime:{future:{one:"{0} हप्तामा",other:"{0} हप्तामा"},past:{one:"{0} हप्ता पहिले",other:"{0} हप्ता पहिले"}},relativePeriod:"{0} को हप्ता"},"week-narrow":{displayName:"हप्ता",relative:{0:"यो हप्ता",1:"आउने हप्ता","-1":"गत हप्ता"},relativeTime:{future:{one:"{0} हप्तामा",other:"{0} हप्तामा"},past:{one:"{0} हप्ता पहिले",other:"{0} हप्ता पहिले"}},relativePeriod:"{0} को हप्ता"},day:{displayName:"बार",relative:{0:"आज",1:"भोलि",2:"पर्सि","-2":"अस्ति","-1":"हिजो"},relativeTime:{future:{one:"{0} दिनमा",other:"{0} दिनमा"},past:{one:"{0} दिन पहिले",other:"{0} दिन पहिले"}}},"day-short":{displayName:"बार",relative:{0:"आज",1:"भोलि",2:"पर्सि","-2":"अस्ति","-1":"हिजो"},relativeTime:{future:{one:"{0} दिनमा",other:"{0} दिनमा"},past:{one:"{0} दिन पहिले",other:"{0} दिन पहिले"}}},"day-narrow":{displayName:"बार",relative:{0:"आज",1:"भोलि",2:"पर्सि","-2":"अस्ति","-1":"हिजो"},relativeTime:{future:{one:"{0} दिनमा",other:"{0} दिनमा"},past:{one:"{0} दिन पहिले",other:"{0} दिन पहिले"}}},hour:{displayName:"घण्टा",relative:{0:"यस घडीमा"},relativeTime:{future:{one:"{0} घण्टामा",other:"{0} घण्टामा"},past:{one:"{0} घण्टा पहिले",other:"{0} घण्टा पहिले"}}},"hour-short":{displayName:"घण्टा",relative:{0:"यस घडीमा"},relativeTime:{future:{one:"{0} घण्टामा",other:"{0} घण्टामा"},past:{one:"{0} घण्टा पहिले",other:"{0} घण्टा पहिले"}}},"hour-narrow":{displayName:"घण्टा",relative:{0:"यस घडीमा"},relativeTime:{future:{one:"{0} घण्टामा",other:"{0} घण्टामा"},past:{one:"{0} घण्टा पहिले",other:"{0} घण्टा पहिले"}}},minute:{displayName:"मिनेट",relative:{0:"यही मिनेटमा"},relativeTime:{future:{one:"{0} मिनेटमा",other:"{0} मिनेटमा"},past:{one:"{0} मिनेट पहिले",other:"{0} मिनेट पहिले"}}},"minute-short":{displayName:"मिनेट",relative:{0:"यही मिनेटमा"},relativeTime:{future:{one:"{0} मिनेटमा",other:"{0} मिनेटमा"},past:{one:"{0} मिनेट पहिले",other:"{0} मिनेट पहिले"}}},"minute-narrow":{displayName:"मिनेट",relative:{0:"यही मिनेटमा"},relativeTime:{future:{one:"{0} मिनेटमा",other:"{0} मिनेटमा"},past:{one:"{0} मिनेट पहिले",other:"{0} मिनेट पहिले"}}},second:{displayName:"सेकेन्ड",relative:{0:"अहिले"},relativeTime:{future:{one:"{0} सेकेन्डमा",other:"{0} सेकेन्डमा"},past:{one:"{0} सेकेन्ड पहिले",other:"{0} सेकेन्ड पहिले"}}},"second-short":{displayName:"सेकेन्ड",relative:{0:"अहिले"},relativeTime:{future:{one:"{0} सेकेन्डमा",other:"{0} सेकेन्डमा"},past:{one:"{0} सेकेन्ड पहिले",other:"{0} सेकेन्ड पहिले"}}},"second-narrow":{displayName:"सेकेन्ड",relative:{0:"अहिले"},relativeTime:{future:{one:"{0} सेकेन्डमा",other:"{0} सेकेन्डमा"},past:{one:"{0} सेकेन्ड पहिले",other:"{0} सेकेन्ड पहिले"}}}}},{locale:"ne-IN",parentLocale:"ne"})}}]);
//# sourceMappingURL=134.aaedf07e1a1c0392f425.index.js.map