(window.webpackJsonp=window.webpackJsonp||[]).push([[157],{282:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"sah",fields:{year:{displayName:"Сыл",relative:{0:"быйыл",1:"эһиил","-1":"Былырыын"},relativeTime:{future:{other:"{0} сылынан"},past:{other:"{0} сыл ынараа өттүгэр"}}},"year-short":{displayName:"Сыл",relative:{0:"быйыл",1:"эһиил","-1":"Былырыын"},relativeTime:{future:{other:"{0} сылынан"},past:{other:"{0} сыл ынараа өттүгэр"}}},"year-narrow":{displayName:"Сыл",relative:{0:"быйыл",1:"эһиил","-1":"Былырыын"},relativeTime:{future:{other:"{0} сылынан"},past:{other:"{0} сыл ынараа өттүгэр"}}},quarter:{displayName:"Чиэппэр",relative:{0:"бу кыбаартал",1:"кэлэр кыбаартал","-1":"ааспыт кыбаартал"},relativeTime:{future:{other:"{0} кыбаарталынан"},past:{other:"{0} кыбаартал анараа өттүгэр"}}},"quarter-short":{displayName:"чпр.",relative:{0:"бу кыбаартал",1:"кэлэр кыбаартал","-1":"ааспыт кыбаартал"},relativeTime:{future:{other:"{0} кыбаарталынан"},past:{other:"{0} кыб. анараа өттүгэр"}}},"quarter-narrow":{displayName:"чпр.",relative:{0:"бу кыбаартал",1:"кэлэр кыбаартал","-1":"ааспыт кыбаартал"},relativeTime:{future:{other:"{0} кыбаарталынан"},past:{other:"{0} кыб. анараа өттүгэр"}}},month:{displayName:"Ый",relative:{0:"бу ый",1:"аныгыскы ый","-1":"ааспыт ый"},relativeTime:{future:{other:"{0} ыйынан"},past:{other:"{0} ый ынараа өттүгэр"}}},"month-short":{displayName:"Ый",relative:{0:"бу ый",1:"аныгыскы ый","-1":"ааспыт ый"},relativeTime:{future:{other:"{0} ыйынан"},past:{other:"{0} ый ынараа өттүгэр"}}},"month-narrow":{displayName:"Ый",relative:{0:"бу ый",1:"аныгыскы ый","-1":"ааспыт ый"},relativeTime:{future:{other:"{0} ыйынан"},past:{other:"{0} ый ынараа өттүгэр"}}},week:{displayName:"Нэдиэлэ",relative:{0:"бу нэдиэлэ",1:"кэлэр нэдиэлэ","-1":"ааспыт нэдиэлэ"},relativeTime:{future:{other:"{0} нэдиэлэннэн"},past:{other:"{0} нэдиэлэ анараа өттүгэр"}},relativePeriod:"the week of {0}"},"week-short":{displayName:"Нэдиэлэ",relative:{0:"бу нэдиэлэ",1:"кэлэр нэдиэлэ","-1":"ааспыт нэдиэлэ"},relativeTime:{future:{other:"{0} нэдиэлэннэн"},past:{other:"{0} нэдиэлэ анараа өттүгэр"}},relativePeriod:"the week of {0}"},"week-narrow":{displayName:"Нэдиэлэ",relative:{0:"бу нэдиэлэ",1:"кэлэр нэдиэлэ","-1":"ааспыт нэдиэлэ"},relativeTime:{future:{other:"{0} нэдиэлэннэн"},past:{other:"{0} нэдиэлэ анараа өттүгэр"}},relativePeriod:"the week of {0}"},day:{displayName:"Күн",relative:{0:"Бүгүн",1:"Сарсын",2:"Өйүүн","-2":"Иллэрээ күн","-1":"Бэҕэһээ"},relativeTime:{future:{other:"{0} күнүнэн"},past:{other:"{0} күн ынараа өттүгэр"}}},"day-short":{displayName:"Күн",relative:{0:"Бүгүн",1:"Сарсын",2:"Өйүүн","-2":"Иллэрээ күн","-1":"Бэҕэһээ"},relativeTime:{future:{other:"{0} күнүнэн"},past:{other:"{0} күн ынараа өттүгэр"}}},"day-narrow":{displayName:"Күн",relative:{0:"Бүгүн",1:"Сарсын",2:"Өйүүн","-2":"Иллэрээ күн","-1":"Бэҕэһээ"},relativeTime:{future:{other:"{0} күнүнэн"},past:{other:"{0} күн ынараа өттүгэр"}}},hour:{displayName:"Чаас",relative:{0:"this hour"},relativeTime:{future:{other:"{0} чааһынан"},past:{other:"{0} чаас ынараа өттүгэр"}}},"hour-short":{displayName:"Чаас",relative:{0:"this hour"},relativeTime:{future:{other:"{0} чааһынан"},past:{other:"{0} чаас ынараа өттүгэр"}}},"hour-narrow":{displayName:"Чаас",relative:{0:"this hour"},relativeTime:{future:{other:"{0} чааһынан"},past:{other:"{0} чаас ынараа өттүгэр"}}},minute:{displayName:"Мүнүүтэ",relative:{0:"this minute"},relativeTime:{future:{other:"{0} мүнүүтэннэн"},past:{other:"{0} мүнүүтэ ынараа өттүгэр"}}},"minute-short":{displayName:"Мүнүүтэ",relative:{0:"this minute"},relativeTime:{future:{other:"{0} мүнүүтэннэн"},past:{other:"{0} мүнүүтэ ынараа өттүгэр"}}},"minute-narrow":{displayName:"Мүнүүтэ",relative:{0:"this minute"},relativeTime:{future:{other:"{0} мүнүүтэннэн"},past:{other:"{0} мүнүүтэ ынараа өттүгэр"}}},second:{displayName:"Сөкүүндэ",relative:{0:"билигин"},relativeTime:{future:{other:"{0} сөкүүндэннэн"},past:{other:"{0} сөкүүндэ ынараа өттүгэр"}}},"second-short":{displayName:"Сөкүүндэ",relative:{0:"билигин"},relativeTime:{future:{other:"{0} сөкүүндэннэн"},past:{other:"{0} сөк. анараа өттүгэр"}}},"second-narrow":{displayName:"Сөкүүндэ",relative:{0:"билигин"},relativeTime:{future:{other:"{0} сөкүүндэннэн"},past:{other:"{0} сөк. анараа өттүгэр"}}}}})}}]);
//# sourceMappingURL=157.aaedf07e1a1c0392f425.index.js.map