(window.webpackJsonp=window.webpackJsonp||[]).push([[84],{209:function(e,a){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"kea",fields:{year:{displayName:"Anu",relative:{0:"es anu li",1:"prósimu anu","-1":"anu pasadu"},relativeTime:{future:{other:"di li {0} anu"},past:{other:"a ten {0} anu"}}},"year-short":{displayName:"anu",relative:{0:"es anu li",1:"prósimu anu","-1":"anu pasadu"},relativeTime:{future:{other:"di li {0} anu"},past:{other:"a ten {0} anu"}}},"year-narrow":{displayName:"anu",relative:{0:"es anu li",1:"prósimu anu","-1":"anu pasadu"},relativeTime:{future:{other:"di li {0} anu"},past:{other:"a ten {0} anu"}}},quarter:{displayName:"Trimestri",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"di li {0} trimestri"},past:{other:"a ten {0} trimestri"}}},"quarter-short":{displayName:"trim.",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"di li {0} trim."},past:{other:"a ten {0} trim."}}},"quarter-narrow":{displayName:"trim.",relative:{0:"this quarter",1:"next quarter","-1":"last quarter"},relativeTime:{future:{other:"di li {0} trim."},past:{other:"a ten {0} trim."}}},month:{displayName:"Mes",relative:{0:"es mes li",1:"prósimu mes","-1":"mes pasadu"},relativeTime:{future:{other:"di li {0} mes"},past:{other:"a ten {0} mes"}}},"month-short":{displayName:"mes",relative:{0:"es mes li",1:"prósimu mes","-1":"mes pasadu"},relativeTime:{future:{other:"di li {0} mes"},past:{other:"a ten {0} mes"}}},"month-narrow":{displayName:"mes",relative:{0:"es mes li",1:"prósimu mes","-1":"mes pasadu"},relativeTime:{future:{other:"di li {0} mes"},past:{other:"a ten {0} mes"}}},week:{displayName:"Simana",relative:{0:"es simana li",1:"prósimu simana","-1":"simana pasadu"},relativeTime:{future:{other:"di li {0} simana"},past:{other:"a ten {0} simana"}},relativePeriod:"the week of {0}"},"week-short":{displayName:"sim.",relative:{0:"es simana li",1:"prósimu simana","-1":"simana pasadu"},relativeTime:{future:{other:"di li {0} sim."},past:{other:"a ten {0} sim."}},relativePeriod:"the week of {0}"},"week-narrow":{displayName:"sim.",relative:{0:"es simana li",1:"prósimu simana","-1":"simana pasadu"},relativeTime:{future:{other:"di li {0} sim."},past:{other:"a ten {0} sim."}},relativePeriod:"the week of {0}"},day:{displayName:"Dia",relative:{0:"oji",1:"manha","-1":"onti"},relativeTime:{future:{other:"di li {0} dia"},past:{other:"a ten {0} dia"}}},"day-short":{displayName:"dia",relative:{0:"oji",1:"manha","-1":"onti"},relativeTime:{future:{other:"di li {0} dia"},past:{other:"a ten {0} dia"}}},"day-narrow":{displayName:"dia",relative:{0:"oji",1:"manha","-1":"onti"},relativeTime:{future:{other:"di li {0} dia"},past:{other:"a ten {0} dia"}}},hour:{displayName:"Ora",relative:{0:"this hour"},relativeTime:{future:{other:"di li {0} ora"},past:{other:"a ten {0} ora"}}},"hour-short":{displayName:"ora",relative:{0:"this hour"},relativeTime:{future:{other:"di li {0} ora"},past:{other:"a ten {0} ora"}}},"hour-narrow":{displayName:"h",relative:{0:"this hour"},relativeTime:{future:{other:"di li {0} ora"},past:{other:"a ten {0} ora"}}},minute:{displayName:"Minutu",relative:{0:"this minute"},relativeTime:{future:{other:"di li {0} minutu"},past:{other:"a ten {0} minutu"}}},"minute-short":{displayName:"min",relative:{0:"this minute"},relativeTime:{future:{other:"di li {0} min"},past:{other:"a ten {0} min"}}},"minute-narrow":{displayName:"m",relative:{0:"this minute"},relativeTime:{future:{other:"di li {0} m"},past:{other:"a ten {0} m"}}},second:{displayName:"Sigundu",relative:{0:"now"},relativeTime:{future:{other:"di li {0} sigundu"},past:{other:"a ten {0} sigundu"}}},"second-short":{displayName:"sig",relative:{0:"now"},relativeTime:{future:{other:"di li {0} sig"},past:{other:"a ten {0} sig"}}},"second-narrow":{displayName:"s",relative:{0:"now"},relativeTime:{future:{other:"di li {0} s"},past:{other:"a ten {0} s"}}}}})}}]);
//# sourceMappingURL=84.aaedf07e1a1c0392f425.index.js.map