(window.webpackJsonp=window.webpackJsonp||[]).push([[125],{250:function(a,e){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"ms",fields:{year:{displayName:"tahun",relative:{0:"tahun ini",1:"tahun depan","-1":"tahun lalu"},relativeTime:{future:{other:"dalam {0} tahun"},past:{other:"{0} tahun lalu"}}},"year-short":{displayName:"thn",relative:{0:"thn ini",1:"thn depan","-1":"thn lepas"},relativeTime:{future:{other:"dalam {0} thn"},past:{other:"{0} thn lalu"}}},"year-narrow":{displayName:"thn",relative:{0:"thn ini",1:"thn depan","-1":"thn lepas"},relativeTime:{future:{other:"dalam {0} thn"},past:{other:"{0} thn lalu"}}},quarter:{displayName:"suku tahun",relative:{0:"suku tahun ini",1:"suku tahun seterusnya","-1":"suku tahun lalu"},relativeTime:{future:{other:"dalam {0} suku tahun"},past:{other:"{0} suku tahun lalu"}}},"quarter-short":{displayName:"suku",relative:{0:"suku ini",1:"suku seterusnya","-1":"suku lepas"},relativeTime:{future:{other:"dlm {0} suku thn"},past:{other:"{0} suku thn lalu"}}},"quarter-narrow":{displayName:"suku",relative:{0:"suku ini",1:"suku seterusnya","-1":"suku lepas"},relativeTime:{future:{other:"dlm {0} suku thn"},past:{other:"{0} suku thn lalu"}}},month:{displayName:"bulan",relative:{0:"bulan ini",1:"bulan depan","-1":"bulan lalu"},relativeTime:{future:{other:"dalam {0} bulan"},past:{other:"{0} bulan lalu"}}},"month-short":{displayName:"bln",relative:{0:"bln ini",1:"bln depan","-1":"bln lalu"},relativeTime:{future:{other:"dlm {0} bln"},past:{other:"{0} bln lalu"}}},"month-narrow":{displayName:"bln",relative:{0:"bln ini",1:"bln depan","-1":"bln lalu"},relativeTime:{future:{other:"dlm {0} bln"},past:{other:"{0} bulan lalu"}}},week:{displayName:"minggu",relative:{0:"minggu ini",1:"minggu depan","-1":"minggu lalu"},relativeTime:{future:{other:"dalam {0} minggu"},past:{other:"{0} minggu lalu"}},relativePeriod:"minggu ke-{0}"},"week-short":{displayName:"mgu",relative:{0:"mng ini",1:"mng depan","-1":"mng lepas"},relativeTime:{future:{other:"dlm {0} mgu"},past:{other:"{0} mgu lalu"}},relativePeriod:"minggu ke-{0}"},"week-narrow":{displayName:"mgu",relative:{0:"mng ini",1:"mng depan","-1":"mng lepas"},relativeTime:{future:{other:"dlm {0} mgu"},past:{other:"{0} mgu lalu"}},relativePeriod:"minggu ke-{0}"},day:{displayName:"hari",relative:{0:"hari ini",1:"esok",2:"lusa","-2":"kelmarin","-1":"semalam"},relativeTime:{future:{other:"dalam {0} hari"},past:{other:"{0} hari lalu"}}},"day-short":{displayName:"hari",relative:{0:"hari ini",1:"esok",2:"lusa","-2":"kelmarin","-1":"semlm"},relativeTime:{future:{other:"dlm {0} hari"},past:{other:"{0} hari lalu"}}},"day-narrow":{displayName:"hari",relative:{0:"hari ini",1:"esok",2:"lusa","-2":"kelmarin","-1":"semlm"},relativeTime:{future:{other:"dlm {0} hari"},past:{other:"{0} hari lalu"}}},hour:{displayName:"jam",relative:{0:"jam ini"},relativeTime:{future:{other:"dalam {0} jam"},past:{other:"{0} jam lalu"}}},"hour-short":{displayName:"jam",relative:{0:"jam ini"},relativeTime:{future:{other:"dlm {0} jam"},past:{other:"{0} jam lalu"}}},"hour-narrow":{displayName:"jam",relative:{0:"jam ini"},relativeTime:{future:{other:"dlm {0} jam"},past:{other:"{0} jam lalu"}}},minute:{displayName:"minit",relative:{0:"pada minit ini"},relativeTime:{future:{other:"dalam {0} minit"},past:{other:"{0} minit lalu"}}},"minute-short":{displayName:"min",relative:{0:"pada minit ini"},relativeTime:{future:{other:"dlm {0} min"},past:{other:"{0} min lalu"}}},"minute-narrow":{displayName:"min",relative:{0:"pada minit ini"},relativeTime:{future:{other:"dlm {0} min"},past:{other:"{0} min lalu"}}},second:{displayName:"saat",relative:{0:"sekarang"},relativeTime:{future:{other:"dalam {0} saat"},past:{other:"{0} saat lalu"}}},"second-short":{displayName:"saat",relative:{0:"sekarang"},relativeTime:{future:{other:"dlm {0} saat"},past:{other:"{0} saat lalu"}}},"second-narrow":{displayName:"saat",relative:{0:"sekarang"},relativeTime:{future:{other:"dlm {0} saat"},past:{other:"{0} saat lalu"}}}}},{locale:"ms-BN",parentLocale:"ms"},{locale:"ms-SG",parentLocale:"ms"})}}]);
//# sourceMappingURL=125.aaedf07e1a1c0392f425.index.js.map