(window.webpackJsonp=window.webpackJsonp||[]).push([[69],{194:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"hy",fields:{year:{displayName:"տարի",relative:{0:"այս տարի",1:"հաջորդ տարի","-1":"նախորդ տարի"},relativeTime:{future:{one:"{0} տարուց",other:"{0} տարուց"},past:{one:"{0} տարի առաջ",other:"{0} տարի առաջ"}}},"year-short":{displayName:"տ",relative:{0:"այս տարի",1:"հաջորդ տարի","-1":"նախորդ տարի"},relativeTime:{future:{one:"{0} տարուց",other:"{0} տարուց"},past:{one:"{0} տ առաջ",other:"{0} տ առաջ"}}},"year-narrow":{displayName:"տ",relative:{0:"այս տարի",1:"հաջորդ տարի","-1":"նախորդ տարի"},relativeTime:{future:{one:"{0} տարուց",other:"{0} տարուց"},past:{one:"{0} տ առաջ",other:"{0} տ առաջ"}}},quarter:{displayName:"եռամսյակ",relative:{0:"այս եռամսյակ",1:"հաջորդ եռամսյակ","-1":"նախորդ եռամսյակ"},relativeTime:{future:{one:"{0} եռամսյակից",other:"{0} եռամսյակից"},past:{one:"{0} եռամսյակ առաջ",other:"{0} եռամսյակ առաջ"}}},"quarter-short":{displayName:"եռմս",relative:{0:"այս եռամսյակ",1:"հաջորդ եռամսյակ","-1":"նախորդ եռամսյակ"},relativeTime:{future:{one:"{0} եռմս-ից",other:"{0} եռմս-ից"},past:{one:"{0} եռմս առաջ",other:"{0} եռմս առաջ"}}},"quarter-narrow":{displayName:"եռմս",relative:{0:"այս եռամսյակ",1:"հաջորդ եռամսյակ","-1":"նախորդ եռամսյակ"},relativeTime:{future:{one:"{0} եռմս-ից",other:"{0} եռմս-ից"},past:{one:"{0} եռմս առաջ",other:"{0} եռմս առաջ"}}},month:{displayName:"ամիս",relative:{0:"այս ամիս",1:"հաջորդ ամիս","-1":"նախորդ ամիս"},relativeTime:{future:{one:"{0} ամսից",other:"{0} ամսից"},past:{one:"{0} ամիս առաջ",other:"{0} ամիս առաջ"}}},"month-short":{displayName:"ամս",relative:{0:"այս ամիս",1:"հաջորդ ամիս","-1":"անցյալ ամիս"},relativeTime:{future:{one:"{0} ամսից",other:"{0} ամսից"},past:{one:"{0} ամիս առաջ",other:"{0} ամիս առաջ"}}},"month-narrow":{displayName:"ամս",relative:{0:"այս ամիս",1:"հաջորդ ամիս","-1":"անցյալ ամիս"},relativeTime:{future:{one:"{0} ամսից",other:"{0} ամսից"},past:{one:"{0} ամիս առաջ",other:"{0} ամիս առաջ"}}},week:{displayName:"շաբաթ",relative:{0:"այս շաբաթ",1:"հաջորդ շաբաթ","-1":"նախորդ շաբաթ"},relativeTime:{future:{one:"{0} շաբաթից",other:"{0} շաբաթից"},past:{one:"{0} շաբաթ առաջ",other:"{0} շաբաթ առաջ"}},relativePeriod:"{0} շաբաթում"},"week-short":{displayName:"շաբ",relative:{0:"այս շաբաթ",1:"հաջորդ շաբաթ","-1":"նախորդ շաբաթ"},relativeTime:{future:{one:"{0} շաբ-ից",other:"{0} շաբ-ից"},past:{one:"{0} շաբ առաջ",other:"{0} շաբ առաջ"}},relativePeriod:"{0} շաբ-ում"},"week-narrow":{displayName:"շաբ",relative:{0:"այս շաբաթ",1:"հաջորդ շաբաթ","-1":"նախորդ շաբաթ"},relativeTime:{future:{one:"{0} շաբ անց",other:"{0} շաբ անց"},past:{one:"{0} շաբ առաջ",other:"{0} շաբ առաջ"}},relativePeriod:"{0} շաբ-ում"},day:{displayName:"օր",relative:{0:"այսօր",1:"վաղը",2:"վաղը չէ մյուս օրը","-2":"երեկ չէ առաջի օրը","-1":"երեկ"},relativeTime:{future:{one:"{0} օրից",other:"{0} օրից"},past:{one:"{0} օր առաջ",other:"{0} օր առաջ"}}},"day-short":{displayName:"օր",relative:{0:"այսօր",1:"վաղը",2:"վաղը չէ մյուս օրը","-2":"երեկ չէ առաջի օրը","-1":"երեկ"},relativeTime:{future:{one:"{0} օրից",other:"{0} օրից"},past:{one:"{0} օր առաջ",other:"{0} օր առաջ"}}},"day-narrow":{displayName:"օր",relative:{0:"այսօր",1:"վաղը",2:"վաղը չէ մյուս օրը","-2":"երեկ չէ առաջի օրը","-1":"երեկ"},relativeTime:{future:{one:"{0} օրից",other:"{0} օրից"},past:{one:"{0} օր առաջ",other:"{0} օր առաջ"}}},hour:{displayName:"ժամ",relative:{0:"այս ժամին"},relativeTime:{future:{one:"{0} ժամից",other:"{0} ժամից"},past:{one:"{0} ժամ առաջ",other:"{0} ժամ առաջ"}}},"hour-short":{displayName:"ժ",relative:{0:"այս ժամին"},relativeTime:{future:{one:"{0} ժ-ից",other:"{0} ժ-ից"},past:{one:"{0} ժ առաջ",other:"{0} ժ առաջ"}}},"hour-narrow":{displayName:"ժ",relative:{0:"այս ժամին"},relativeTime:{future:{one:"{0} ժ-ից",other:"{0} ժ-ից"},past:{one:"{0} ժ առաջ",other:"{0} ժ առաջ"}}},minute:{displayName:"րոպե",relative:{0:"այս րոպեին"},relativeTime:{future:{one:"{0} րոպեից",other:"{0} րոպեից"},past:{one:"{0} րոպե առաջ",other:"{0} րոպե առաջ"}}},"minute-short":{displayName:"ր",relative:{0:"այս րոպեին"},relativeTime:{future:{one:"{0} ր-ից",other:"{0} ր-ից"},past:{one:"{0} ր առաջ",other:"{0} ր առաջ"}}},"minute-narrow":{displayName:"ր",relative:{0:"այս րոպեին"},relativeTime:{future:{one:"{0} ր-ից",other:"{0} ր-ից"},past:{one:"{0} ր առաջ",other:"{0} ր առաջ"}}},second:{displayName:"վայրկյան",relative:{0:"հիմա"},relativeTime:{future:{one:"{0} վայրկյանից",other:"{0} վայրկյանից"},past:{one:"{0} վայրկյան առաջ",other:"{0} վայրկյան առաջ"}}},"second-short":{displayName:"վ",relative:{0:"հիմա"},relativeTime:{future:{one:"{0} վրկ-ից",other:"{0} վրկ-ից"},past:{one:"{0} վրկ առաջ",other:"{0} վրկ առաջ"}}},"second-narrow":{displayName:"վ",relative:{0:"հիմա"},relativeTime:{future:{one:"{0} վ-ից",other:"{0} վ-ից"},past:{one:"{0} վ առաջ",other:"{0} վ առաջ"}}}}})}}]);
//# sourceMappingURL=69.aaedf07e1a1c0392f425.index.js.map