{% load cms_tags %}{% spaceless %}

{% for child in children %}
    {% with children_slug=child.get_menu_title|slugify %}
        <li class="menu__list__item
            {% if child.selected %} menu__list__item--selected{% endif %}
            {% if child.ancestor %} menu__list__item--ancestor{% endif %}
            {% if child.sibling %} menu__list__item--sibling{% endif %}
            {% if child.descendant %} menu__list__item--descendant{% endif %}">
            <a class="menu__list__item__link" href="{{ child.attr.redirect_url|default:child.get_absolute_url }}">{{ child.get_menu_title }}</a>
            {% if child.children %}
            <ul>
                {% show_menu from_level to_level extra_inactive extra_active template "" "" child %}
            </ul>
            {% endif %}
        </li>
    {% endwith %}
{% endfor %}

{% endspaceless %}
