(window.webpackJsonp=window.webpackJsonp||[]).push([[181],{306:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"ti",fields:{year:{displayName:"ዓመት",relative:{0:"ሎሚ ዓመት",1:"ንዓመታ","-1":"ዓሚ"},relativeTime:{future:{one:"ኣብ {0} ዓ",other:"ኣብ {0} ዓ"},past:{one:"ቅድሚ {0} ዓ",other:"ቅድሚ {0} ዓ"}}},"year-short":{displayName:"ዓመት",relative:{0:"ሎሚ ዓመት",1:"ንዓመታ","-1":"ዓሚ"},relativeTime:{future:{one:"ኣብ {0} ዓ",other:"ኣብ {0} ዓ"},past:{one:"ቅድሚ -{0} ዓ",other:"ቅድሚ {0} ዓ"}}},"year-narrow":{displayName:"ዓመት",relative:{0:"ሎሚ ዓመት",1:"ንዓመታ","-1":"ዓሚ"},relativeTime:{future:{one:"ኣብ {0} ዓ",other:"ኣብ {0} ዓ"},past:{one:"ቅድሚ {0} ዓ",other:"ቅድሚ {0} ዓ"}}},quarter:{displayName:"ርብዒ",relative:{0:"ህሉው ርብዒ",1:"ዝመጽእ ርብዒ","-1":"ዝሓለፈ ርብዒ"},relativeTime:{future:{one:"ኣብ {0} ርብዒ",other:"ኣብ {0} ርብዒ"},past:{one:"ቅድሚ {0} ርብዒ",other:"ቅድሚ {0} ርብዒ"}}},"quarter-short":{displayName:"ርብዒ",relative:{0:"ህሉው ርብዒ",1:"ዝመጽእ ርብዒ","-1":"ዝሓለፈ ርብዒ"},relativeTime:{future:{one:"ኣብ {0} ርብዒ",other:"ኣብ {0} ርብዒ"},past:{one:"ቅድሚ {0} ርብዒ",other:"ቅድሚ {0} ርብዒ"}}},"quarter-narrow":{displayName:"ርብዒ",relative:{0:"ህሉው ርብዒ",1:"ዝመጽእ ርብዒ","-1":"ዝሓለፈ ርብዒ"},relativeTime:{future:{one:"ኣብ {0} ርብዒ",other:"ኣብ {0} ርብዒ"},past:{one:"ቅድሚ {0} ርብዒ",other:"ቅድሚ {0} ርብዒ"}}},month:{displayName:"ወርሒ",relative:{0:"ህሉው ወርሒ",1:"ዝመጽእ ወርሒ","-1":"last month"},relativeTime:{future:{one:"ኣብ {0} ወርሒ",other:"ኣብ {0} ወርሒ"},past:{one:"ቅድሚ {0} ወርሒ",other:"ቅድሚ {0} ወርሒ"}}},"month-short":{displayName:"ወርሒ",relative:{0:"ህሉው ወርሒ",1:"ዝመጽእ ወርሒ","-1":"last month"},relativeTime:{future:{one:"ኣብ {0} ወርሒ",other:"ኣብ {0} ወርሒ"},past:{one:"ቅድሚ {0} ወርሒ",other:"ቅድሚ {0} ወርሒ"}}},"month-narrow":{displayName:"ወርሒ",relative:{0:"ህሉው ወርሒ",1:"ዝመጽእ ወርሒ","-1":"last month"},relativeTime:{future:{one:"ኣብ {0} ወርሒ",other:"ኣብ {0} ወርሒ"},past:{one:"ቅድሚ {0} ወርሒ",other:"ቅድሚ {0} ወርሒ"}}},week:{displayName:"ሰሙን",relative:{0:"ህሉው ሰሙን",1:"ዝመጽእ ሰሙን","-1":"ዝሓለፈ ሰሙን"},relativeTime:{future:{one:"ኣብ {0} ሰሙን",other:"ኣብ {0} ሰሙን"},past:{one:"ቅድሚ {0} ሰሙን",other:"ቅድሚ {0} ሰሙን"}},relativePeriod:"ሰሙን ናይ {0}"},"week-short":{displayName:"ሰሙን",relative:{0:"ህሉው ሰሙን",1:"ዝመጽእ ሰሙን","-1":"ዝሓለፈ ሰሙን"},relativeTime:{future:{one:"ኣብ {0} ሰሙን",other:"ኣብ {0} ሰሙን"},past:{one:"ቅድሚ {0} ሰሙን",other:"ቅድሚ {0} ሰሙን"}},relativePeriod:"ሰሙን ናይ {0}"},"week-narrow":{displayName:"ሰሙን",relative:{0:"ህሉው ሰሙን",1:"ዝመጽእ ሰሙን","-1":"ዝሓለፈ ሰሙን"},relativeTime:{future:{one:"ኣብ {0} ሰሙን",other:"ኣብ {0} ሰሙን"},past:{one:"ቅድሚ {0} ሰሙን",other:"ቅድሚ {0} ሰሙን"}},relativePeriod:"ሰሙን ናይ {0}"},day:{displayName:"መዓልቲ",relative:{0:"ሎሚ",1:"ጽባሕ","-1":"ትማሊ"},relativeTime:{future:{one:"ኣብ {0} መዓልቲ",other:"ኣብ {0} መዓልቲ"},past:{one:"ቅድሚ {0} መዓልቲ",other:"ኣብ {0} መዓልቲ"}}},"day-short":{displayName:"መዓልቲ",relative:{0:"ሎሚ",1:"ጽባሕ","-1":"ትማሊ"},relativeTime:{future:{one:"ኣብ {0} መዓልቲ",other:"ኣብ {0} መዓልቲ"},past:{one:"ቅድሚ {0} መዓልቲ",other:"ቅድሚ {0} መዓልቲ"}}},"day-narrow":{displayName:"መዓልቲ",relative:{0:"ሎሚ",1:"ጽባሕ","-1":"ትማሊ"},relativeTime:{future:{one:"ኣብ {0} መዓልቲ",other:"ኣብ {0} መዓልቲ"},past:{one:"ቅድሚ {0} መዓልቲ",other:"ቅድሚ {0} መዓልቲ"}}},hour:{displayName:"ሰዓት",relative:{0:"ኣብዚ ሰዓት"},relativeTime:{future:{one:"ኣብ {0} ሰዓት",other:"ኣብ {0} ሰዓት"},past:{one:"ቅድሚ {0} ሰዓት",other:"ቅድሚ {0} ሰዓት"}}},"hour-short":{displayName:"ሰዓት",relative:{0:"ኣብዚ ሰዓት"},relativeTime:{future:{one:"ኣብ {0} ሰዓት",other:"ኣብ {0} ሰዓት"},past:{one:"ቅድሚ {0} ሰዓት",other:"ቅድሚ {0} ሰዓት"}}},"hour-narrow":{displayName:"ሰዓት",relative:{0:"ኣብዚ ሰዓት"},relativeTime:{future:{one:"ኣብ {0} ሰዓት",other:"ኣብ {0} ሰዓት"},past:{one:"ቅድሚ {0} ሰዓት",other:"ቅድሚ {0} ሰዓት"}}},minute:{displayName:"ደቒቕ",relative:{0:"ኣብዚ ደቒቕ"},relativeTime:{future:{one:"ኣብ {0} ደቒቕ",other:"ኣብ {0} ደቒቕ"},past:{one:"ቅድሚ {0} ደቒቕ",other:"ቅድሚ {0} ደቒቕ"}}},"minute-short":{displayName:"ደቒቕ",relative:{0:"ኣብዚ ደቒቕ"},relativeTime:{future:{one:"ኣብ {0} ደቒቕ",other:"ኣብ {0} ደቒቕ"},past:{one:"ቅድሚ {0} ደቒቕ",other:"ቅድሚ {0} ደቒቕ"}}},"minute-narrow":{displayName:"ደቒ.",relative:{0:"ኣብዚ ደቒቕ"},relativeTime:{future:{one:"ኣብ {0} ደቒቕ",other:"ኣብ {0} ደቒቕ"},past:{one:"ቅድሚ {0} ደቒቕ",other:"ቅድሚ {0} ደቒቕ"}}},second:{displayName:"ካልኢት",relative:{0:"ሕጂ"},relativeTime:{future:{one:"ኣብ {0} ካልኢት",other:"ኣብ {0} ካልኢት"},past:{one:"ቅድሚ {0} ካልኢት",other:"ቅድሚ {0} ካልኢት"}}},"second-short":{displayName:"ካልኢት",relative:{0:"ሕጂ"},relativeTime:{future:{one:"ኣብ {0} ካልኢት",other:"ኣብ {0} ካልኢት"},past:{one:"ቅድሚ {0} ካልኢት",other:"ቅድሚ {0} ካልኢት"}}},"second-narrow":{displayName:"ካልኢት",relative:{0:"ሕጂ"},relativeTime:{future:{one:"ኣብ {0} ካልኢት",other:"ኣብ {0} ካልኢት"},past:{one:"ቅድሚ {0} ካልኢት",other:"ቅድሚ {0} ካልኢት"}}}}},{locale:"ti-ER",parentLocale:"ti"})}}]);
//# sourceMappingURL=181.aaedf07e1a1c0392f425.index.js.map