{% load i18n cms_tags extra_tags thumbnail %}
{% comment %}Obviously, the context template variable "organization" is required and must be an Organization page extension{% endcomment %}
{% with organization_page=organization.extended_object %}
<a class="organization-glimpse organization-glimpse--link{% if organization_page.publisher_is_draft is True %} organization-glimpse--draft{% endif %}" href="{{ organization_page.get_absolute_url }}">
  <div class="organization-glimpse__logo">
    {% get_placeholder_plugins "logo" organization_page as plugins or %}
      <p class="organization-glimpse__logo__empty">{% trans "Logo" %}</p>
    {% endget_placeholder_plugins %}
    {% blockplugin plugins.0 %}
      <img src="{% thumbnail instance.picture 200x113 upscale subject_location=instance.picture.subject_location %}"
        srcset="
          {% thumbnail instance.picture 200x113 upscale subject_location=instance.picture.subject_location %} 200w,
          {% if instance.picture.width >= 400 %}{% thumbnail instance.picture 400x225 upscale subject_location=instance.picture.subject_location %} 400w,{% endif %}
          {% if instance.picture.width >= 600 %}{% thumbnail instance.picture 600x338 upscale subject_location=instance.picture.subject_location %} 600w{% endif %}
          {% if instance.picture.width >= 800 %}{% thumbnail instance.picture 800x450 upscale subject_location=instance.picture.subject_location %} 800w{% endif %}
        "
        sizes="100vw, (min-width: 576px) 50vw, (min-width: 1200px) 25vw"
        alt=""
      />
    {% endblockplugin %}
  </div>
  <div class="organization-glimpse__title">
    {{ organization_page.get_title }}
  </div>
</a>
{% endwith %}
