{% load i18n %}{% spaceless %}
    <a href="https://www.facebook.com/example" target="_blank" class="body-footer__brand__badge body-footer__brand__badge--facebook" title="{% trans "Facebook page" %}">
        <span class="icon-facebook"></span>
    </a>
    <a href="https://twitter.com/@funmooc" class="body-footer__brand__badge body-footer__brand__badge--twitter" target="_blank" title="{% trans "Twitter page" %}">
        <span class="icon-twitter"></span>
    </a>
{% endspaceless %}
