(window.webpackJsonp=window.webpackJsonp||[]).push([[94],{219:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"kok",fields:{year:{displayName:"वर्स",relative:{0:"हें वर्स",1:"फुडलें वर्स","-1":"फाटलें वर्स"},relativeTime:{future:{other:"{0} वर्सांनीं"},past:{other:"{0} वर्सां आदीं"}}},"year-short":{displayName:"वर्स",relative:{0:"हें वर्स",1:"फुडलें वर्स","-1":"फाटलें वर्स"},relativeTime:{future:{other:"{0} वर्सांनीं"},past:{other:"{0} वर्स आदीं"}}},"year-narrow":{displayName:"वर्स",relative:{0:"हें वर्स",1:"फुडलें वर्स","-1":"फाटलें वर्स"},relativeTime:{future:{other:"{0} वर्सांनीं"},past:{other:"{0} वर्स आदीं"}}},quarter:{displayName:"त्रैमासीक",relative:{0:"हो त्रैमासीक",1:"फुडलो त्रैमासीक","-1":"फाटलो त्रैमासीक"},relativeTime:{future:{other:"{0} त्रैमासीकांत"},past:{other:"{0} त्रैमासीकां आदीं"}}},"quarter-short":{displayName:"त्रैमासीक",relative:{0:"हो त्रैमासीक",1:"फुडलो त्रैमासीक","-1":"फाटलो त्रैमासीक"},relativeTime:{future:{other:"{0} त्रैमासीकांत"},past:{other:"{0} त्रैमासीकां आदीं"}}},"quarter-narrow":{displayName:"त्रैमासीक",relative:{0:"हो त्रैमासीक",1:"फुडलो त्रैमासीक","-1":"फाटलो त्रैमासीक"},relativeTime:{future:{other:"{0} त्रैमासीकांत"},past:{other:"{0} त्रैमासीकां आदीं"}}},month:{displayName:"म्हयनो",relative:{0:"हो म्हयनो",1:"फुडलो म्हयनो","-1":"फाटलो म्हयनो"},relativeTime:{future:{other:"{0} म्हयन्यानीं"},past:{other:"{0} म्हयन्यां आदीं"}}},"month-short":{displayName:"म्हयनो",relative:{0:"हो म्हयनो",1:"फुडलो म्हयनो","-1":"फाटलो म्हयनो"},relativeTime:{future:{other:"{0} म्हयन्यानीं"},past:{other:"{0} म्हयन्यां आदीं"}}},"month-narrow":{displayName:"म्हयनो",relative:{0:"हो म्हयनो",1:"फुडलो म्हयनो","-1":"फाटलो म्हयनो"},relativeTime:{future:{other:"{0} म्हयन्यानीं"},past:{other:"{0} म्हयन्यां आदीं"}}},week:{displayName:"सप्तक",relative:{0:"हो सप्तक",1:"फुडलो सप्तक","-1":"निमाणो सप्तक"},relativeTime:{future:{other:"{0} सप्तकांनीं"},past:{other:"{0} सप्तकां आदीं"}},relativePeriod:"{0} चो सप्तक"},"week-short":{displayName:"सप्तक",relative:{0:"हो सप्तक",1:"फुडलो सप्तक","-1":"निमाणो सप्तक"},relativeTime:{future:{other:"{0} सप्त."},past:{other:"{0} सप्तकां आदीं"}},relativePeriod:"{0} चो सप्तक"},"week-narrow":{displayName:"सप्तक",relative:{0:"हो सप्तक",1:"फुडलो सप्तक","-1":"निमाणो सप्तक"},relativeTime:{future:{other:"{0} सप्तकांनीं"},past:{other:"{0} सप्त. आदीं"}},relativePeriod:"{0} चो सप्तक"},day:{displayName:"दीस",relative:{0:"आयज",1:"फाल्यां","-1":"काल"},relativeTime:{future:{other:"{0} दिसानीं"},past:{other:"{0} दीस आदीं"}}},"day-short":{displayName:"दीस",relative:{0:"आयज",1:"फाल्यां","-1":"काल"},relativeTime:{future:{other:"{0} दिसानीं"},past:{other:"{0} दीस आदीं"}}},"day-narrow":{displayName:"दीस",relative:{0:"आयज",1:"फाल्यां","-1":"काल"},relativeTime:{future:{other:"{0} दिसानीं"},past:{other:"{0} दीस आदीं"}}},hour:{displayName:"वर",relative:{0:"हें वर"},relativeTime:{future:{other:"{0} वरांनीं"},past:{other:"{0} वरा आदीं"}}},"hour-short":{displayName:"वर",relative:{0:"हें वर"},relativeTime:{future:{other:"{0} वरांनीं"},past:{other:"{0} वरा आदीं"}}},"hour-narrow":{displayName:"वर",relative:{0:"हें वर"},relativeTime:{future:{other:"{0} वरांनीं"},past:{other:"{0} वरा आदीं"}}},minute:{displayName:"मिनीट",relative:{0:"हें मिनीट"},relativeTime:{future:{other:"{0} मिन्टां"},past:{other:"{0} मिन्टां आदीं"}}},"minute-short":{displayName:"मिनीट",relative:{0:"हें मिनीट"},relativeTime:{future:{other:"{0} मिन्टां"},past:{other:"{0} मिन्टां आदीं"}}},"minute-narrow":{displayName:"मिनीट",relative:{0:"हें मिनीट"},relativeTime:{future:{other:"{0} मिन्टां"},past:{other:"{0} मिन्टां आदीं"}}},second:{displayName:"सेकंद",relative:{0:"आतां"},relativeTime:{future:{other:"{0} सेकंदानीं"},past:{other:"{0} सेकंद आदीं"}}},"second-short":{displayName:"सेकंद",relative:{0:"आतां"},relativeTime:{future:{other:"{0} सेकंदानीं"},past:{other:"{0} से. आदीं"}}},"second-narrow":{displayName:"सेकंद",relative:{0:"आतां"},relativeTime:{future:{other:"{0} सेकंदानीं"},past:{other:"{0} से. आदीं"}}}}})}}]);
//# sourceMappingURL=94.aaedf07e1a1c0392f425.index.js.map