(window.webpackJsonp=window.webpackJsonp||[]).push([[47],{172:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"fa",fields:{year:{displayName:"سال",relative:{0:"امسال",1:"سال آینده","-1":"سال گذشته"},relativeTime:{future:{one:"{0} سال بعد",other:"{0} سال بعد"},past:{one:"{0} سال پیش",other:"{0} سال پیش"}}},"year-short":{displayName:"سال",relative:{0:"امسال",1:"سال آینده","-1":"سال گذشته"},relativeTime:{future:{one:"{0} سال بعد",other:"{0} سال بعد"},past:{one:"{0} سال پیش",other:"{0} سال پیش"}}},"year-narrow":{displayName:"سال",relative:{0:"امسال",1:"سال آینده","-1":"سال گذشته"},relativeTime:{future:{one:"{0} سال بعد",other:"{0} سال بعد"},past:{one:"{0} سال پیش",other:"{0} سال پیش"}}},quarter:{displayName:"سه‌ماهه",relative:{0:"سه‌ماههٔ کنونی",1:"سه‌ماههٔ آینده","-1":"سه‌ماههٔ گذشته"},relativeTime:{future:{one:"{0} سه‌ماههٔ بعد",other:"{0} سه‌ماههٔ بعد"},past:{one:"{0} سه‌ماههٔ پیش",other:"{0} سه‌ماههٔ پیش"}}},"quarter-short":{displayName:"سه‌ماهه",relative:{0:"سه‌ماههٔ کنونی",1:"سه‌ماههٔ آینده","-1":"سه‌ماههٔ گذشته"},relativeTime:{future:{one:"{0} سه‌ماههٔ بعد",other:"{0} سه‌ماههٔ بعد"},past:{one:"{0} سه‌ماههٔ پیش",other:"{0} سه‌ماههٔ پیش"}}},"quarter-narrow":{displayName:"سه‌ماهه",relative:{0:"سه‌ماههٔ کنونی",1:"سه‌ماههٔ آینده","-1":"سه‌ماههٔ گذشته"},relativeTime:{future:{one:"{0} سه‌ماههٔ بعد",other:"{0} سه‌ماههٔ بعد"},past:{one:"{0} سه‌ماههٔ پیش",other:"{0} سه‌ماههٔ پیش"}}},month:{displayName:"ماه",relative:{0:"این ماه",1:"ماه آینده","-1":"ماه گذشته"},relativeTime:{future:{one:"{0} ماه بعد",other:"{0} ماه بعد"},past:{one:"{0} ماه پیش",other:"{0} ماه پیش"}}},"month-short":{displayName:"ماه",relative:{0:"این ماه",1:"ماه آینده","-1":"ماه پیش"},relativeTime:{future:{one:"{0} ماه بعد",other:"{0} ماه بعد"},past:{one:"{0} ماه پیش",other:"{0} ماه پیش"}}},"month-narrow":{displayName:"ماه",relative:{0:"این ماه",1:"ماه آینده","-1":"ماه پیش"},relativeTime:{future:{one:"{0} ماه بعد",other:"{0} ماه بعد"},past:{one:"{0} ماه پیش",other:"{0} ماه پیش"}}},week:{displayName:"هفته",relative:{0:"این هفته",1:"هفتهٔ آینده","-1":"هفتهٔ گذشته"},relativeTime:{future:{one:"{0} هفته بعد",other:"{0} هفته بعد"},past:{one:"{0} هفته پیش",other:"{0} هفته پیش"}},relativePeriod:"هفتهٔ {0}"},"week-short":{displayName:"هفته",relative:{0:"این هفته",1:"هفتهٔ آینده","-1":"هفتهٔ گذشته"},relativeTime:{future:{one:"{0} هفته بعد",other:"{0} هفته بعد"},past:{one:"{0} هفته پیش",other:"{0} هفته پیش"}},relativePeriod:"هفتهٔ {0}"},"week-narrow":{displayName:"هفته",relative:{0:"این هفته",1:"هفتهٔ آینده","-1":"هفتهٔ گذشته"},relativeTime:{future:{one:"{0} هفته بعد",other:"{0} هفته بعد"},past:{one:"{0} هفته پیش",other:"{0} هفته پیش"}},relativePeriod:"هفتهٔ {0}"},day:{displayName:"روز",relative:{0:"امروز",1:"فردا",2:"پس‌فردا","-2":"پریروز","-1":"دیروز"},relativeTime:{future:{one:"{0} روز بعد",other:"{0} روز بعد"},past:{one:"{0} روز پیش",other:"{0} روز پیش"}}},"day-short":{displayName:"روز",relative:{0:"امروز",1:"فردا",2:"پس‌فردا","-2":"پریروز","-1":"دیروز"},relativeTime:{future:{one:"{0} روز بعد",other:"{0} روز بعد"},past:{one:"{0} روز پیش",other:"{0} روز پیش"}}},"day-narrow":{displayName:"روز",relative:{0:"امروز",1:"فردا",2:"پس‌فردا","-2":"پریروز","-1":"دیروز"},relativeTime:{future:{one:"{0} روز بعد",other:"{0} روز بعد"},past:{one:"{0} روز پیش",other:"{0} روز پیش"}}},hour:{displayName:"ساعت",relative:{0:"همین ساعت"},relativeTime:{future:{one:"{0} ساعت بعد",other:"{0} ساعت بعد"},past:{one:"{0} ساعت پیش",other:"{0} ساعت پیش"}}},"hour-short":{displayName:"ساعت",relative:{0:"همین ساعت"},relativeTime:{future:{one:"{0} ساعت بعد",other:"{0} ساعت بعد"},past:{one:"{0} ساعت پیش",other:"{0} ساعت پیش"}}},"hour-narrow":{displayName:"ساعت",relative:{0:"همین ساعت"},relativeTime:{future:{one:"{0} ساعت بعد",other:"{0} ساعت بعد"},past:{one:"{0} ساعت پیش",other:"{0} ساعت پیش"}}},minute:{displayName:"دقیقه",relative:{0:"همین دقیقه"},relativeTime:{future:{one:"{0} دقیقه بعد",other:"{0} دقیقه بعد"},past:{one:"{0} دقیقه پیش",other:"{0} دقیقه پیش"}}},"minute-short":{displayName:"دقیقه",relative:{0:"همین دقیقه"},relativeTime:{future:{one:"{0} دقیقه بعد",other:"{0} دقیقه بعد"},past:{one:"{0} دقیقه پیش",other:"{0} دقیقه پیش"}}},"minute-narrow":{displayName:"دقیقه",relative:{0:"همین دقیقه"},relativeTime:{future:{one:"{0} دقیقه بعد",other:"{0} دقیقه بعد"},past:{one:"{0} دقیقه پیش",other:"{0} دقیقه پیش"}}},second:{displayName:"ثانیه",relative:{0:"اکنون"},relativeTime:{future:{one:"{0} ثانیه بعد",other:"{0} ثانیه بعد"},past:{one:"{0} ثانیه پیش",other:"{0} ثانیه پیش"}}},"second-short":{displayName:"ثانیه",relative:{0:"اکنون"},relativeTime:{future:{one:"{0} ثانیه بعد",other:"{0} ثانیه بعد"},past:{one:"{0} ثانیه پیش",other:"{0} ثانیه پیش"}}},"second-narrow":{displayName:"ثانیه",relative:{0:"اکنون"},relativeTime:{future:{one:"{0} ثانیه بعد",other:"{0} ثانیه بعد"},past:{one:"{0} ثانیه پیش",other:"{0} ثانیه پیش"}}}}},{locale:"fa-AF",parentLocale:"fa"})}}]);
//# sourceMappingURL=47.aaedf07e1a1c0392f425.index.js.map