(window.webpackJsonp=window.webpackJsonp||[]).push([[25],{150:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"chr",fields:{year:{displayName:"ᎤᏕᏘᏴᏌᏗᏒᎢ",relative:{0:"ᎯᎠ ᏧᏕᏘᏴᏒᏘ",1:"ᎡᏘᏴᎢ","-1":"ᎡᏘ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎤᏕᏘᏴᏌᏗᏒᎢ",other:"ᎾᎿ {0} ᎢᏧᏕᏘᏴᏌᏗᏒᎢ"},past:{one:"{0} ᎤᏕᏘᏴᏌᏗᏒᎢ ᏥᎨᏒ",other:"{0} ᎢᏧᏕᏘᏴᏌᏗᏒᎢ ᏥᎨᏒ"}}},"year-short":{displayName:"ᎤᏕ.",relative:{0:"ᎯᎠ ᏧᏕᏘᏴᏒᏘ",1:"ᎡᏘᏴᎢ","-1":"ᎡᏘ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎤᏕ.",other:"ᎾᎿ {0} ᎤᏕ."},past:{one:"{0} ᎤᏕ. ᏥᎨᏒ",other:"{0} ᎤᏕ. ᏥᎨᏒ"}}},"year-narrow":{displayName:"ᎤᏕ.",relative:{0:"ᎯᎠ ᏧᏕᏘᏴᏒᏘ",1:"ᎡᏘᏴᎢ","-1":"ᎡᏘ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎤᏕ.",other:"ᎾᎿ {0} ᎤᏕ."},past:{one:"{0} ᎤᏕ. ᏥᎨᏒ",other:"{0} ᎤᏕ. ᏥᎨᏒ"}}},quarter:{displayName:"ᎩᏄᏙᏗ",relative:{0:"ᎯᎠ ᎩᏄᏙᏗ",1:"ᏔᎵᏁ ᎩᏄᏙᏗ","-1":"ᎩᏄᏙᏗ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎩᏄᏙᏗ",other:"ᎾᎿ {0} ᎩᏄᏙᏗ"},past:{one:"ᎾᎿ {0} ᎩᏄᏙᏗ ᏥᎨᏒ",other:"{0} ᎩᏄᏙᏗ ᏥᎨᏒ"}}},"quarter-short":{displayName:"ᎩᏄᏘ.",relative:{0:"ᎯᎠ ᎩᏄᏙᏗ",1:"ᏔᎵᏁ ᎩᏄᏙᏗ","-1":"ᎩᏄᏙᏗ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎩᏄᏘ.",other:"ᎾᎿ {0} ᎩᏄᏘ."},past:{one:"{0} ᎩᏄᏘ. ᏥᎨᏒ",other:"{0} ᎩᏄᏘ. ᏥᎨᏒ"}}},"quarter-narrow":{displayName:"ᎩᏄᏘ.",relative:{0:"ᎯᎠ ᎩᏄᏙᏗ",1:"ᏔᎵᏁ ᎩᏄᏙᏗ","-1":"ᎩᏄᏙᏗ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎩᏄᏘ.",other:"ᎾᎿ {0} ᎩᏄᏘ."},past:{one:"{0} ᎩᏄᏘ. ᏥᎨᏒ",other:"{0} ᎩᏄᏘ. ᏥᎨᏒ"}}},month:{displayName:"ᎧᎸᎢ",relative:{0:"ᎯᎠ ᎧᎸᎢ",1:"ᏔᎵᏁ ᎧᎸᎢ","-1":"ᎧᎸᎢ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎧᎸᎢ",other:"ᎾᎿ {0} ᏗᎧᎸᎢ"},past:{one:"{0} ᎧᎸᎢ ᏥᎨᏒ",other:"{0} ᏗᎧᎸᎢ ᏥᎨᏒ"}}},"month-short":{displayName:"ᎧᎸ.",relative:{0:"ᎯᎠ ᎧᎸᎢ",1:"ᏔᎵᏁ ᎧᎸᎢ","-1":"ᎧᎸᎢ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎧᎸ.",other:"ᎾᎿ {0} ᎧᎸ."},past:{one:"{0} ᎧᎸ. ᏥᎨᏒ",other:"{0} ᎧᎸ. ᏥᎨᏒ"}}},"month-narrow":{displayName:"ᎧᎸ.",relative:{0:"ᎯᎠ ᎧᎸᎢ",1:"ᏔᎵᏁ ᎧᎸᎢ","-1":"ᎧᎸᎢ ᏥᎨᏒ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎧᎸ.",other:"ᎾᎿ {0} ᎧᎸ."},past:{one:"{0} ᎧᎸ. ᏥᎨᏒ",other:"{0} ᎧᎸ. ᏥᎨᏒ"}}},week:{displayName:"ᏒᎾᏙᏓᏆᏍᏗ",relative:{0:"ᎯᎠ ᎠᎵᎵᏌ",1:"ᏐᏆᎴᏅᎲ","-1":"ᏥᏛᎵᏱᎵᏒᎢ"},relativeTime:{future:{one:"ᎾᎿ {0} ᏒᎾᏙᏓᏆᏍᏗ",other:"ᎾᎿ {0} ᎢᏳᎾᏙᏓᏆᏍᏗ"},past:{one:"{0} ᏒᎾᏙᏓᏆᏍᏗ ᏥᎨᏒ",other:"{0} ᎢᏳᎾᏙᏓᏆᏍᏗ ᏥᎨᏒ"}},relativePeriod:"Ꮎ ᏒᎾᏙᏓᏆᏍᏗ ᎾᏍᎩ {0}"},"week-short":{displayName:"ᏒᎾ.",relative:{0:"ᎯᎠ ᎠᎵᎵᏌ",1:"ᏐᏆᎴᏅᎲ","-1":"ᏥᏛᎵᏱᎵᏒᎢ"},relativeTime:{future:{one:"ᎾᎿ {0} ᏒᎾ.",other:"ᎾᎿ {0} ᏒᎾ."},past:{one:"{0} ᏒᎾ. ᏥᎨᏒ",other:"{0} ᏒᎾ. ᏥᎨᏒ"}},relativePeriod:"Ꮎ ᏒᎾᏙᏓᏆᏍᏗ ᎾᏍᎩ {0}"},"week-narrow":{displayName:"ᏒᎾ.",relative:{0:"ᎯᎠ ᎠᎵᎵᏌ",1:"ᏐᏆᎴᏅᎲ","-1":"ᏥᏛᎵᏱᎵᏒᎢ"},relativeTime:{future:{one:"ᎾᎿ {0} ᏒᎾ.",other:"ᎾᎿ {0} ᏒᎾ."},past:{one:"{0} ᏒᎾ. ᏥᎨᏒ",other:"{0} ᏒᎾ. ᏥᎨᏒ"}},relativePeriod:"Ꮎ ᏒᎾᏙᏓᏆᏍᏗ ᎾᏍᎩ {0}"},day:{displayName:"ᎢᎦ",relative:{0:"ᎪᎯ ᎢᎦ",1:"ᏌᎾᎴᎢ","-1":"ᏒᎯ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎢᎦ",other:"ᎾᎿ {0} ᎯᎸᏍᎩ ᏧᏒᎯᏛ"},past:{one:"{0} ᎢᎦ ᏥᎨᏒ",other:"{0} ᎯᎸᏍᎩ ᏧᏒᎯᏛ ᏥᎨᏒ"}}},"day-short":{displayName:"ᎢᎦ",relative:{0:"ᎪᎯ ᎢᎦ",1:"ᏌᎾᎴᎢ","-1":"ᏒᎯ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎢᎦ",other:"ᎾᎿ {0} ᎯᎸᏍᎩ ᏧᏒᎯᏛ"},past:{one:"{0} ᎢᎦ ᏥᎨᏒ",other:"{0} ᎯᎸᏍᎩ ᏧᏒᎯᏛ ᏥᎨᏒ"}}},"day-narrow":{displayName:"ᎢᎦ",relative:{0:"ᎪᎯ ᎢᎦ",1:"ᏌᎾᎴᎢ","-1":"ᏒᎯ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎢᎦ",other:"ᎾᎿ {0} ᎯᎸᏍᎩ ᏧᏒᎯᏛ"},past:{one:"{0} ᎢᎦ ᏥᎨᏒ",other:"{0} ᎯᎸᏍᎩ ᏧᏒᎯᏛ ᏥᎨᏒ"}}},hour:{displayName:"ᏑᏟᎶᏓ",relative:{0:"ᎯᎠ ᏑᏟᎶᏓ"},relativeTime:{future:{one:"ᎾᎿ {0} ᏑᏟᎶᏓ",other:"ᎾᎿ {0} ᎢᏳᏟᎶᏓ"},past:{one:"{0} ᏑᏟᎶᏓ ᏥᎨᏒ",other:"{0} ᎢᏳᏟᎶᏓ ᏥᎨᏒ"}}},"hour-short":{displayName:"ᏑᏟ.",relative:{0:"ᎯᎠ ᏑᏟᎶᏓ"},relativeTime:{future:{one:"ᎾᎿ {0} ᏑᏟ.",other:"ᎾᎿ {0} ᏑᏟ."},past:{one:"{0} ᏑᏟ. ᏥᎨᏒ",other:"{0} ᏑᏟ. ᏥᎨᏒ"}}},"hour-narrow":{displayName:"ᏑᏟ.",relative:{0:"ᎯᎠ ᏑᏟᎶᏓ"},relativeTime:{future:{one:"ᎾᎿ {0} ᏑᏟ.",other:"ᎾᎿ {0} ᏑᏟ."},past:{one:"{0} ᏑᏟ. ᏥᎨᏒ",other:"{0} ᏑᏟ. ᏥᎨᏒ"}}},minute:{displayName:"ᎢᏯᏔᏬᏍᏔᏅ",relative:{0:"ᎯᎠ ᎢᏯᏔᏬᏍᏔᏅ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎢᏯᏔᏬᏍᏔᏅ",other:"ᎾᎿ {0} ᎢᏯᏔᏬᏍᏔᏅ"},past:{one:"{0} ᎢᏯᏔᏬᏍᏔᏅ ᏥᎨᏒ",other:"{0} ᎢᏯᏔᏬᏍᏔᏅ ᏥᎨᏒ"}}},"minute-short":{displayName:"ᎢᏯᏔ.",relative:{0:"ᎯᎠ ᎢᏯᏔᏬᏍᏔᏅ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎢᏯᏔ.",other:"ᎾᎿ {0} ᎢᏯᏔ."},past:{one:"{0} ᎢᏯᏔ. ᏥᎨᏒ",other:"{0} ᎢᏯᏔ. ᏥᎨᏒ"}}},"minute-narrow":{displayName:"ᎢᏯᏔ.",relative:{0:"ᎯᎠ ᎢᏯᏔᏬᏍᏔᏅ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎢᏯᏔ.",other:"ᎾᎿ {0} ᎢᏯᏔ."},past:{one:"{0} ᎢᏯᏔ. ᏥᎨᏒ",other:"{0} ᎢᏯᏔ. ᏥᎨᏒ"}}},second:{displayName:"ᎠᏎᏢ",relative:{0:"ᏃᏊ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎠᏎᏢ",other:"ᎾᎿ {0} ᏓᏓᎾᏩᏍᎬ ᏥᎨᏒ"},past:{one:"{0} ᎠᏎᏢ ᏥᎨᏒ",other:"{0} ᏓᏓᎾᏩᏍᎬ ᏥᎨᏒ"}}},"second-short":{displayName:"ᎠᏎ.",relative:{0:"ᏃᏊ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎠᏎ.",other:"ᎾᎿ {0} ᎠᏎ."},past:{one:"{0} ᎠᏎ. ᏥᎨᏒ",other:"{0} ᎠᏎ. ᏥᎨᏒ"}}},"second-narrow":{displayName:"ᎠᏎ.",relative:{0:"ᏃᏊ"},relativeTime:{future:{one:"ᎾᎿ {0} ᎠᏎ.",other:"ᎾᎿ {0} ᎠᏎ."},past:{one:"{0} ᎠᏎ. ᏥᎨᏒ",other:"{0} ᎠᏎ. ᏥᎨᏒ"}}}}})}}]);
//# sourceMappingURL=25.aaedf07e1a1c0392f425.index.js.map