(window.webpackJsonp=window.webpackJsonp||[]).push([[80],{205:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"ka",fields:{year:{displayName:"წელი",relative:{0:"ამ წელს",1:"მომავალ წელს","-1":"გასულ წელს"},relativeTime:{future:{one:"{0} წელიწადში",other:"{0} წელიწადში"},past:{one:"{0} წლის წინ",other:"{0} წლის წინ"}}},"year-short":{displayName:"წ.",relative:{0:"ამ წელს",1:"მომავალ წელს","-1":"გასულ წელს"},relativeTime:{future:{one:"{0} წელში",other:"{0} წელში"},past:{one:"{0} წლის წინ",other:"{0} წლის წინ"}}},"year-narrow":{displayName:"წ.",relative:{0:"ამ წელს",1:"მომავალ წელს","-1":"გასულ წელს"},relativeTime:{future:{one:"{0} წელში",other:"{0} წელში"},past:{one:"{0} წლის წინ",other:"{0} წლის წინ"}}},quarter:{displayName:"კვარტალი",relative:{0:"ამ კვარტალში",1:"შემდეგ კვარტალში","-1":"გასულ კვარტალში"},relativeTime:{future:{one:"{0} კვარტალში",other:"{0} კვარტალში"},past:{one:"{0} კვარტალის წინ",other:"{0} კვარტალის წინ"}}},"quarter-short":{displayName:"კვარტ.",relative:{0:"ამ კვარტალში",1:"შემდეგ კვარტალში","-1":"გასულ კვარტალში"},relativeTime:{future:{one:"{0} კვარტალში",other:"{0} კვარტალში"},past:{one:"{0} კვარტ. წინ",other:"{0} კვარტ. წინ"}}},"quarter-narrow":{displayName:"კვარტ.",relative:{0:"ამ კვარტალში",1:"შემდეგ კვარტალში","-1":"გასულ კვარტალში"},relativeTime:{future:{one:"{0} კვარტალში",other:"{0} კვარტალში"},past:{one:"{0} კვარტ. წინ",other:"{0} კვარტ. წინ"}}},month:{displayName:"თვე",relative:{0:"ამ თვეში",1:"მომავალ თვეს","-1":"გასულ თვეს"},relativeTime:{future:{one:"{0} თვეში",other:"{0} თვეში"},past:{one:"{0} თვის წინ",other:"{0} თვის წინ"}}},"month-short":{displayName:"თვე",relative:{0:"ამ თვეში",1:"მომავალ თვეს","-1":"გასულ თვეს"},relativeTime:{future:{one:"{0} თვეში",other:"{0} თვეში"},past:{one:"{0} თვის წინ",other:"{0} თვის წინ"}}},"month-narrow":{displayName:"თვე",relative:{0:"ამ თვეში",1:"მომავალ თვეს","-1":"გასულ თვეს"},relativeTime:{future:{one:"{0} თვეში",other:"{0} თვეში"},past:{one:"{0} თვის წინ",other:"{0} თვის წინ"}}},week:{displayName:"კვირა",relative:{0:"ამ კვირაში",1:"მომავალ კვირაში","-1":"გასულ კვირაში"},relativeTime:{future:{one:"{0} კვირაში",other:"{0} კვირაში"},past:{one:"{0} კვირის წინ",other:"{0} კვირის წინ"}},relativePeriod:"{0}-ის კვირაში"},"week-short":{displayName:"კვ.",relative:{0:"ამ კვირაში",1:"მომავალ კვირაში","-1":"გასულ კვირაში"},relativeTime:{future:{one:"{0} კვირაში",other:"{0} კვირაში"},past:{one:"{0} კვ. წინ",other:"{0} კვ. წინ"}},relativePeriod:"{0}-ის კვირაში"},"week-narrow":{displayName:"კვ.",relative:{0:"ამ კვირაში",1:"მომავალ კვირაში","-1":"გასულ კვირაში"},relativeTime:{future:{one:"{0} კვირაში",other:"{0} კვირაში"},past:{one:"{0} კვირის წინ",other:"{0} კვირის წინ"}},relativePeriod:"{0}-ის კვირაში"},day:{displayName:"დღე",relative:{0:"დღეს",1:"ხვალ",2:"ზეგ","-2":"გუშინწინ","-1":"გუშინ"},relativeTime:{future:{one:"{0} დღეში",other:"{0} დღეში"},past:{one:"{0} დღის წინ",other:"{0} დღის წინ"}}},"day-short":{displayName:"დღე",relative:{0:"დღეს",1:"ხვალ",2:"ზეგ","-2":"გუშინწინ","-1":"გუშინ"},relativeTime:{future:{one:"{0} დღეში",other:"{0} დღეში"},past:{one:"{0} დღის წინ",other:"{0} დღის წინ"}}},"day-narrow":{displayName:"დღე",relative:{0:"დღეს",1:"ხვალ",2:"ზეგ","-2":"გუშინწინ","-1":"გუშინ"},relativeTime:{future:{one:"{0} დღეში",other:"{0} დღეში"},past:{one:"{0} დღის წინ",other:"{0} დღის წინ"}}},hour:{displayName:"საათი",relative:{0:"ამ საათში"},relativeTime:{future:{one:"{0} საათში",other:"{0} საათში"},past:{one:"{0} საათის წინ",other:"{0} საათის წინ"}}},"hour-short":{displayName:"სთ.",relative:{0:"ამ საათში"},relativeTime:{future:{one:"{0} საათში",other:"{0} საათში"},past:{one:"{0} სთ წინ",other:"{0} სთ წინ"}}},"hour-narrow":{displayName:"სთ.",relative:{0:"ამ საათში"},relativeTime:{future:{one:"{0} საათში",other:"{0} საათში"},past:{one:"{0} სთ წინ",other:"{0} სთ წინ"}}},minute:{displayName:"წუთი",relative:{0:"ამ წუთში"},relativeTime:{future:{one:"{0} წუთში",other:"{0} წუთში"},past:{one:"{0} წუთის წინ",other:"{0} წუთის წინ"}}},"minute-short":{displayName:"წთ.",relative:{0:"ამ წუთში"},relativeTime:{future:{one:"{0} წუთში",other:"{0} წუთში"},past:{one:"{0} წთ წინ",other:"{0} წთ წინ"}}},"minute-narrow":{displayName:"წთ.",relative:{0:"ამ წუთში"},relativeTime:{future:{one:"{0} წუთში",other:"{0} წუთში"},past:{one:"{0} წთ წინ",other:"{0} წთ წინ"}}},second:{displayName:"წამი",relative:{0:"ახლა"},relativeTime:{future:{one:"{0} წამში",other:"{0} წამში"},past:{one:"{0} წამის წინ",other:"{0} წამის წინ"}}},"second-short":{displayName:"წმ.",relative:{0:"ახლა"},relativeTime:{future:{one:"{0} წამში",other:"{0} წამში"},past:{one:"{0} წმ წინ",other:"{0} წმ წინ"}}},"second-narrow":{displayName:"წმ.",relative:{0:"ახლა"},relativeTime:{future:{one:"{0} წამში",other:"{0} წამში"},past:{one:"{0} წმ წინ",other:"{0} წმ წინ"}}}}})}}]);
//# sourceMappingURL=80.aaedf07e1a1c0392f425.index.js.map