(window.webpackJsonp=window.webpackJsonp||[]).push([[171],{296:function(a,e){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"so",fields:{year:{displayName:"Sannad",relative:{0:"Sannadkan",1:"Sannadka danbe","-1":"Sannadkii hore"},relativeTime:{future:{one:"{0} sannad",other:"{0} sannadood"},past:{one:"{0} sannad kahor",other:"{0} sannadood kahor"}}},"year-short":{displayName:"snd",relative:{0:"Sannadkan",1:"Sannadka danbe","-1":"Sannadkii hore"},relativeTime:{future:{one:"{0} snd",other:"{0} snd"},past:{one:"{0} snd khr",other:"{0} Snd khr"}}},"year-narrow":{displayName:"Snd",relative:{0:"Sannadkan",1:"Sannadka xiga","-1":"Sannadkii la soo dhaafay"},relativeTime:{future:{one:"{0} snd",other:"{0} snd"},past:{one:"{0} snd khr",other:"{0} Snd khr"}}},quarter:{displayName:"Rubuc",relative:{0:"Rubucan",1:"Rubuca danbe","-1":"Rubucii hore"},relativeTime:{future:{one:"{0} rubuc",other:"{0} rubuc"},past:{one:"{0} rubuc kahor",other:"{0} rubuc kahor"}}},"quarter-short":{displayName:"rbc",relative:{0:"Rubucan",1:"Rubuca danbe","-1":"Rubucii hore"},relativeTime:{future:{one:"{0} rbc",other:"{0} rbc"},past:{one:"{0} rbc khr",other:"{0} rbc khr"}}},"quarter-narrow":{displayName:"rbc",relative:{0:"Rubucan",1:"Rubuca danbe","-1":"Rubucii hore"},relativeTime:{future:{one:"{0} rbc",other:"{0} rbc"},past:{one:"{0} rbc khr",other:"{0} rbc khr"}}},month:{displayName:"Bil",relative:{0:"Bishan",1:"Bisha danbe","-1":"Bishii hore"},relativeTime:{future:{one:"{0} bil",other:"{0} bilood"},past:{one:"{0} bil kahor",other:"{0} bilood kahor"}}},"month-short":{displayName:"Bil-gaaban",relative:{0:"Bishan",1:"Bisha danbe","-1":"Bishii hore"},relativeTime:{future:{one:"{0} bil",other:"{0} bil"},past:{one:"{0} bil khr",other:"{0} bil khr"}}},"month-narrow":{displayName:"Bil-gaaban",relative:{0:"Bishan",1:"Bisha danbe","-1":"Bishii hore"},relativeTime:{future:{one:"{0} bil",other:"{0} bil"},past:{one:"{0} bil khr",other:"{0} bil khr"}}},week:{displayName:"Toddobaad",relative:{0:"Usbuucan",1:"Toddobaadka danbe","-1":"Toddobaadkii hore"},relativeTime:{future:{one:"{0} toddobaad",other:"{0} toddobaad"},past:{one:"{0} toddobaad kahor",other:"{0} toddobaad kahor"}},relativePeriod:"Toddobaadka {0}"},"week-short":{displayName:"tdbd",relative:{0:"Usbuucan",1:"Toddobaadka danbe","-1":"Toddobaadkii hore"},relativeTime:{future:{one:"{0} tdbd",other:"{0} tdbd"},past:{one:"{0} tdbd khr",other:"{0} tdbd khr"}},relativePeriod:"Tdbdka {0}"},"week-narrow":{displayName:"tdbd",relative:{0:"Usbuucan",1:"Toddobaadka danbe","-1":"Toddobaadkii hore"},relativeTime:{future:{one:"{0} tdbd",other:"{0} tdbd"},past:{one:"{0} tdbd khr",other:"{0} tdbd khr"}},relativePeriod:"Tdbdka {0}"},day:{displayName:"maalin",relative:{0:"Maanta",1:"Berri","-1":"Shalay"},relativeTime:{future:{one:"{0} maalin",other:"{0} maalmood"},past:{one:"{0} maalin kahor",other:"{0} maalmood kahor"}}},"day-short":{displayName:"mln",relative:{0:"Maanta",1:"Berri","-1":"Shalay"},relativeTime:{future:{one:"{0} mln",other:"{0} mlmd"},past:{one:"{0} mln khr",other:"{0} mlmd khr"}}},"day-narrow":{displayName:"mln",relative:{0:"Maanta",1:"Berri","-1":"Shalay"},relativeTime:{future:{one:"{0} mln",other:"{0} mlmd"},past:{one:"{0} mln khr",other:"{0} mlmd khr"}}},hour:{displayName:"Saacad",relative:{0:"Saacadan"},relativeTime:{future:{one:"{0} saacad",other:"{0} saacadood"},past:{one:"{0} saacad kahor",other:"{0} saacadood kahor"}}},"hour-short":{displayName:"scd",relative:{0:"Saacadan"},relativeTime:{future:{one:"{0} scd",other:"{0} scd"},past:{one:"{0} scd khr",other:"{0} scd khr"}}},"hour-narrow":{displayName:"scd",relative:{0:"Saacadan"},relativeTime:{future:{one:"{0} scd",other:"{0} scd"},past:{one:"{0} scd khr",other:"{0} scd khr"}}},minute:{displayName:"daqiiqad",relative:{0:"Daqiiqadan"},relativeTime:{future:{one:"{0} daqiiqad",other:"{0} daqiidadood"},past:{one:"{0} daqiiqad kahor",other:"{0} daqiiqadood kahor"}}},"minute-short":{displayName:"dqqd",relative:{0:"Daqiiqadan"},relativeTime:{future:{one:"{0} dqqd",other:"{0} dqqd"},past:{one:"{0} dqqd khr",other:"{0} dqqd khr"}}},"minute-narrow":{displayName:"dqqd",relative:{0:"Daqiiqadan"},relativeTime:{future:{one:"{0} dqqd",other:"{0} dqqd"},past:{one:"{0} dqqd khr",other:"{0} dqqd khr"}}},second:{displayName:"ilbiriqsi",relative:{0:"Imika"},relativeTime:{future:{one:"{0} ilbiriqsi",other:"{0} ilbiriqsi"},past:{one:"{0} ilbiriqsi kahor",other:"{0} ilbiriqsi kahor"}}},"second-short":{displayName:"ilbrqsi",relative:{0:"Imika"},relativeTime:{future:{one:"{0} ilbrqsi",other:"{0} ilbrqsi"},past:{one:"{0} ilbrqsi khr",other:"{0} ilbrqsi khr"}}},"second-narrow":{displayName:"ilbrqsi",relative:{0:"Imika"},relativeTime:{future:{one:"{0} ilbrqsi",other:"{0} ilbrqsi"},past:{one:"{0} ilbrqsi khr",other:"{0} ilbrqsi khr"}}}}},{locale:"so-DJ",parentLocale:"so"},{locale:"so-ET",parentLocale:"so"},{locale:"so-KE",parentLocale:"so"})}}]);
//# sourceMappingURL=171.aaedf07e1a1c0392f425.index.js.map