(window.webpackJsonp=window.webpackJsonp||[]).push([[15],{140:function(e,t){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"bn",fields:{year:{displayName:"বছর",relative:{0:"এই বছর",1:"পরের বছর","-1":"গত বছর"},relativeTime:{future:{one:"{0} বছরে",other:"{0} বছরে"},past:{one:"{0} বছর পূর্বে",other:"{0} বছর পূর্বে"}}},"year-short":{displayName:"বছর",relative:{0:"এই বছর",1:"পরের বছর","-1":"গত বছর"},relativeTime:{future:{one:"{0} বছরে",other:"{0} বছরে"},past:{one:"{0} বছর পূর্বে",other:"{0} বছর পূর্বে"}}},"year-narrow":{displayName:"বছর",relative:{0:"এই বছর",1:"পরের বছর","-1":"গত বছর"},relativeTime:{future:{one:"{0} বছরে",other:"{0} বছরে"},past:{one:"{0} বছর পূর্বে",other:"{0} বছর পূর্বে"}}},quarter:{displayName:"ত্রৈমাসিক",relative:{0:"এই ত্রৈমাসিক",1:"পরের ত্রৈমাসিক","-1":"গত ত্রৈমাসিক"},relativeTime:{future:{one:"{0} ত্রৈমাসিকে",other:"{0} ত্রৈমাসিকে"},past:{one:"{0} ত্রৈমাসিক আগে",other:"{0} ত্রৈমাসিক আগে"}}},"quarter-short":{displayName:"ত্রৈমাসিক",relative:{0:"এই ত্রৈমাসিক",1:"পরের ত্রৈমাসিক","-1":"গত ত্রৈমাসিক"},relativeTime:{future:{one:"{0} ত্রৈমাসিকে",other:"{0} ত্রৈমাসিকে"},past:{one:"{0} ত্রৈমাসিক আগে",other:"{0} ত্রৈমাসিক আগে"}}},"quarter-narrow":{displayName:"ত্রৈমাসিক",relative:{0:"এই ত্রৈমাসিক",1:"পরের ত্রৈমাসিক","-1":"গত ত্রৈমাসিক"},relativeTime:{future:{one:"{0} ত্রৈমাসিকে",other:"{0} ত্রৈমাসিকে"},past:{one:"{0} ত্রৈমাসিক আগে",other:"{0} ত্রৈমাসিক আগে"}}},month:{displayName:"মাস",relative:{0:"এই মাস",1:"পরের মাস","-1":"গত মাস"},relativeTime:{future:{one:"{0} মাসে",other:"{0} মাসে"},past:{one:"{0} মাস আগে",other:"{0} মাস আগে"}}},"month-short":{displayName:"মাস",relative:{0:"এই মাস",1:"পরের মাস","-1":"গত মাস"},relativeTime:{future:{one:"{0} মাসে",other:"{0} মাসে"},past:{one:"{0} মাস আগে",other:"{0} মাস আগে"}}},"month-narrow":{displayName:"মাস",relative:{0:"এই মাস",1:"পরের মাস","-1":"গত মাস"},relativeTime:{future:{one:"{0} মাসে",other:"{0} মাসে"},past:{one:"{0} মাস আগে",other:"{0} মাস আগে"}}},week:{displayName:"সপ্তাহ",relative:{0:"এই সপ্তাহ",1:"পরের সপ্তাহ","-1":"গত সপ্তাহ"},relativeTime:{future:{one:"{0} সপ্তাহে",other:"{0} সপ্তাহে"},past:{one:"{0} সপ্তাহ আগে",other:"{0} সপ্তাহ আগে"}},relativePeriod:"{0} তম সপ্তাহে"},"week-short":{displayName:"সপ্তাহ",relative:{0:"এই সপ্তাহ",1:"পরের সপ্তাহ","-1":"গত সপ্তাহ"},relativeTime:{future:{one:"{0} সপ্তাহে",other:"{0} সপ্তাহে"},past:{one:"{0} সপ্তাহ আগে",other:"{0} সপ্তাহ আগে"}},relativePeriod:"{0} তম সপ্তাহে"},"week-narrow":{displayName:"সপ্তাহ",relative:{0:"এই সপ্তাহ",1:"পরের সপ্তাহ","-1":"গত সপ্তাহ"},relativeTime:{future:{one:"{0} সপ্তাহে",other:"{0} সপ্তাহে"},past:{one:"{0} সপ্তাহ আগে",other:"{0} সপ্তাহ আগে"}},relativePeriod:"{0} এর সপ্তাহে"},day:{displayName:"দিন",relative:{0:"আজ",1:"আগামীকাল",2:"আগামী পরশু","-2":"গত পরশু","-1":"গতকাল"},relativeTime:{future:{one:"{0} দিনের মধ্যে",other:"{0} দিনের মধ্যে"},past:{one:"{0} দিন আগে",other:"{0} দিন আগে"}}},"day-short":{displayName:"দিন",relative:{0:"আজ",1:"আগামীকাল",2:"আগামী পরশু","-2":"গত পরশু","-1":"গতকাল"},relativeTime:{future:{one:"{0} দিনের মধ্যে",other:"{0} দিনের মধ্যে"},past:{one:"{0} দিন আগে",other:"{0} দিন আগে"}}},"day-narrow":{displayName:"দিন",relative:{0:"আজ",1:"আগামীকাল",2:"আগামী পরশু","-2":"গত পরশু","-1":"গতকাল"},relativeTime:{future:{one:"{0} দিনের মধ্যে",other:"{0} দিনের মধ্যে"},past:{one:"{0} দিন আগে",other:"{0} দিন আগে"}}},hour:{displayName:"ঘণ্টা",relative:{0:"এই ঘণ্টায়"},relativeTime:{future:{one:"{0} ঘন্টায়",other:"{0} ঘন্টায়"},past:{one:"{0} ঘন্টা আগে",other:"{0} ঘন্টা আগে"}}},"hour-short":{displayName:"ঘণ্টা",relative:{0:"এই ঘণ্টায়"},relativeTime:{future:{one:"{0} ঘন্টায়",other:"{0} ঘন্টায়"},past:{one:"{0} ঘন্টা আগে",other:"{0} ঘন্টা আগে"}}},"hour-narrow":{displayName:"ঘণ্টা",relative:{0:"এই ঘণ্টায়"},relativeTime:{future:{one:"{0} ঘন্টায়",other:"{0} ঘন্টায়"},past:{one:"{0} ঘন্টা আগে",other:"{0} ঘন্টা আগে"}}},minute:{displayName:"মিনিট",relative:{0:"এই মিনিট"},relativeTime:{future:{one:"{0} মিনিটে",other:"{0} মিনিটে"},past:{one:"{0} মিনিট আগে",other:"{0} মিনিট আগে"}}},"minute-short":{displayName:"মিনিট",relative:{0:"এই মিনিট"},relativeTime:{future:{one:"{0} মিনিটে",other:"{0} মিনিটে"},past:{one:"{0} মিনিট আগে",other:"{0} মিনিট আগে"}}},"minute-narrow":{displayName:"মিনিট",relative:{0:"এই মিনিট"},relativeTime:{future:{one:"{0} মিনিটে",other:"{0} মিনিটে"},past:{one:"{0} মিনিট আগে",other:"{0} মিনিট আগে"}}},second:{displayName:"সেকেন্ড",relative:{0:"এখন"},relativeTime:{future:{one:"{0} সেকেন্ডে",other:"{0} সেকেন্ডে"},past:{one:"{0} সেকেন্ড পূর্বে",other:"{0} সেকেন্ড পূর্বে"}}},"second-short":{displayName:"সেকেন্ড",relative:{0:"এখন"},relativeTime:{future:{one:"{0} সেকেন্ডে",other:"{0} সেকেন্ডে"},past:{one:"{0} সেকেন্ড পূর্বে",other:"{0} সেকেন্ড পূর্বে"}}},"second-narrow":{displayName:"সেকেন্ড",relative:{0:"এখন"},relativeTime:{future:{one:"{0} সেকেন্ডে",other:"{0} সেকেন্ডে"},past:{one:"{0} সেকেন্ড আগে",other:"{0} সেকেন্ড আগে"}}}}},{locale:"bn-IN",parentLocale:"bn"})}}]);
//# sourceMappingURL=15.aaedf07e1a1c0392f425.index.js.map