(window.webpackJsonp=window.webpackJsonp||[]).push([[174],{299:function(e,r){Intl.RelativeTimeFormat&&"function"==typeof Intl.RelativeTimeFormat.__addLocaleData&&Intl.RelativeTimeFormat.__addLocaleData({locale:"sv",fields:{year:{displayName:"år",relative:{0:"i år",1:"nästa år","-1":"i fjol"},relativeTime:{future:{one:"om {0} år",other:"om {0} år"},past:{one:"för {0} år sedan",other:"för {0} år sedan"}}},"year-short":{displayName:"år",relative:{0:"i år",1:"nästa år","-1":"i fjol"},relativeTime:{future:{one:"om {0} år",other:"om {0} år"},past:{one:"för {0} år sen",other:"för {0} år sen"}}},"year-narrow":{displayName:"år",relative:{0:"i år",1:"nästa år","-1":"i fjol"},relativeTime:{future:{one:"+{0} år",other:"+{0} år"},past:{one:"−{0} år",other:"−{0} år"}}},quarter:{displayName:"kvartal",relative:{0:"detta kvartal",1:"nästa kvartal","-1":"förra kvartalet"},relativeTime:{future:{one:"om {0} kvartal",other:"om {0} kvartal"},past:{one:"för {0} kvartal sedan",other:"för {0} kvartal sedan"}}},"quarter-short":{displayName:"kv.",relative:{0:"detta kv.",1:"nästa kv.","-1":"förra kv."},relativeTime:{future:{one:"om {0} kv.",other:"om {0} kv."},past:{one:"för {0} kv. sen",other:"för {0} kv. sen"}}},"quarter-narrow":{displayName:"kv.",relative:{0:"detta kv.",1:"nästa kv.","-1":"förra kv."},relativeTime:{future:{one:"+{0} kv.",other:"+{0} kv."},past:{one:"−{0} kv",other:"−{0} kv"}}},month:{displayName:"månad",relative:{0:"denna månad",1:"nästa månad","-1":"förra månaden"},relativeTime:{future:{one:"om {0} månad",other:"om {0} månader"},past:{one:"för {0} månad sedan",other:"för {0} månader sedan"}}},"month-short":{displayName:"m",relative:{0:"denna mån.",1:"nästa mån.","-1":"förra mån."},relativeTime:{future:{one:"om {0} mån.",other:"om {0} mån."},past:{one:"för {0} mån. sen",other:"för {0} mån. sen"}}},"month-narrow":{displayName:"mån",relative:{0:"denna mån.",1:"nästa mån.","-1":"förra mån."},relativeTime:{future:{one:"+{0} mån.",other:"+{0} mån."},past:{one:"−{0} mån",other:"−{0} mån"}}},week:{displayName:"vecka",relative:{0:"denna vecka",1:"nästa vecka","-1":"förra veckan"},relativeTime:{future:{one:"om {0} vecka",other:"om {0} veckor"},past:{one:"för {0} vecka sedan",other:"för {0} veckor sedan"}},relativePeriod:"veckan för {0}"},"week-short":{displayName:"v",relative:{0:"denna v.",1:"nästa v.","-1":"förra v."},relativeTime:{future:{one:"om {0} v.",other:"om {0} v."},past:{one:"för {0} v. sedan",other:"för {0} v. sedan"}},relativePeriod:"veckan för {0}"},"week-narrow":{displayName:"v",relative:{0:"denna v.",1:"nästa v.","-1":"förra v."},relativeTime:{future:{one:"+{0} v.",other:"+{0} v."},past:{one:"−{0} v",other:"−{0} v"}},relativePeriod:"veckan för {0}"},day:{displayName:"dag",relative:{0:"i dag",1:"i morgon",2:"i övermorgon","-2":"i förrgår","-1":"i går"},relativeTime:{future:{one:"om {0} dag",other:"om {0} dagar"},past:{one:"för {0} dag sedan",other:"för {0} dagar sedan"}}},"day-short":{displayName:"dag",relative:{0:"i dag",1:"i morgon",2:"i övermorgon","-2":"i förrgår","-1":"i går"},relativeTime:{future:{one:"om {0} d",other:"om {0} d"},past:{one:"för {0} d sedan",other:"för {0} d sedan"}}},"day-narrow":{displayName:"dag",relative:{0:"idag",1:"imorgon",2:"i övermorgon","-2":"i förrgår","-1":"igår"},relativeTime:{future:{one:"+{0} d",other:"+{0} d"},past:{one:"−{0} d",other:"−{0} d"}}},hour:{displayName:"timme",relative:{0:"denna timme"},relativeTime:{future:{one:"om {0} timme",other:"om {0} timmar"},past:{one:"för {0} timme sedan",other:"för {0} timmar sedan"}}},"hour-short":{displayName:"tim",relative:{0:"denna timme"},relativeTime:{future:{one:"om {0} tim",other:"om {0} tim"},past:{one:"för {0} tim sedan",other:"för {0} tim sedan"}}},"hour-narrow":{displayName:"h",relative:{0:"denna timme"},relativeTime:{future:{one:"+{0} h",other:"+{0} h"},past:{one:"−{0} h",other:"−{0} h"}}},minute:{displayName:"minut",relative:{0:"denna minut"},relativeTime:{future:{one:"om {0} minut",other:"om {0} minuter"},past:{one:"för {0} minut sedan",other:"för {0} minuter sedan"}}},"minute-short":{displayName:"min",relative:{0:"denna minut"},relativeTime:{future:{one:"om {0} min",other:"om {0} min"},past:{one:"för {0} min sen",other:"för {0} min sen"}}},"minute-narrow":{displayName:"m",relative:{0:"denna minut"},relativeTime:{future:{one:"+{0} min",other:"+{0} min"},past:{one:"−{0} min",other:"−{0} min"}}},second:{displayName:"sekund",relative:{0:"nu"},relativeTime:{future:{one:"om {0} sekund",other:"om {0} sekunder"},past:{one:"för {0} sekund sedan",other:"för {0} sekunder sedan"}}},"second-short":{displayName:"sek",relative:{0:"nu"},relativeTime:{future:{one:"om {0} sek",other:"om {0} sek"},past:{one:"för {0} s sen",other:"för {0} s sen"}}},"second-narrow":{displayName:"s",relative:{0:"nu"},relativeTime:{future:{one:"+{0} s",other:"+{0} s"},past:{one:"−{0} s",other:"−{0} s"}}}}},{locale:"sv-AX",parentLocale:"sv"},{locale:"sv-FI",parentLocale:"sv"})}}]);
//# sourceMappingURL=174.aaedf07e1a1c0392f425.index.js.map